@@ -2,7 +2,7 @@
 *                                transfer.cpp
 *                             -------------------
 *
-*    Revision     : $Id: transfer.cpp,v 1.40.2.2 2002/12/10 02:03:58 pfeiffer Exp $
+*    Revision     : $Id: transfer.cpp,v 1.40.2.4 2003/03/03 15:42:12 pfeiffer Exp $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -35,6 +35,7 @@
 #include <kwin.h>
 
 #include <assert.h>
+#include "safedelete.h"
 #include "settings.h"
 #include "logwindow.h"
 #include "kmainwidget.h"
@@ -86,8 +87,8 @@ Transfer::~Transfer()
 {
     sDebugIn << endl;
 
-    tryKillSlave();
-    
+    synchronousAbort();
+
     delete dlgIndividual;
     sDebugOut << endl;
 }
@@ -145,7 +146,7 @@ Transfer::init()
 
     // Actions
 
-    //        m_paDock = new KAction(i18n("&Dock"),"tool_dock.png", 0, this,SLOT(slotRequestDelay()), this, "dockIndividual");
+    // m_paDock = new KAction(i18n("&Dock"),"tool_dock", 0, this,SLOT(slotRequestDelay()), this, "dockIndividual");
 
     // setup individual transfer dialog
     dlgIndividual = new DlgIndividual(this);
@@ -157,17 +158,26 @@ Transfer::init()
 }
 
 
-void Transfer::tryKillSlave()
+void Transfer::synchronousAbort()
 {
-    // ###
-    // should we terminate() the slave and delete them all?
-    // which slaves keep running even tho the transfer has finished?
-    // needs some more investigation
-    if ( m_pSlave && !m_pSlave->running() )
+    if ( m_pSlave )
     {
+        if ( m_pSlave->running() )
+        {
+            m_pSlave->Op(Slave::KILL);
+            m_pSlave->wait();
+        }
+
+        if ( m_pSlave->running() )
+            m_pSlave->terminate();
+
         delete m_pSlave;
         m_pSlave = 0L;
+
+        status = ST_STOPPED;
+        slotUpdateActions();
     }
+
 }
 
 void Transfer::copy(Transfer * _orig)
@@ -187,16 +197,16 @@ void Transfer::copy(Transfer * _orig)
     remainingTime = _orig->remainingTime;
     retryCount = _orig->retryCount;
     speed = _orig->speed;
-    src = _orig->src;
     startTime = _orig->startTime;
     status = _orig->status;
     totalSize = _orig->totalSize;
-    
+
     updateAll();
+    slotUpdateActions();
 
     if ( _orig->isVisible() )
         showIndividual();
-        
+
     sDebugOut << endl;
 }
 
@@ -441,10 +451,10 @@ void Transfer::slotRequestRemove()
         file.setFileName( dest.fileName() + ".part" ); // ### get it from the job?
         if ( KIO::NetAccess::exists( file ) ) // don't pollute user with warnings
         {
-            KIO::NetAccess::del( file ); // ### messagebox on failure?
+            SafeDelete::deleteFile( file ); // ### messagebox on failure?
         }
     }
-    if (status == ST_RUNNING) 
+    if (status == ST_RUNNING)
         m_pSlave->Op(Slave::REMOVE);
     else
         emit statusChanged(this, OP_REMOVED);
@@ -807,12 +817,10 @@ void Transfer::slotExecAbort(const QString & _msg)
     emit statusChanged(this, OP_ABORTED);
 }
 
-/** No descriptions */
 void Transfer::slotExecRemove()
 {
     sDebugIn << endl;
 
-    //m_pFTP.wait();
     m_pSlave->wait();
     emit statusChanged(this, OP_REMOVED);
     sDebugOut << endl;
@@ -891,7 +899,7 @@ void Transfer::slotStartTime(const QDateTime & _startTime)
 }
 
 /** return true if the dlgIndividual is Visible */
-bool Transfer::isVisible()
+bool Transfer::isVisible() const
 {
     return dlgIndividual->isVisible();
 }
