@@ -18,8 +18,11 @@ int main(int argc, char **argv)
 {
 	// about data
 	KAboutData aboutData("kit", I18N_NOOP("Kit"), KIT_VER_NUM,
-	                     I18N_NOOP("AOL Instant Messenger Client"), KAboutData::License_LGPL, 0,
-	                     "http://kitclient.sourceforge.net/", "neil@qualityassistant.com");
+	                     I18N_NOOP("AOL Instant Messenger Client"),
+	                     KAboutData::License_LGPL,
+	                     "Copyright (C) 1999, 2002 Neil Stevens",
+	                     0, "http://www.freekde.org/neil/kit/");
+
 	aboutData.addAuthor("Neil Stevens", I18N_NOOP("Original author"), "neil@qualityassistant.com");
 	aboutData.addCredit("Benjamin Meyer", I18N_NOOP("Password Changing"));
 
