@@ -502,7 +502,7 @@ void TAim::updateIdleness(void)
 void TAim::tocSignon(const QString &auth_host, const QString &auth_port)
 {
 	QString data;
-	data.sprintf("toc_signon %s %s  %s %s %s \"TIK:\\$Revision: 1.23 $\"",
+	data.sprintf("toc_signon %s %s  %s %s %s \"TIK:\\$Revision: 1.23.2.1 $\"",
 	             auth_host.latin1(), auth_port.latin1(),
 	             (tocNormalize(username)).latin1(), r_password.latin1(), TOC_LANG);
 
@@ -667,12 +667,12 @@ void TAim::doUpdate(const QString &data)
 			if(buddy.status)
 			{
 				message = i18n("%1 is online.").arg(buddy.name);
-				KNotifyClient::event("Buddy Online", message);
+				KNotifyClient::event( 0, "Buddy Online", message);
 			}
 			else
 			{
 				message = i18n("%1 is offline.").arg(buddy.name);
-				KNotifyClient::event("Buddy Offline", message);
+				KNotifyClient::event( 0, "Buddy Offline", message);
 			}
 		}
 		currentConfig.buddyList.setStatus(currentNum, buddy.status);
