@@ -1,6 +1,7 @@
-/*
+/*   -*- c++ -*-
  *   kmail: KDE mail client
  *   This file: Copyright (C) 2000 Espen Sand, espen@kde.org
+ *              Copyright (C) 2001-2002 Marc Mutz <mutz@kde.org>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,17 +23,12 @@
 #define _CONFIGURE_DIALOG_H_
 
 #include <kdialogbase.h>
+#include <qptrlist.h>
 
 class QWidget;
 class KConfig;
 
-class IdentityPage;
-class NetworkPage;
-class AppearancePage;
-class ComposerPage;
-class SecurityPage;
-class MiscPage;
-class PluginPage;
+class ConfigurationPage;
 
 class ConfigureDialog : public KDialogBase
 {
@@ -65,13 +61,8 @@ class ConfigureDialog : public KDialogBase
     void apply(bool);
 
   protected:
-    IdentityPage   *mIdentityPage;
-    NetworkPage    *mNetworkPage;
-    AppearancePage *mAppearancePage;
-    ComposerPage   *mComposerPage;
-    SecurityPage   *mSecurityPage;
-    MiscPage       *mMiscPage;
-    PluginPage     *mPluginPage;
+    QPtrList<ConfigurationPage> mPages;
+    ConfigurationPage * mPageWithProfiles;
 };
 
 #endif
