@@ -1,7 +1,6 @@
 #include <kdebug.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <dcopclient.h>
-#include <klocale.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 
