@@ -8,7 +8,6 @@
 
 #include "kalarmtimer.h"
 
-class KApplication;
 class QCursor;
 
 class KBusyPtr: public KAlarmTimer
@@ -47,13 +46,14 @@ private:
   bool loadBitmap(QBitmap& bitmap, const QString& fileName);
 
 protected:
-  KApplication* app;
   int busyLevel;
   int numCursors;
   int frameDelay;
   int currentCursor;
   bool animated;
   QCursor* cursorList;
+  /** avoid warning about hidden virtual */
+  virtual void timerEvent(QTimerEvent *e) { KAlarmTimer::timerEvent( e ); }
 };
 
 #endif /*kbusyptr_h_*/
