@@ -484,7 +484,7 @@ void KMAcctExpPop::slotMsgRetrieved(KIO::Job*, const QString & infoMsg)
   KMMessage *msg = new KMMessage;
   curMsgData.resize(curMsgData.size() + 1);
   curMsgData[curMsgData.size() - 1] = '\0';
-  msg->fromString(QCString(curMsgData),TRUE);
+  msg->fromString(QCString(curMsgData, curMsgData.size()),TRUE);
   if (stage == Head)
   {
     kdDebug(5006) << "Size of Message: " << (*lensOfMsgsPendingDownload.at(
@@ -532,6 +532,9 @@ void KMAcctExpPop::slotJobFinished() {
       "work properly."));
     }
 
+    // An attempt to work around buggy pop servers, these seem to be popular.
+    if (uidsOfNextSeenMsgs.isEmpty())
+        uidsOfNextSeenMsgs = uidsOfSeenMsgs;
     //check if filter on server
     if (mFilterOnServer == true) {
       QStringList::Iterator hids = idsOfMsgsPendingDownload.begin();
