@@ -2,7 +2,8 @@
 #define KMAcctExpPop_h
 
 #include "kmaccount.h"
-#include <kapp.h>
+#include "kmpopheaders.h"
+#include "kmfiltermgr.h"
 #include <qdialog.h>
 #include "kio/job.h"
 #include "kio/global.h"
@@ -11,6 +12,8 @@
 #include <qcstring.h>
 #include <qtimer.h>
 
+#include <kdebug.h>
+
 class QLineEdit;
 class QPushButton;
 class DwPopClient;
@@ -69,6 +72,12 @@ public:
   QString auth(void) const { return mAuth; }
   virtual void setAuth(const QString &);
 
+  /**
+   * Sending of several commands at once
+   */
+  bool usePipelining(void) const { return mUsePipelining; }
+  virtual void setUsePipelining(bool);
+
   /**
    * Will the password be stored in the config file ?
    */
@@ -100,28 +109,35 @@ public:
   bool leaveOnServer(void) const { return mLeaveOnServer; }
   virtual void setLeaveOnServer(bool);
 
+  /**
+   * Shall messages be filter on the server (TRUE)
+   * or not (FALSE).
+   */
+  bool filterOnServer(void) const { return mFilterOnServer; }
+  virtual void setFilterOnServer(bool);
+
+  /**
+   * Size of messages which should be check on the
+   * pop server before download
+   */
+  unsigned int filterOnServerCheckSize(void) const { return mFilterOnServerCheckSize; }
+  virtual void setFilterOnServerCheckSize(unsigned int);
+
   /**
    * Inherited methods.
    */
-  virtual const char* type(void) const;
+  virtual QString type(void) const;
   virtual void readConfig(KConfig&);
   virtual void writeConfig(KConfig&);
   virtual void processNewMail(bool _interactive);
   virtual void pseudoAssign(KMAccount*);
 
 protected:
-  enum Stage { Idle, List, Uidl, Retr, Dele, Quit };
+  enum Stage { Idle, List, Uidl, Head, Retr, Dele, Quit };
   friend class KMAcctMgr;
   friend class KMPasswdDialog;
   KMAcctExpPop(KMAcctMgr* owner, const QString& accountName);
 
-  /**
-   * Very primitive en/de-cryption so that the password is not
-   * readable in the config file. But still very easy breakable.
-   */
-  QString encryptStr(const QString& inStr) const;
-  QString decryptStr(const QString& inStr) const;
-
   /**
    * Start a KIO Job to get a list of messages on the pop server
    */
@@ -150,22 +166,34 @@ protected:
   bool    mUseSSL;
   bool    mUseTLS;
   QString mAuth;
+  bool    mUsePipelining;
   bool    mStorePasswd;
+  bool    mAskAgain;
   bool    mLeaveOnServer;
   bool    gotMsgs;
+  bool    mFilterOnServer;
+  unsigned int mFilterOnServerCheckSize;
 
   KIO::SimpleJob *job;
   KIO::Slave *slave;
   KIO::MetaData mSlaveConfig;
-  QStringList idsOfMsgsPendingDownload;
-  QValueList<int> lensOfMsgsPendingDownload;
+  QStringList idsOfMsgsPendingDownload; //ID of messages which should be downloaded
+  QValueList<int> lensOfMsgsPendingDownload; //length of messages which should be downloaded
 
-  QStringList idsOfMsgs;
+  QPtrList<KMPopHeaders> headersOnServer;
+  QPtrListIterator<KMPopHeaders> headerIt;
+  bool headers;
+  QStringList headerDeleteUids;
+  QStringList headerDownUids;
+  QStringList headerLaterUids;
+
+
+  QStringList idsOfMsgs; //used for ids and for count
   QValueList<int> lensOfMsgs;
   QStringList uidsOfMsgs;
-  QStringList uidsOfSeenMsgs;
-  QStringList uidsOfNextSeenMsgs;
-  KURL::List idsOfMsgsToDelete;
+  QStringList uidsOfSeenMsgs; //UIDS of seen messages, saved in config
+  QStringList uidsOfNextSeenMsgs; //UIDS of new seen messages, for writing in the config file
+  QStringList idsOfMsgsToDelete;
   int indexOfCurrentMsg;
 
   QValueList<KMMessage*> msgsAwaitingProcessing;
@@ -205,6 +233,12 @@ protected slots:
    */
   void slotGetNextMsg();
 
+  /**
+   * A messages has been retrieved successfully. The next data belongs to the
+   * next message.
+   */
+  void slotMsgRetrieved(KIO::Job*, const QString &);
+
   /**
    * New data has arrived append it to the end of the current message
    */
@@ -237,30 +271,14 @@ protected slots:
    * Slave error handling
    */
   void slotSlaveError(KIO::Slave *, int, const QString &);
+
+  /**
+   * If there are more headers to be downloaded then start a new kio job
+   * to get the next header
+   */
+  void slotGetNextHdr();
 };
 
 
-//-----------------------------------------------------------------------------
-class KMExpPasswdDialog : public QDialog
-{
-  Q_OBJECT
 
-public:
-  KMExpPasswdDialog(QWidget *parent = 0,const char *name= 0,
-	  	    KMAcctExpPop *act=0, const QString &caption=QString::null,
-		    const QString &login=QString::null,
-                    const QString &passwd=QString::null);
-
-private:
-  QLineEdit *usernameLEdit;
-  QLineEdit *passwdLEdit;
-  QPushButton *ok;
-  QPushButton *cancel;
-  KMAcctExpPop *act;
-
-private slots:
-  void slotOkPressed();
-  void slotCancelPressed();
-
-};
 #endif /*KMAcctExpPop_h*/
