@@ -27,6 +27,7 @@
 #include "kmfoldertree.h"
 #include "kmfoldermgr.h"
 #include "kmfiltermgr.h"
+#include "kmacctmgr.h"
 
 #include <kmfolderimap.h>
 #include <kio/passdlg.h>
@@ -63,6 +64,8 @@ KMAcctImap::KMAcctImap(KMAcctMgr* aOwner, const QString& aAccountName):
   KIO::Scheduler::connect(
     SIGNAL(slaveError(KIO::Slave *, int, const QString &)),
     this, SLOT(slotSlaveError(KIO::Slave *, int, const QString &)));
+  connect(kernel->imapFolderMgr(), SIGNAL(changed()),
+      this, SLOT(slotUpdateFolderList()));
 }
 
 
@@ -391,7 +394,7 @@ void KMAcctImap::slotSlaveError(KIO::Slave *aSlave, int errorCode,
   if ( !errorDialogIsActive )
   {
     errorDialogIsActive = true;
-    if ( KMessageBox::messageBox(kernel->mainWin(), KMessageBox::Error,
+    if ( KMessageBox::messageBox(kernel->mainWin(false), KMessageBox::Error,
           KIO::buildErrorString(errorCode, errorMsg),
           i18n("Error")) == KMessageBox::Ok )
     {
@@ -545,6 +548,30 @@ void KMAcctImap::slotSimpleResult(KIO::Job * job)
 }
 
 
+//-----------------------------------------------------------------------------
+void KMAcctImap::slotUpdateFolderList()
+{
+  if (mFolder && mFolder->child())
+  {
+    QStringList strList;
+    mMailCheckFolders.clear();
+    kernel->imapFolderMgr()->createFolderList(&strList, &mMailCheckFolders,
+        mFolder->child(), QString::null, false);
+  }
+}
+
+//-----------------------------------------------------------------------------
+void KMAcctImap::processNewMailSingleFolder(KMFolderImap* folder)
+{
+  QValueList<QGuardedPtr<KMFolder> > mSaveList = mMailCheckFolders;
+  mMailCheckFolders.clear();
+  mMailCheckFolders.append(folder);
+  
+  kernel->acctMgr()->singleCheckMail(this, true);
+
+  mMailCheckFolders = mSaveList;
+}
+
 //-----------------------------------------------------------------------------
 void KMAcctImap::processNewMail(bool interactive)
 {
@@ -556,15 +583,18 @@ void KMAcctImap::processNewMail(bool interactive)
     emit finishedCheck(false);
     return;
   }
-  QStringList strList;
-  QValueList<QGuardedPtr<KMFolder> > folderList;
-  kernel->imapFolderMgr()->createFolderList(&strList, &folderList,
-    mFolder->child(), QString::null, false);
+  // if necessary then initialize the list of folders which should be checked
+  if( mMailCheckFolders.isEmpty() ) {
+    slotUpdateFolderList();
+    // if no folders should be checked then the check is finished
+    if( mMailCheckFolders.isEmpty() )
+      emit finishedCheck(false);
+  }
   QValueList<QGuardedPtr<KMFolder> >::Iterator it;
   // first get the current count of unread-messages
   mCountRemainChecks = 0;
   mCountLastUnread = 0;
-  for (it = folderList.begin(); it != folderList.end(); it++)
+  for (it = mMailCheckFolders.begin(); it != mMailCheckFolders.end(); it++)
   {
     KMFolder *folder = *it;
     if (folder && !folder->noContent())
@@ -573,7 +603,7 @@ void KMAcctImap::processNewMail(bool interactive)
     }
   }
   // then check for new mails
-  for (it = folderList.begin(); it != folderList.end(); it++)
+  for (it = mMailCheckFolders.begin(); it != mMailCheckFolders.end(); it++)
   {
     KMFolder *folder = *it;
     if (folder && !folder->noContent())
