@@ -3,17 +3,24 @@
 // based on work by Stefan Taferner <taferner@kde.org>
 // This code is under the GPL
 
+#include <config.h>
 #include "kmfilterdlg.h"
+
+// other KMail headers:
 #include "kmsearchpatternedit.h"
 #include "kmfiltermgr.h"
-//Tudo
 
+// other KDE headers:
+#include <kdeversion.h>
+#include <kmessagebox.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <klineeditdlg.h>
 #include <kiconloader.h>
 #include <kapplication.h>
+#include <kwin.h>
 
+// other Qt headers:
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qcombobox.h>
@@ -21,10 +28,12 @@
 #include <qtooltip.h>
 #include <qwhatsthis.h>
 #include <qcheckbox.h>
-
-#include <assert.h>
 #include <qpushbutton.h>
 
+// other headers:
+#include <assert.h>
+
+
 // What's this help texts
 const char * _wt_filterlist =
 I18N_NOOP( "<qt><p>This is the list of defined filters. "
@@ -34,17 +43,17 @@ I18N_NOOP( "<qt><p>This is the list of defined filters. "
 	   "of the dialog.</p></qt>" );
 const char * _wt_filterlist_new =
 I18N_NOOP( "<qt><p>Click this button to create a new filter.</p>"
-	   "<p>It will be inserted just before the currently "
+	   "<p>The filter will be inserted just before the currently "
 	   "selected one, but you can always change that "
 	   "later on.</p>"
-	   "<p>If you have hit this button accidently, you can undo this "
-	   "by clicking on the <em>delete</em> button (to the right).</p></qt>" );
+	   "<p>If you have clicked this button accidentally, you can undo this "
+	   "by clicking on the <em>Delete</em> button (to the right).</p></qt>" );
 const char * _wt_filterlist_delete =
 I18N_NOOP( "<qt><p>Click this button to <em>delete</em> the currently "
 	   "selected filter from the list above.</p>"
-	   "<p>There's no way to get the filter back once "
+	   "<p>There is no way to get the filter back once "
 	   "it is deleted, but you can always leave the "
-	   "dialog through <em>Cancel</em> to discard the "
+	   "dialog by clicking <em>Cancel</em> to discard the "
 	   "changes made.</p></qt>" );
 const char * _wt_filterlist_up =
 I18N_NOOP( "<qt><p>Click this button to move the currently "
@@ -52,29 +61,29 @@ I18N_NOOP( "<qt><p>Click this button to move the currently "
 	   "<p>This is useful since the order of the filters in the list "
 	   "determines the order in which they are tried on messages: "
 	   "The topmost filter gets tried first.</p>"
-	   "<p>If you have hit this button accidently, you can undo this "
-	   "by clicking on the <em>down</em> button (to the right)</p></qt>" );
+	   "<p>If you have clicked this button accidentally, you can undo this "
+	   "by clicking on the <em>down</em> button (to the right).</p></qt>" );
 const char * _wt_filterlist_down =
 I18N_NOOP( "<qt><p>Click this button to move the currently "
 	   "selected filter <em>down</em> one in the list above.</p>"
 	   "<p>This is useful since the order of the filters in the list "
 	   "determines the order in which they are tried on messages: "
 	   "The topmost filter gets tried first.</p>"
-	   "<p>If you have hit this button accidently, you can undo this "
+	   "<p>If you have clicked this button accidentally, you can undo this "
 	   "by clicking on the <em>up</em> button (to the left)</p></qt>" );
 const char * _wt_filterlist_rename =
 I18N_NOOP( "<qt><p>Click this button to rename the currently selected filter.</p>"
 	   "<p>Filters are named automatically, as long as they start with "
 	   "\"<<\".</p>"
-	   "<p>If you have renamed a filter accidently and want automatic "
-	   "naming back, click this button and select <em>Clear</em> and "
-	   "then <em>OK</em> in the appearing dialog.</p></qt>" );
+	   "<p>If you have renamed a filter accidentally and want automatic "
+	   "naming back, click this button and select <em>Clear</em> followed "
+	   "by <em>OK</em> in the appearing dialog.</p></qt>" );
 const char * _wt_filterdlg_showLater =
 I18N_NOOP( "<qt><p>Check this button to force the confirmation dialog to show "
 	   "up.</p><p>This is useful if you have defined a ruleset that tags "
            "messages to be downloaded later. Without the possibility to force "
            "the dialog popup, these messages could never be downloaded if no "
-           "other big messages were waiting on the server, or if you wanted to "
+           "other large messages were waiting on the server, or if you wanted to "
            "change the ruleset to tag the messages differently.</p></qt>" );
 
 // The anchor of the filter dialog's help.
@@ -94,6 +103,7 @@ KMFilterDlg::KMFilterDlg(QWidget* parent, const char* name, bool popFilter)
 		 Ok /* default btn */, FALSE /* separator */),
   bPopFilter(popFilter)
 {
+  KWin::setIcons( winId(), kapp->icon(), kapp->miniIcon() );
   setHelp( (bPopFilter)? KMPopFilterDlgHelpAnchor: KMFilterDlgHelpAnchor );
 
   QWidget *w = new QWidget(this);
@@ -147,11 +157,11 @@ KMFilterDlg::KMFilterDlg(QWidget* parent, const char* name, bool popFilter)
   }
   // spacer:
   vbl->addStretch( 1 );
-  
+
   // load the filter parts into the edit widgets
   connect( mFilterList, SIGNAL(filterSelected(KMFilter*)),
 	   this, SLOT(slotFilterSelected(KMFilter*)) );
-  
+
   if (bPopFilter){
     // set the state of the global setting 'show later msgs'
     connect( mShowLaterBtn, SIGNAL(toggled(bool)),
@@ -175,11 +185,11 @@ KMFilterDlg::KMFilterDlg(QWidget* parent, const char* name, bool popFilter)
     connect( mStopProcessingHere, SIGNAL(toggled(bool)),
 	     this, SLOT(slotStopProcessingButtonToggled(bool)) );
   }
-	
+
   // reset all widgets here
   connect( mFilterList, SIGNAL(resetWidgets()),
 	   this, SLOT(slotReset()) );
-  
+
   // support auto-naming the filter
   connect( mPatternEdit, SIGNAL(maybeNameChanged()),
 	   mFilterList, SLOT(slotUpdateFilterName()) );
@@ -198,7 +208,7 @@ KMFilterDlg::KMFilterDlg(QWidget* parent, const char* name, bool popFilter)
 
   // destruct the dialog on OK, close and Cancel
   connect( this, SIGNAL(finished()),
-	   this, SLOT(slotDelayedDestruct()) );
+	   this, SLOT(slotFinished()) );
 
   KConfigGroup geometry( kapp->config(), "Geometry");
   const char * configKey
@@ -212,6 +222,10 @@ KMFilterDlg::KMFilterDlg(QWidget* parent, const char* name, bool popFilter)
   mFilterList->loadFilterList();
 }
 
+void KMFilterDlg::slotFinished() {
+	delayedDestruct();
+}
+
 void KMFilterDlg::slotSaveSize() {
   KConfigGroup geometry( kapp->config(), "Geometry" );
   geometry.writeEntry( bPopFilter ? "popFilterDialogSize" : "filterDialogSize", size() );
@@ -226,7 +240,7 @@ void KMFilterDlg::slotActionChanged(const KMPopFilterAction aAction)
 void KMFilterDlg::slotFilterSelected( KMFilter* aFilter )
 {
   assert( aFilter );
-  
+
   if (bPopFilter){
     mActionGroup->setAction( aFilter->action() );
     mGlobalsBox->setEnabled(true);
@@ -255,7 +269,7 @@ void KMFilterDlg::slotFilterSelected( KMFilter* aFilter )
     bool applyOnOut = aFilter->applyOnOutbound();
     bool applyOnExplicit = aFilter->applyOnExplicit();
     bool stopHere = aFilter->stopProcessingHere();
-    
+
     mApplyOnIn->setChecked( applyOnIn );
     mApplyOnOut->setChecked( applyOnOut );
     mApplyOnCtrlJ->setChecked( applyOnExplicit );
@@ -267,7 +281,7 @@ void KMFilterDlg::slotReset()
 {
   mFilter = 0;
   mPatternEdit->reset();
-  
+
   if(bPopFilter) {
     mActionGroup->reset();
     mGlobalsBox->setEnabled( false );
@@ -317,14 +331,16 @@ KMFilterListBox::KMFilterListBox( const QString & title, QWidget *parent, const
   mListBox = new QListBox(this);
   mListBox->setMinimumWidth(150);
   QWhatsThis::add( mListBox, i18n(_wt_filterlist) );
-  
+
   //----------- the first row of buttons
   QHBox *hb = new QHBox(this);
   hb->setSpacing(4);
   mBtnUp = new QPushButton( QString::null, hb );
+  mBtnUp->setAutoRepeat( true );
   mBtnUp->setPixmap( BarIcon( "up", KIcon::SizeSmall ) );
   mBtnUp->setMinimumSize( mBtnUp->sizeHint() * 1.2 );
   mBtnDown = new QPushButton( QString::null, hb );
+  mBtnDown->setAutoRepeat( true );
   mBtnDown->setPixmap( BarIcon( "down", KIcon::SizeSmall ) );
   mBtnDown->setMinimumSize( mBtnDown->sizeHint() * 1.2 );
   QToolTip::add( mBtnUp, i18n("Up") );
@@ -374,11 +390,11 @@ void KMFilterListBox::createFilter( const QCString & field,
 {
   KMSearchRule *newRule = new KMSearchRule();
   newRule->init( field, KMSearchRule::FuncContains, value );
-  
+
   KMFilter *newFilter = new KMFilter(0, bPopFilter);
   newFilter->pattern()->append( newRule );
   newFilter->pattern()->setName( QString("<%1>:%2").arg( field ).arg( value) );
-  
+
   KMFilterActionDesc *desc = (*kernel->filterActionDict())["transfer"];
   if ( desc )
     newFilter->actions()->append( desc->create() );
@@ -399,7 +415,7 @@ void KMFilterListBox::slotUpdateFilterName()
 
   QString shouldBeName = p->name();
   QString displayedName = mListBox->text( mIdxSelItem );
-  
+
   if ( shouldBeName.stripWhiteSpace().isEmpty() || shouldBeName[0] == '<' ) {
     // auto-naming of patterns
     if ( p->first() && !p->first()->field().stripWhiteSpace().isEmpty() )
@@ -445,24 +461,43 @@ void KMFilterListBox::slotApplyFilterChanges()
   fm->beginUpdate();
   fm->clear();
 
+  QStringList emptyFilters;
   QPtrListIterator<KMFilter> it( mFilterList );
   for ( it.toFirst() ; it.current() ; ++it ) {
-    KMFilter *f = new KMFilter( (*it) ); // deep copy
+    KMFilter *f = new KMFilter( **it ); // deep copy
     f->purify();
     if ( !f->isEmpty() )
       // the filter is valid:
       fm->append( f );
-    else
+    else {
       // the filter is invalid:
+      emptyFilters << f->name();
       delete f;
+    }
   }
   if (bPopFilter)
     fm->setShowLaterMsgs(mShowLater);
-  
+
   // allow usage of the filters again.
   fm->endUpdate();
   fm->writeConfig();
 
+  // report on invalid filters:
+  if ( !emptyFilters.empty() ) {
+#if KDE_VERSION < 306
+    QString msg = i18n("Some filters have not been saved because they were "
+		       "invalid (e.g. containing no actions or no search "
+		       "rules).");
+    KMessageBox::information( 0, msg, QString::null, "ShowInvalidFilterWarning" );
+#else
+    QString msg = i18n("The following filters have not been saved because they "
+		       "were invalid (e.g. containing no actions or no search "
+		       "rules).");
+    KMessageBox::informationList( 0, msg, emptyFilters, QString::null,
+				  "ShowInvalidFilterWarning" );
+#endif
+  }
+
   if ( oIdxSelItem >= 0 ) {
     mIdxSelItem = oIdxSelItem;
     mListBox->setSelected( oIdxSelItem, TRUE);
@@ -473,7 +508,7 @@ void KMFilterListBox::slotApplyFilterChanges()
 void KMFilterListBox::slotSelected( int aIdx )
 {
   mIdxSelItem = aIdx;
-  // QPtrList::at(i) will return NULL if i is out of range.
+  // QPtrList::at(i) will return 0 if i is out of range.
   KMFilter *f = mFilterList.at(aIdx);
   if ( f )
     emit filterSelected( f );
@@ -495,7 +530,7 @@ void KMFilterListBox::slotDelete()
     kdDebug(5006) << "KMFilterListBox::slotDelete called while no filter is selected, ignoring." << endl;
     return;
   }
-  
+
   int oIdxSelItem = mIdxSelItem;
   mIdxSelItem = -1;
   // unselect all
@@ -548,7 +583,7 @@ void KMFilterListBox::slotDown()
     kdDebug(5006) << "KMFilterListBox::slotDown called while the _last_ filter is selected, ignoring." << endl;
     return;
   }
-  
+
   swapNeighbouringFilters( mIdxSelItem, mIdxSelItem + 1);
   enableControls();
 }
@@ -626,7 +661,7 @@ void KMFilterListBox::loadFilterList()
 
   QPtrListIterator<KMFilter> it( *manager );
   for ( it.toFirst() ; it.current() ; ++it ) {
-    mFilterList.append( new KMFilter( *it ) ); // deep copy
+    mFilterList.append( new KMFilter( **it ) ); // deep copy
     mListBox->insertItem( (*it)->pattern()->name() );
   }
 
@@ -706,7 +741,7 @@ KMFilterActionWidget::KMFilterActionWidget( QWidget *parent, const char* name )
   assert( mWidgetStack );
 
   setSpacing( 4 );
-  
+
   QPtrListIterator<KMFilterActionDesc> it ( kernel->filterActionDict()->list() );
   for ( i=0, it.toFirst() ; it.current() ; ++it, ++i ) {
     //create an instance:
@@ -721,7 +756,7 @@ KMFilterActionWidget::KMFilterActionWidget( QWidget *parent, const char* name )
   // widget for the case where no action is selected.
   mWidgetStack->addWidget( new QLabel( i18n("Please select an action."), mWidgetStack ), i );
   mWidgetStack->raiseWidget(i);
-  mComboBox->insertItem( " " ); 
+  mComboBox->insertItem( " " );
   mComboBox->setCurrentItem(i);
 
   // don't show scroll bars.
@@ -749,7 +784,7 @@ void KMFilterActionWidget::setAction( const KMFilterAction* aAction )
 
   // find the index of typeOf(aAction) in mComboBox
   // and clear the other widgets on the way.
-  for ( ; i < count ; i++ ) 
+  for ( ; i < count ; i++ )
     if ( aAction && mComboBox->text(i) == label ) {
       //...set the parameter widget to the settings
       // of aAction...
@@ -782,7 +817,7 @@ KMFilterAction * KMFilterActionWidget::action()
       return fa;
     }
   }
-  
+
   return 0;
 }
 
@@ -871,7 +906,7 @@ void KMFilterActionWidgetLister::regenerateActionListFromWidgets()
     if ( a )
       mActionList->append( a );
   }
-    
+
 }
 
 //=============================================================================
