@@ -351,7 +351,7 @@ void KMFldSearch::searchInFolder(QGuardedPtr<KMFolder> aFld, bool recursive,
     if (found)
     {
       QString from;
-      if(aFld->type() == KFolderTreeItem::SentMail)
+      if(strcmp(aFld->type(), "out")==0)
         from = msg->to();
       else
         from = msg->from();
