@@ -6,6 +6,7 @@
 #define kmfldsearch_h
 
 #include <qvaluelist.h>
+#include <qptrlist.h>
 #include <qstringlist.h>
 #include <qguardedptr.h>
 
@@ -30,13 +31,16 @@ class KMMainWin;
 class KMMessage;
 class KStatusBar;
 
+typedef QPtrList<KMFldSearchRule> KMFldSearchRuleList;
+typedef QPtrListIterator<KMFldSearchRule> KMFldSearchRuleIt;
+
 class KMFldSearch: public KDialogBase
 {
   Q_OBJECT
 
 public:
-  KMFldSearch(KMMainWin* parent, const char* name=NULL,
-              KMFolder *curFolder=NULL, bool modal=FALSE);
+  KMFldSearch(KMMainWin* parent, const char* name=0,
+              KMFolder *curFolder=0, bool modal=FALSE);
   virtual ~KMFldSearch();
 
   void activateFolder(KMFolder* curFolder);
@@ -48,8 +52,6 @@ protected slots:
   virtual bool slotShowMsg(QListViewItem *);
   virtual void slotFolderActivated(int nr);
   virtual void slotFolderComplete(KMFolderImap *folder, bool success);
-  virtual void slotSearchAllFolders(bool on);
-  virtual void slotSearchSpecificFolder(bool on);
 
 protected:
   void enableGUI();
@@ -58,7 +60,7 @@ protected:
   virtual bool searchInMessage(KMMessage*, const QCString&);
 
   /** Search for matches in given folder. Adds matches to listbox mLbxMatches. */
-  virtual void searchInFolder(QGuardedPtr<KMFolder>, bool recursive = true,
+  virtual void searchInFolder(QGuardedPtr<KMFolder>, bool recursive,
     bool fetchHeaders = true);
 
   /** Search for matches in all folders. Calls searchInFolder() for every
@@ -81,18 +83,14 @@ protected:
   virtual void closeEvent(QCloseEvent*);
 
 protected:
-  bool mSearchAllFolders;
   bool mSearching;
   bool mStopped;
   bool mCloseRequested;
   int mFetchingInProgress;
-  int mNumRules;
   int mNumMatches;
   int mCount;
   QString mSearchFolder;
-
-  // Ours to delete
-  KMFldSearchRule **mRules;
+  KMFldSearchRuleList mRules;
 
   // GC'd by Qt
   QGridLayout* mGrid;
@@ -109,7 +107,6 @@ protected:
   // not owned by us
   KMMainWin* mMainWin;
   
-  static const int FOLDER_COLUMN;
   static const int MSGID_COLUMN;
 };
 
