@@ -276,10 +276,19 @@ int KMFolder::writeIndex()
     if(fwrite(buffer, len, 1, tmpIndexStream) != 1)
 	kdDebug(5006) << "Whoa! " << __FILE__ << ":" << __LINE__ << endl;
   }
-  if (ferror(tmpIndexStream)) return ferror(tmpIndexStream);
-  if (fflush(tmpIndexStream) != 0) return errno;
-  if (fsync(fileno(tmpIndexStream)) != 0) return errno;
-  if (fclose(tmpIndexStream) != 0) return errno;
+  int fError = ferror( tmpIndexStream );
+  if( fError != 0 ) {
+    fclose( tmpIndexStream );
+    return fError;
+  }
+  if(    ( fflush( tmpIndexStream ) != 0 )
+      || ( fsync( fileno( tmpIndexStream ) ) != 0 ) ) {
+    int errNo = errno;
+    fclose( tmpIndexStream );
+    return errNo;
+  }
+  if( fclose( tmpIndexStream ) != 0 )
+    return errno;
 
   _rename(tempName.local8Bit(), indexLocation().local8Bit());
   if (mIndexStream)
@@ -757,6 +766,8 @@ bool KMFolder::canAddMsgNow(KMMessage* aMsg, int* aIndex_ret)
 //-----------------------------------------------------------------------------
 void KMFolder::reallyAddMsg(KMMessage* aMsg)
 {
+  if (!aMsg)
+    return;
   aMsg->setTransferInProgress(FALSE);
   KMFolder *folder = aMsg->parent();
   int index;
@@ -1014,59 +1025,75 @@ int KMFolder::find(const QString& msgIdMD5) const
 
 
 //-----------------------------------------------------------------------------
-int KMFolder::rename(const QString& aName, KMFolderDir *aParent)
+int KMFolder::rename(const QString& newName, KMFolderDir *newParent)
 {
-  QString oldLoc, oldIndexLoc, newLoc, newIndexLoc;
+  QString oldLoc, oldIndexLoc, oldIdsLoc, newLoc, newIndexLoc, newIdsLoc;
   QString oldSubDirLoc, newSubDirLoc;
   QString oldName;
   int rc=0, openCount=mOpenCount;
   KMFolderDir *oldParent;
 
-  assert(!aName.isEmpty());
+  assert(!newName.isEmpty());
 
   oldLoc = location();
   oldIndexLoc = indexLocation();
   oldSubDirLoc = subdirLocation();
+  if (kernel->msgDict())
+    oldIdsLoc = kernel->msgDict()->getFolderIdsLocation(this);
 
   close(TRUE);
 
   oldName = fileName();
   oldParent = parent();
-  if (aParent)
-    setParent( aParent );
+  if (newParent)
+    setParent( newParent );
 
-  setName(aName);
+  setName(newName);
   newLoc = location();
   newIndexLoc = indexLocation();
   newSubDirLoc = subdirLocation();
+  if (kernel->msgDict())
+    newIdsLoc = kernel->msgDict()->getFolderIdsLocation(this);
 
   if (_rename(oldLoc.local8Bit(), newLoc.local8Bit())) {
     setName(oldName);
     setParent(oldParent);
     rc = errno;
   }
-  else if (!oldIndexLoc.isEmpty()) {
-    _rename(oldIndexLoc.local8Bit(), newIndexLoc.local8Bit());
-    if (!_rename(oldSubDirLoc.local8Bit(), newSubDirLoc.local8Bit() )) {
-      KMFolderDir* fdir = parent();
-      KMFolderNode* fN;
-
-      for (fN = fdir->first(); fN != 0; fN = fdir->next())
-	if (fN->name() == "." + oldName + ".directory" ) {
-	  fN->setName( "." + fileName().local8Bit() + ".directory" );
-	  break;
-	}
+  else {
+    // rename/move index file and index.sorted file
+    if (!oldIndexLoc.isEmpty()) {
+      _rename(oldIndexLoc.local8Bit(), newIndexLoc.local8Bit());
+      _rename(oldIndexLoc.local8Bit() + ".sorted",
+              newIndexLoc.local8Bit() + ".sorted");
     }
-  }
 
-  if (aParent) {
-    if (oldParent->findRef( this ) != -1)
-      oldParent->take();
-    aParent->inSort( this );
-    if (mChild) {
-      if (mChild->parent()->findRef( mChild ) != -1)
-	mChild->parent()->take();
-      aParent->inSort( mChild );
+    // rename/move serial number file
+    if (!oldIdsLoc.isEmpty())
+      _rename(oldIdsLoc.local8Bit(), newIdsLoc.local8Bit());
+
+    // rename/move the subfolder directory
+    if (!::rename(oldSubDirLoc.local8Bit(), newSubDirLoc.local8Bit() )) {
+      // now that the subfolder directory has been renamed and/or moved also
+      // change the name that is stored in the corresponding KMFolderNode
+      // (provide that the name actually changed)
+      if( mChild && ( oldName != newName ) ) {
+        mChild->setName( "." + newName.local8Bit() + ".directory" );
+      }
+    }
+
+    // if the folder is being moved then move it and, if necessary, also the
+    // associated subfolder directory node to the new parent 
+    if (newParent) {
+      if (oldParent->findRef( this ) != -1)
+        oldParent->take();
+      newParent->inSort( this );
+      if (mChild) {
+        if (mChild->parent()->findRef( mChild ) != -1)
+          mChild->parent()->take();
+        newParent->inSort( mChild );
+        mChild->setParent( newParent );
+      }
     }
   }
 
@@ -1438,7 +1465,8 @@ int KMFolder::appendtoMsgDict(int idx)
 void KMFolder::setStatus(int idx, KMMsgStatus status)
 {
   KMMsgBase *msg = getMsgBase(idx);
-  msg->setStatus(status, idx);
+  if( msg )
+    msg->setStatus(status, idx);
 }
 
 void KMFolder::setRDict(KMMsgDictREntry *rentry) {
