@@ -18,13 +18,16 @@
 #ifndef kmfolder_h
 #define kmfolder_h
 
+// for large file support
+#include <config.h>
+#include <sys/types.h>
 #include "kmfoldernode.h"
 #include "kmmsginfo.h"
 #include "kmmsglist.h"
 #include "kmglobal.h"
 
 #include <stdio.h>
-#include <qvector.h>
+#include <qptrvector.h>
 
 class KMMessage;
 class KMFolderDir;
@@ -47,11 +50,18 @@ class KMMsgDictREntry;
 class KMFolder: public KMFolderNode
 {
   Q_OBJECT
-    friend class KMMsgBase;
+  friend class KMMsgBase;
   friend class KMMessage;
 
 public:
 
+  /** This enum indicates the status of the index file. It's returned by
+      indexStatus().
+   */
+  enum IndexStatus { IndexOk,
+                     IndexMissing,
+                     IndexTooOld
+  };
 
   /** Usually a parent is given. But in some cases there is no
     fitting parent object available. Then the name of the folder
@@ -107,7 +117,8 @@ public:
     in the index. Whenever you only need subject, from, date, status
     you should use this method instead of getMsg() because getMsg()
     will load the message if necessary and this method does not. */
-  virtual KMMsgBase* getMsgBase(int idx) const { return mMsgList[idx]; }
+  virtual const KMMsgBase* getMsgBase(int idx) const { return mMsgList[idx]; }
+  virtual KMMsgBase* getMsgBase(int idx) { return mMsgList[idx]; }
 
   /** Same as getMsgBase(int). */
   const KMMsgBase* operator[](int idx) const { return mMsgList[idx]; }
@@ -126,7 +137,7 @@ public:
     is stored in index_return if given.
     Please note that the message is added as is to the folder and the folder
     takes ownership of the message (deleting it in the destructor).*/
-  virtual int addMsg(KMMessage* msg, int* index_return = NULL) = 0;
+  virtual int addMsg(KMMessage* msg, int* index_return = 0) = 0;
 
   /** Returns FALSE, if the message has to be retrieved from an IMAP account
    * first. In this case this function does this and cares for the rest */
@@ -134,7 +145,7 @@ public:
 
   /** Remove (first occurance of) given message from the folder. */
   virtual void removeMsg(int i, bool imapQuiet = FALSE);
-  virtual void removeMsg(KMMsgBasePtr msg);
+  virtual void removeMsg(const KMMsgBase* msg);
   virtual void removeMsg(QPtrList<KMMessage> msgList, bool imapQuiet = FALSE);
 
   /** Delete messages in the folder that are older than days. Return the
@@ -149,17 +160,17 @@ public:
     adds it to this folder. Returns zero on success and an errno error
     code on failure. The index of the new message is stored in index_return
     if given. */
-  virtual int moveMsg(KMMessage* msg, int* index_return = NULL);
-  virtual int moveMsg(QPtrList<KMMessage>, int* index_return = NULL);
+  virtual int moveMsg(KMMessage* msg, int* index_return = 0);
+  virtual int moveMsg(QPtrList<KMMessage>, int* index_return = 0);
 
   /** Returns the index of the given message or -1 if not found. */
-  virtual int find(const KMMsgBasePtr msg) const { return mMsgList.find(msg); }
+  virtual int find(const KMMsgBase* msg) const { return mMsgList.find((KMMsgBase*)msg); }
 
   /** Returns the index of the given message or -1 if not found. */
   virtual int find(const QString& msgIdMD5) const;
 
   /** Number of messages in this folder. */
-  virtual int count() const { return mMsgList.count(); }
+  virtual int count(bool cache = false) const;
 
   /** Number of new or unread messages in this folder. */
   virtual int countUnread();
@@ -180,6 +191,10 @@ public:
     fopen call otherwise (errno). */
   virtual int open() = 0;
 
+  /** Check folder for permissions
+    Returns zero if readable and writable. */
+  virtual int canAccess() = 0;
+
   /** Close folder. If force is TRUE the files are closed even if
     others still use it (e.g. other mail reader windows). */
   virtual void close(bool force=FALSE) = 0;
@@ -265,7 +280,7 @@ public:
   virtual QCString protocol() const = 0;
 
   /** Returns TRUE if accounts are associated with this folder. */
-  bool hasAccounts() const { return (mAcctList != NULL); }
+  bool hasAccounts() const { return (mAcctList != 0); }
 
   /** Returns TRUE if this folder is associated with a mailing-list. */
   void setMailingList(bool enabled)
@@ -282,10 +297,29 @@ public:
   QString mailingListAdminAddress() const
   { return mMailingListAdminAddress; }
 
-  void setIdentity(const QString &identity)
-  { mIdentity = identity; writeConfig(); }
-  QString identity() const
-  { return mIdentity; }
+  void setIdentity(uint identity);
+  uint identity() const { return mIdentity; }
+
+  bool useCustomIcons() const { return mUseCustomIcons; }
+  void setUseCustomIcons( bool yes ) { mUseCustomIcons = yes; }
+  void setIconPaths(const QString &normal, const QString &unread)
+  { mNormalIconPath = normal; mUnreadIconPath = unread; iconsFromPath(); 
+    writeConfig(); if (mUseCustomIcons) mNeedsRepainting = true; }
+  QString normalIconPath() const 
+  { return mNormalIconPath; }
+  QString unreadIconPath() const
+  { return mUnreadIconPath; }
+  QPixmap* normalIcon() const 
+  { if ( mUseCustomIcons ) return mNormalIcon; else return 0; }
+  QPixmap* unreadIcon() const
+  { if ( mUseCustomIcons ) return mUnreadIcon; else return 0; }
+  
+  /** Tell the folder tree if repainting is required */
+  bool needsRepainting() const 
+  { return mNeedsRepainting; }
+  /** repaint has been scheduled so stop demanding it */
+  void repaintScheduled() 
+  { mNeedsRepainting = false; }
 
   /** Tell the folder that a header field that is usually used for
     the index (subject, from, ...) has changed of given message.
@@ -293,18 +327,18 @@ public:
   virtual void headerOfMsgChanged(const KMMsgBase*, int idx = -1);
 
   /** Get / set the name of the field that is used for the Sender/Receiver column in the headers (From/To) */
-  const char* whoField() const { return mWhoField.latin1(); }
+  QString whoField() const { return mWhoField; }
   void setWhoField(const QString& aWhoField) { mWhoField = aWhoField; /*writeConfig();*/ }
 
   /** Get / set the user-settings for the WhoField (From/To/Empty) */
-	QString userWhoField(void) { return mUserWhoField; }
-	void setUserWhoField(const QString &whoField);
+  QString userWhoField(void) { return mUserWhoField; }
+  void setUserWhoField(const QString &whoField);
 
   /** A cludge to help make sure the count of unread messges is kept in sync */
   virtual void correctUnreadMsgsCount();
 
   /** Returns a string that can be used to identify this folder */
-  virtual QString idString();
+  virtual QString idString() const;
 
   uchar *indexStreamBasePtr() { return mIndexStreamPtr; }
   
@@ -439,9 +473,11 @@ signals:
 
   /** Emitted when a message is removed from the folder. */
   void msgRemoved(int,QString);
+  void msgRemoved(KMFolder*);
 
   /** Emitted when a message is added from the folder. */
   void msgAdded(int);
+  void msgAdded(KMFolder*);
 
   /** Emitted when a field of the header of a specific message changed. */
   void msgHeaderChanged(int);
@@ -465,7 +501,7 @@ protected:
   /** Escape a leading dot */
   virtual QString dotEscape(const QString&) const;
 
-  /** Load message from file and store it at given index. Returns NULL
+  /** Load message from file and store it at given index. Returns 0
     on failure. */
   virtual KMMessage* readMsg(int idx) = 0;
 
@@ -473,7 +509,7 @@ protected:
   virtual bool readIndex();
 
   /** Read index header. Called from within readIndex(). */
-    virtual bool readIndexHeader(int *gv=NULL);
+    virtual bool readIndexHeader(int *gv=0);
 
   /** Create index file from messages file and fill the message-info list
       mMsgList. Returns 0 on success and an errno value (see fopen) on
@@ -482,11 +518,13 @@ protected:
 
   bool updateIndexStreamPtr(bool just_close=FALSE);
 
-  /** Tests whether the contents (file) is newer than the index. Returns
-    TRUE if the contents has changed (and the index should be recreated),
-    and FALSE otherwise. Returns TRUE if there is no index file, and
-    TRUE if there is no contents (file). */
-  virtual bool isIndexOutdated() = 0;
+  /** Tests whether the contents of this folder is newer than the index.
+      Should return IndexTooOld if the index is older than the contents.
+      Should return IndexMissing if there is contents but no index.
+      Should return IndexOk if the folder doesn't exist anymore "physically"
+      or if the index is not older than the contents.
+  */
+  virtual IndexStatus indexStatus() = 0;
 
   /** Called by KMFolder::remove() to delete the actual contents.
     At the time of the call the folder has already been closed, and
@@ -503,6 +541,9 @@ protected:
 
   /** Read the config file */
   virtual void readConfig();
+
+  /** tries to create icons from paths */
+  virtual void iconsFromPath();
   
   /** table of contents file */
   FILE* mIndexStream;
@@ -511,14 +552,14 @@ protected:
   int mOpenCount, mQuiet;
   bool mChanged;
   /** offset of header of index file */
-  unsigned long mHeaderOffset;
+  off_t mHeaderOffset;
   /** is the automatic creation of a index file allowed ? */
   bool mAutoCreateIndex;
   /** if the index is dirty it will be recreated upon close() */
   bool mDirty;
   /** TRUE if the files of the folder are locked (writable) */
   bool mFilesLocked;
-  /** nationalized label or NULL (then name() should be used) */
+  /** nationalized label or QString::null (then name() should be used) */
   QString mLabel;
   /** name of the field that is used for "From" in listbox */
   QString mWhoField, mUserWhoField;
@@ -528,10 +569,19 @@ protected:
   bool    mMailingListEnabled;
   QString mMailingListPostingAddress;
   QString mMailingListAdminAddress;
-  QString mIdentity;
+  uint    mIdentity;
 
+  /** Custom pixmaps to display in the tree, none by default */
+  QPixmap *mNormalIcon;
+  QPixmap *mUnreadIcon;
+  QString mNormalIconPath;
+  QString mUnreadIconPath;
+  bool    mUseCustomIcons;
+  bool    mNeedsRepainting;
+  
   /** number of unread messages, -1 if not yet set */
   int mUnreadMsgs, mGuessedUnreadMsgs;
+  int mTotalMsgs;
   bool mWriteConfigEnabled;
   /** sven: true if on destruct folder needs to be compacted. */
   bool needsCompact;
