@@ -166,8 +166,11 @@ KMFolderDialog::KMFolderDialog(KMFolder* aFolder, KMFolderDir *aFolderDir,
   ml->addStretch( 1 );
 
   QStringList str;
-//  if (!folder) kernel->imapFolderMgr()->createI18nFolderList( &str, &mFolders );
-  kernel->imapFolderMgr()->createI18nFolderList( &str, &mFolders );
+  // Moving local folders to IMAP servers is currently not possible.
+  // Therefore don't add IMAP folders if an existing local folder is editted.
+  if( !aFolder || ( aFolder->protocol() == "imap" ) ) {
+    kernel->imapFolderMgr()->createI18nFolderList( &str, &mFolders );
+  }
   kernel->folderMgr()->createFolderList( &str, &mFolders  );
   str.prepend( i18n( "Top Level" ));
   QGuardedPtr<KMFolder> curFolder;
@@ -459,7 +462,7 @@ void KMFolderDialog::slotOk()
     if (!nameEdit->text().isEmpty()) fldName = nameEdit->text();
     else fldName = oldFldName;
     fldName.replace(QRegExp("/"), "");
-    fldName.replace(QRegExp("^\\."), "");
+    fldName.replace(QRegExp("^\\.*"), "");
     if (fldName.isEmpty()) fldName = i18n("unnamed");
     if (curFolder != 0)
     {
