@@ -232,9 +232,12 @@ int KMFolderImap::addMsg(QPtrList<KMMessage>& msgList, int* aIndex_ret)
           // transfer the whole message, e.g. a draft-message is canceled and re-added to the drafts-folder
           for ( KMMessage* msg = msgList.first(); msg; msg = msgList.next() )
           {
-            int idx = msgParent->find(msg);
-            assert(idx != -1);
-            msg = msgParent->getMsg(idx);
+            if (!msg->isComplete())
+            {  
+              int idx = msgParent->find(msg);
+              assert(idx != -1);
+              msg = msgParent->getMsg(idx);
+            }
             imapJob = new KMImapJob(msg, KMImapJob::tPutMessage, this);
             connect(imapJob, SIGNAL(messageCopied(KMMessage*)),
                 SLOT(addMsgQuiet(KMMessage*)));
@@ -242,8 +245,7 @@ int KMFolderImap::addMsg(QPtrList<KMMessage>& msgList, int* aIndex_ret)
 
         } else {
 
-          /* get the messages and the uids
-             don't unGet the messages because we need to access the serial number in addMsgQuiet */
+          // get the uids
           QValueList<int> uids;
           getUids(msgList, uids);
 
@@ -632,6 +634,18 @@ kdDebug(5006) << "KMFolderImap::slotCheckValidityResult" << endl;
   }
 }
 
+//-----------------------------------------------------------------------------
+void KMFolderImap::getAndCheckFolder(bool force)
+{
+  if (mNoContent || kernel->checkingMail())
+    return getFolder(force);
+
+  mAccount->processNewMailSingleFolder(this);
+  if (force) {
+    // force an update
+    mCheckFlags = TRUE;
+  }
+}
 
 //-----------------------------------------------------------------------------
 void KMFolderImap::getFolder(bool force)
@@ -1249,7 +1263,7 @@ void KMImapJob::slotGetMessageResult(KIO::Job * job)
       QString uid = mMsg->headerField("X-UID");
       (*it).data.resize((*it).data.size() + 1);
       (*it).data[(*it).data.size() - 1] = '\0';
-      mMsg->fromString(QCString((*it).data));
+      mMsg->fromString(QCString((*it).data, (*it).data.size()+1));
       mMsg->setHeaderField("X-UID",uid);
       mMsg->setComplete( TRUE );
       emit messageRetrieved(mMsg);
