@@ -1,13 +1,13 @@
 // kmfolderseldlg.cpp
 
+#include <config.h>
 #include "kmfolderseldlg.h"
 #include "kmfoldertree.h"
 #include "kmmainwin.h"
 
 #include <qlistbox.h>
 #include <qlayout.h>
-#include <qaccel.h>
-#include <kbuttonbox.h>
+#include <qvbox.h>
 
 #include <assert.h>
 #include <qpushbutton.h>
@@ -15,65 +15,36 @@
 QString KMFolderSelDlg::oldSelection;
 
 //-----------------------------------------------------------------------------
-KMFolderSelDlg::KMFolderSelDlg(QWidget * parent, QString caption):
-  KMFolderSelDlgInherited(parent, 0, TRUE) // mainwin as parent, no name, but modal
+KMFolderSelDlg::KMFolderSelDlg(KMMainWin * parent, const QString& caption)
+    : KMFolderSelDlgInherited(parent, "folder dialog", true, caption,
+                              Ok|Cancel, Ok, true) // mainwin as parent, modal
 {
-  QPushButton *btnCancel, *btnOk;
-  QBoxLayout* box = new QVBoxLayout(this, 2, 0);
-  QBoxLayout* bbox = new QHBoxLayout(0);
   QGuardedPtr<KMFolder> cur;
 
-
-  setCaption(caption);
-
-  mListBox = new QListBox(this);
-  box->addWidget(mListBox, 100);
+  mListBox = new QListBox(makeVBoxMainWidget());
   connect(mListBox, SIGNAL(selected(int)), this, SLOT(slotSelect(int)));
 
-  box->addLayout(bbox, 1);
-
-  KButtonBox *butbox = new KButtonBox(this);
-  btnOk = butbox->addButton(i18n("OK"));
-  btnOk->setDefault(TRUE);
-  connect(btnOk, SIGNAL(clicked()), this, SLOT(accept()));
-
-  btnCancel = butbox->addButton(i18n("Cancel"));
-  connect(btnCancel, SIGNAL(clicked()), this, SLOT(slotCancel()));
-  butbox->layout();
-  box->addWidget(butbox);
-
-  QAccel *acc = new QAccel(this);
-  acc->connectItem(acc->insertItem(Key_Escape), this, SLOT(slotCancel()));
-
   resize(220, 300);
-  box->activate();
 
   QStringList str;
-  KMMainWin * mw = dynamic_cast<KMMainWin*>( parent );
-  assert( mw );
-  KMFolderTree * ft = mw->folderTree();
+  KMFolderTree * ft = parent->folderTree();
   assert( ft );
   ft->createFolderList( &str, &mFolder  );
   mListBox->insertStringList( str );
   int i = 0;
   while (mFolder.at(i) != mFolder.end()) {
     cur = *mFolder.at(i);
-    // cur will be NULL for accounts. Don't crash on that,
+    // cur will be 0 for accounts. Don't crash on that,
     // but ignore them for now.
     if(!cur)
       mListBox->item(i)->setSelectable(false);
-    else if (!oldSelection.isNull() && oldSelection == cur->label())
+    else if (!oldSelection.isNull() && oldSelection == cur->idString())
       mListBox->setCurrentItem(i);
     ++i;
   }
 
-  // make sure item is visible
-  if(mListBox->currentItem() != -1)
-  {
-    unsigned idx = 0;
-    while(mListBox->numItemsVisible()-2 + mListBox->topItem() < mListBox->currentItem() && idx < mListBox->count())
-	  mListBox->setTopItem(idx++);
-  }
+  // make sure that the current item is visible
+  mListBox->centerCurrentItem();
 
   mListBox->setFocus();
 }
@@ -82,6 +53,11 @@ KMFolderSelDlg::KMFolderSelDlg(QWidget * parent, QString caption):
 //-----------------------------------------------------------------------------
 KMFolderSelDlg::~KMFolderSelDlg()
 {
+  if(mListBox->currentItem() != -1) {
+    QGuardedPtr<KMFolder> cur = *mFolder.at(mListBox->currentItem());
+    if( cur )
+      oldSelection = cur->idString();
+  }
 }
 
 
@@ -90,7 +66,7 @@ KMFolder* KMFolderSelDlg::folder(void)
 {
   int idx = mListBox->currentItem();
 
-  if (idx < 0) return NULL;
+  if (idx < 0) return 0;
   return *mFolder.at(idx);
 }
 
@@ -98,8 +74,6 @@ KMFolder* KMFolderSelDlg::folder(void)
 //-----------------------------------------------------------------------------
 void KMFolderSelDlg::slotSelect(int)
 {
-  if(mListBox->currentItem() != -1)
-    oldSelection = mListBox->text(mListBox->currentItem());
   accept();
 }
 
@@ -108,8 +82,6 @@ void KMFolderSelDlg::slotSelect(int)
 void KMFolderSelDlg::slotCancel()
 {
   disconnect(mListBox, SIGNAL(selected(int)), this, SLOT(slotSelect(int)));
-  if(mListBox->currentItem() != -1)
-    oldSelection = mListBox->text(mListBox->currentItem());
   reject();
 }
 
