@@ -100,9 +100,6 @@ KMFolderTree::KMFolderTree( QWidget *parent,
   int namecol = addColumn( i18n("Folder"), 250 );
   header()->setStretchEnabled( true, namecol );
 
-  // connect
-  connectSignals();
-
   // popup to switch columns
   header()->setClickEnabled(true);
   header()->installEventFilter(this);
@@ -115,6 +112,9 @@ KMFolderTree::KMFolderTree( QWidget *parent,
   // add the folders
   reload();
 
+  // connect
+  connectSignals();
+
   // read the config
   readConfig();
 
@@ -753,6 +753,10 @@ KMFolder *KMFolderTree::currentFolder() const
 // so that the header list and reader window can be udpated.
 void KMFolderTree::doFolderSelected( QListViewItem* qlvi )
 {
+  if (!qlvi) return;
+  disconnect(this, SIGNAL(currentChanged(QListViewItem*)),
+	  this, SLOT(doFolderSelected(QListViewItem*)));
+
   KMFolderTreeItem* fti = static_cast< KMFolderTreeItem* >(qlvi);
   KMFolder* folder = 0;
   if (fti) folder = fti->folder();
@@ -781,16 +785,19 @@ void KMFolderTree::doFolderSelected( QListViewItem* qlvi )
     emit folderSelected(folder);
     if (folder->protocol() == "imap")
     {
-      KMFolderImap *imap_folder = static_cast<KMFolderImap*>(fti->folder());
+      KMFolderImap *imap_folder = static_cast<KMFolderImap*>(folder);
       imap_folder->setSelected(TRUE);
       if (imap_folder->getContentState() != KMFolderImap::imapInProgress)
-        imap_folder->getFolder();
+        imap_folder->getAndCheckFolder();
     } else {
       // we don't need this for imap-folders because
       // they're updated with the folderComplete-signal
       slotUpdateCounts(folder);
     }
   }
+  connect(this, SIGNAL(currentChanged(QListViewItem*)),
+	  this, SLOT(doFolderSelected(QListViewItem*)));
+
 }
 
 //-----------------------------------------------------------------------------
@@ -1401,9 +1408,6 @@ void KMFolderTree::toggleColumn(int column, bool openFolders)
     }
     // toggle KPopupMenu and KToggleAction
     mPopup->setItemChecked( mUnreadPop, isUnreadActive() );
-    if ( parentWidget()->parentWidget()->isA("KMMainWin") )
-      static_cast<KMMainWin*>(parentWidget()->parentWidget())
-        ->unreadColumnToggle->setChecked( isUnreadActive() );
 
   } else if (column == total) {	
     // switch total
@@ -1417,11 +1421,10 @@ void KMFolderTree::toggleColumn(int column, bool openFolders)
     }
     // toggle KPopupMenu and KToggleAction
     mPopup->setItemChecked( mTotalPop, isTotalActive() );
-    if ( parentWidget()->parentWidget()->isA("KMMainWin") )
-      static_cast<KMMainWin*>(parentWidget()->parentWidget())
-        ->totalColumnToggle->setChecked( isTotalActive() );
 
   } else kdDebug(5006) << "unknown column:" << column << endl;
+
+  emit columnsChanged();
 }
 
 //-----------------------------------------------------------------------------
