@@ -391,7 +391,7 @@ public:
     } else if (column == paintInfo->subCol) {
       if (paintInfo->status)
         return ret + QString( QChar( (uint)msg->status() )) + sortArrival;
-      return ret + KMMsgBase::skipKeyword( msg->subject().lower() ) + ' ' + sortArrival;
+      return ret + KMMessage::stripOffPrefixes( msg->subject().lower() ) + ' ' + sortArrival;
     }
     else if (column == paintInfo->sizeCol) {
       QString len;
@@ -1203,9 +1203,11 @@ void KMHeaders::slotExpandOrCollapseAllThreads( bool expand )
     static_cast<KMHeaderItem*>(item)->setOpen( expand );
   if ( !expand ) { // collapse can hide the current item:
     QListViewItem * item = currentItem();
-    while ( item->parent() )
-      item = item->parent();
-    setCurrentMsg( static_cast<KMHeaderItem*>(item)->msgId() );
+    if( item ) {
+      while ( item->parent() )
+        item = item->parent();
+      setCurrentMsg( static_cast<KMHeaderItem*>(item)->msgId() );
+    }
   }
   ensureItemVisible( currentItem() );
 }
@@ -1328,10 +1330,7 @@ void KMHeaders::resendMsg ()
   kernel->kbp()->busy();
   newMsg = new KMMessage;
   newMsg->fromString(msg->asString());
-  newMsg->initFromMessage(msg, true);
   newMsg->setCharset(msg->codec()->mimeName());
-  newMsg->setTo(msg->to());
-  newMsg->setSubject(msg->subject());
   // the message needs a new Message-Id
   newMsg->removeHeaderField( "Message-Id" );
 
@@ -1597,19 +1596,21 @@ void KMHeaders::nextMessage()
 void KMHeaders::selectNextMessage()
 {
   QListViewItem *lvi = currentItem();
-  QListViewItem *below = lvi->itemBelow();
-  QListViewItem *temp = lvi;
-  if (lvi && below ) {
-    while (temp) {
-      temp->firstChild();
-      temp = temp->parent();
+  if( lvi ) {
+    QListViewItem *below = lvi->itemBelow();
+    QListViewItem *temp = lvi;
+    if (lvi && below ) {
+      while (temp) {
+        temp->firstChild();
+        temp = temp->parent();
+      }
+      lvi->repaint();
+      /* test to see if we need to unselect messages on back track */
+      (below->isSelected() ? setSelected(lvi, FALSE) : setSelected(below, TRUE));
+      setCurrentItem(below);
+      makeHeaderVisible();
+      setFolderInfoStatus();
     }
-    lvi->repaint();
-    /* test to see if we need to unselect messages on back track */
-    (below->isSelected() ? setSelected(lvi, FALSE) : setSelected(below, TRUE));
-    setCurrentItem(below);
-    makeHeaderVisible();
-    setFolderInfoStatus();
   }
 }
 
@@ -1627,20 +1628,22 @@ void KMHeaders::prevMessage()
 void KMHeaders::selectPrevMessage()
 {
   QListViewItem *lvi = currentItem();
-  QListViewItem *above = lvi->itemAbove();
-  QListViewItem *temp = lvi;
+  if( lvi ) {
+    QListViewItem *above = lvi->itemAbove();
+    QListViewItem *temp = lvi;
 
-  if (lvi && above) {
-    while (temp) {
-      temp->firstChild();
-      temp = temp->parent();
+    if (lvi && above) {
+      while (temp) {
+        temp->firstChild();
+        temp = temp->parent();
+      }
+      lvi->repaint();
+      /* test to see if we need to unselect messages on back track */
+      (above->isSelected() ? setSelected(lvi, FALSE) : setSelected(above, TRUE));
+      setCurrentItem(above);
+      makeHeaderVisible();
+      setFolderInfoStatus();
     }
-    lvi->repaint();
-    /* test to see if we need to unselect messages on back track */
-    (above->isSelected() ? setSelected(lvi, FALSE) : setSelected(above, TRUE));
-    setCurrentItem(above);
-    makeHeaderVisible();
-    setFolderInfoStatus();
   }
 }
 
