@@ -545,8 +545,7 @@ void KMKernel::initFolders(KConfig* cfg)
   the_inboxFolder  = (KMFolder*)the_folderMgr->findOrCreate(name);
 
   if (the_inboxFolder->canAccess() != 0) {
-    KMessageBox::sorry(0, i18n("You do not have read/write permission to your inbox folder.") );
-    exit(1);
+    emergencyExit( i18n("You do not have read/write permission to your inbox folder.") );
   }
 
   the_inboxFolder->setSystemFolder(TRUE);
@@ -554,8 +553,7 @@ void KMKernel::initFolders(KConfig* cfg)
 
   the_outboxFolder = the_folderMgr->findOrCreate(cfg->readEntry("outboxFolder", I18N_NOOP("outbox")));
   if (the_outboxFolder->canAccess() != 0) {
-    KMessageBox::sorry(0, i18n("You do not have read/write permission to your outbox folder.") );
-    exit(1);
+    emergencyExit( i18n("You do not have read/write permission to your outbox folder.") );
   }
 
   the_outboxFolder->setType("Out");
@@ -564,8 +562,7 @@ void KMKernel::initFolders(KConfig* cfg)
 
   the_sentFolder = the_folderMgr->findOrCreate(cfg->readEntry("sentFolder", I18N_NOOP("sent-mail")));
   if (the_sentFolder->canAccess() != 0) {
-    KMessageBox::sorry(0, i18n("You do not have read/write permission to your sent-mail folder.") );
-    exit(1);
+    emergencyExit( i18n("You do not have read/write permission to your sent-mail folder.") );
   }
   the_sentFolder->setType("St");
   the_sentFolder->setSystemFolder(TRUE);
@@ -573,8 +570,7 @@ void KMKernel::initFolders(KConfig* cfg)
 
   the_trashFolder  = the_folderMgr->findOrCreate(cfg->readEntry("trashFolder", I18N_NOOP("trash")));
   if (the_trashFolder->canAccess() != 0) {
-    KMessageBox::sorry(0, i18n("You do not have read/write permission to your trash folder.") );
-    exit(1);
+    emergencyExit( i18n("You do not have read/write permission to your trash folder.") );
   }
   the_trashFolder->setType("Tr");
   the_trashFolder->setSystemFolder(TRUE);
@@ -582,8 +578,7 @@ void KMKernel::initFolders(KConfig* cfg)
 
   the_draftsFolder = the_folderMgr->findOrCreate(cfg->readEntry("draftsFolder", I18N_NOOP("drafts")));
   if (the_draftsFolder->canAccess() != 0) {
-    KMessageBox::sorry(0, i18n("You do not have read/write permission to your drafts folder.") );
-    exit(1);
+    emergencyExit( i18n("You do not have read/write permission to your drafts folder.") );
   }
   the_draftsFolder->setType("Df");
   the_draftsFolder->setSystemFolder(TRUE);
@@ -747,6 +742,15 @@ void KMKernel::cleanupProgress()
 
 void KMKernel::cleanupLoop()
 {
+  QStringList cleanupMsgs;
+  cleanupMsgs << i18n("Cleaning up")
+              << i18n("Emptying trash...")
+              << i18n("Expiring old messages...")
+              << i18n("Compacting folders...");
+  enum { CleaningUpMsgNo = 0,
+         EmptyTrashMsgNo = 1,
+         ExpiringOldMessagesMsgNo = 2,
+         CompactingFoldersMsgNo = 3 };
   mProgress = 0;
   mCleanupLabel = 0;
   mCleanupPopup = 0;
@@ -756,8 +760,20 @@ void KMKernel::cleanupLoop()
     mCleanupPopup = new KPassivePopup();
     QVBox *box = mCleanupPopup->standardView( kapp->aboutData()->programName(),
                                               QString::null, kapp->miniIcon());
-    mCleanupLabel = new QLabel( i18n("Cleaning up"), box );
+    mCleanupLabel = new QLabel( cleanupMsgs[CleaningUpMsgNo], box );
+    // determine the maximal width of the clean up messages
+    QFontMetrics fm = mCleanupLabel->fontMetrics();
+    int maxTextWidth = 0;
+    for( QStringList::ConstIterator it = cleanupMsgs.begin();
+         it != cleanupMsgs.end();
+         ++it ) {
+      int w;
+      if( maxTextWidth < ( w = fm.width( *it ) ) )
+        maxTextWidth = w;
+    }
+    
     mProgress = new KProgress( box, "kmail-cleanupProgress" );
+    mProgress->setMinimumWidth( maxTextWidth+20 );
     mCleanupPopup->setView( box );
     
     mProgress->setTotalSteps(nrFolders*2+2);
@@ -797,7 +813,7 @@ void KMKernel::cleanupLoop()
     {
       if (mCleanupLabel)
       {
-        mCleanupLabel->setText(i18n("Emptying trash..."));
+        mCleanupLabel->setText( cleanupMsgs[EmptyTrashMsgNo] );
         QApplication::syncX();
         kapp->processEvents();
       }
@@ -811,7 +827,7 @@ void KMKernel::cleanupLoop()
   if (expire) {
     if (mCleanupLabel)
     {
-       mCleanupLabel->setText(i18n("Expiring old messages..."));
+       mCleanupLabel->setText( cleanupMsgs[ExpiringOldMessagesMsgNo] );
        QApplication::syncX();
        kapp->processEvents();
     }
@@ -826,15 +842,19 @@ void KMKernel::cleanupLoop()
     {
       if (mCleanupLabel)
       {
-        mCleanupLabel->setText(i18n("Compacting folders..."));
+        mCleanupLabel->setText( cleanupMsgs[CompactingFoldersMsgNo] );
         QApplication::syncX();
         kapp->processEvents();
       }
       the_folderMgr->compactAll(); // I can compact for ages in peace now!
     }
   }
-  if (mProgress)
-     mProgress->setProgress(2+2*nrFolders);
+  if (mProgress) {
+    mCleanupLabel->setText( cleanupMsgs[CleaningUpMsgNo] );
+    mProgress->setProgress(2+2*nrFolders);
+    QApplication::syncX();
+    kapp->processEvents();
+  }
 
   if (the_inboxFolder) the_inboxFolder->close(TRUE);
   if (the_outboxFolder) the_outboxFolder->close(TRUE);
@@ -1152,7 +1172,7 @@ IdentityManager * KMKernel::identityManager() {
   return mIdentityManager;
 }
 
-KMMainWin* KMKernel::mainWin()
+KMMainWin* KMKernel::mainWin(bool create)
 {
   KMainWindow *kmWin = 0;
 
@@ -1161,9 +1181,11 @@ KMMainWin* KMKernel::mainWin()
       if (kmWin->isA("KMMainWin")) break;
   if (kmWin && kmWin->isA("KMMainWin")) {
     return (KMMainWin *) kmWin;
-  } else {
+  } else if (create) {
     mWin = new KMMainWin;
     return mWin;
+  } else {
+    return 0;
   }
 }
 
