@@ -161,8 +161,9 @@ public:
   /** See @ref slotCollectStdErr */
   QByteArray getCollectedStdErr(KProcess*);
 
-  /** returns a reference to the first Mainwin or a temporary Mainwin */
-  KMMainWin* mainWin();
+  /** returns a reference to the first Mainwin 
+    or a temporary Mainwin if create is true */
+  KMMainWin* mainWin(bool create = true);
 
 public slots:
   /** Connect the received* signals of K(Shell)Process to these slots
