@@ -135,6 +135,9 @@ public slots:
   /** Update the undo action */
   void slotUpdateUndo();
 
+  /** The columns of the foldertree changed */
+  void slotFolderTreeColumnsChanged();
+
 protected:
   void setupMenuBar();
   void setupStatusBar();
@@ -242,7 +245,7 @@ protected slots:
   void slotCycleAttachmentStyles();
   void slotSetEncoding();
   void slotSendQueued();
-  void slotMsgPopup(KMMessage &msg, const KURL &aUrl, const QPoint&);
+  void slotMsgPopup(const KMReaderWin* win, KMMessage &msg, const KURL &aUrl, const QPoint&);
   void slotUrlClicked(const KURL &url, int button);
   void slotCopyText();
   void slotMarkAll();
