@@ -81,8 +81,11 @@ KMMessage::KMMessage(DwMessage* aMsg)
     mTransferInProgress(false),
     mDecodeHTML(false),
     mCodec(0),
+    mAutoDetectCodec(true),
     mUnencryptedMsg(0)
 {
+  mEncryptionState = KMMsgEncryptionStateUnknown;
+  mSignatureState = KMMsgSignatureStateUnknown;
 }
 
 //-----------------------------------------------------------------------------
@@ -102,6 +105,7 @@ void KMMessage::assign( const KMMessage& other )
   if( other.mMsg )
     mMsg = new DwMessage( *(other.mMsg) );
   mCodec = other.mCodec;
+  mAutoDetectCodec = other.mAutoDetectCodec;
   mDecodeHTML = other.mDecodeHTML;
   mIsComplete = false;//other.mIsComplete;
   mTransferInProgress = other.mTransferInProgress;
@@ -166,6 +170,7 @@ KMMessage::KMMessage(KMFolder* parent): KMMessageInherited(parent)
   mNeedsAssembly = FALSE;
   mMsg = new DwMessage;
   mCodec = 0;
+  mAutoDetectCodec = true;
   mDecodeHTML = FALSE;
   mIsComplete = FALSE;
   mTransferInProgress = FALSE;
@@ -188,6 +193,7 @@ KMMessage::KMMessage(KMMsgInfo& msgInfo): KMMessageInherited()
   mNeedsAssembly = FALSE;
   mMsg = new DwMessage;
   mCodec = 0;
+  mAutoDetectCodec = true;
   mDecodeHTML = FALSE;
   mIsComplete = FALSE;
   mTransferInProgress = FALSE;
@@ -683,8 +689,10 @@ static void smartQuote( QString &msg, int maxLength )
 
 
 //-----------------------------------------------------------------------------
-void KMMessage::parseTextStringFromDwPart( DwBodyPart& dwPart,
+void KMMessage::parseTextStringFromDwPart( DwBodyPart * mainBody,
+					   DwBodyPart * firstBodyPart,
                                            QCString& parsedString,
+                                           const QTextCodec*& codec,
                                            bool& isHTML ) const
 {
   // get a valid CryptPlugList
@@ -700,9 +708,11 @@ void KMMessage::parseTextStringFromDwPart( DwBodyPart& dwPart,
       mainType    = DwMime::kTypeText;
       mainSubType = DwMime::kSubtypePlain;
   }
-  partNode rootNode(0, mainType, mainSubType);
-  partNode* curNode = rootNode.setFirstChild( new partNode( &dwPart ) );
-  curNode->buildObjectTree( false );
+  partNode rootNode(mainBody, mainType, mainSubType);
+  if ( firstBodyPart ) {
+    partNode* curNode = rootNode.setFirstChild( new partNode( firstBodyPart ) );
+    curNode->buildObjectTree();
+  }
   // initialy parse the complete message to decrypt any encrypted parts
   KMReaderWin::parseObjectTree( 0,
                                 0,
@@ -711,14 +721,14 @@ void KMMessage::parseTextStringFromDwPart( DwBodyPart& dwPart,
                                 true,
                                 false,
                                 true );
-  curNode = curNode->findType( DwMime::kTypeText,
+  partNode * curNode = rootNode.findType( DwMime::kTypeText,
                                DwMime::kSubtypeUnknown,
                                true,
                                false );
   kdDebug(5006) << "\n\n======= KMMessage::parseTextStringFromDwPart()   -    "
                 << QString( curNode ? "text part found!\n" : "sorry, no text node!\n" ) << endl;
   if( curNode ) {
-    isHTML = DwMime::kSubtypeHtml == curNode->type();
+    isHTML = DwMime::kSubtypeHtml == curNode->subType();
     // now parse the TEXT message part we want to quote
     KMReaderWin::parseObjectTree( 0,
                                   &parsedString,
@@ -727,140 +737,73 @@ void KMMessage::parseTextStringFromDwPart( DwBodyPart& dwPart,
                                   true,
                                   false,
                                   true );
+    codec = curNode->msgPart().codec();
   }
   kdDebug(5006) << "\n\n======= KMMessage::parseTextStringFromDwPart()   -    parsed string:\n\""
                 << QString( parsedString + "\"\n\n" ) << endl;
 }
 
 //-----------------------------------------------------------------------------
-QCString KMMessage::asQuotedString(const QString& aHeaderStr,
-                                   const QString& aIndentStr,
-                                   const QString& selection,
-                                   bool aStripSignature,
-                                   bool allowDecryption) const
+QCString KMMessage::asQuotedString( const QString& aHeaderStr,
+                                    const QString& aIndentStr,
+                                    const QString& selection /* = QString::null */,
+                                    bool aStripSignature /* = true */,
+                                    bool allowDecryption /* = true */) const
 {
   QString result;
   QString headerStr;
-  QRegExp reNL("\\n");
   QString indentStr;
-  int i;
-  bool clearSigned = false;
-
-  QTextCodec *codec = mCodec;
-  if (!codec)
-  {
-    QCString cset = charset();
-    if (!cset.isEmpty())
-      codec = KMMsgBase::codecForName(cset);
-    if (!codec) codec = kernel->networkCodec();
-  }
 
   indentStr = formatString(aIndentStr);
   headerStr = formatString(aHeaderStr);
 
-
-  QCString parsedString;
-  bool isHTML = false;
-
   // Quote message. Do not quote mime message parts that are of other
   // type than "text".
-  if (numBodyParts() == 0 || !selection.isEmpty() ) {
-    if( !selection.isEmpty() ) {
-      result = selection;
-    } else {
+  if( !selection.isEmpty() ) {
+    result = selection;
+  }
+  else {
+    QCString parsedString;
+    bool isHTML = false;
+    bool clearSigned = false;
+    const QTextCodec* codec = 0;
 
+    if( numBodyParts() == 0 ) {
+      DwBodyPart * mainBody = 0;
+      DwBodyPart * firstBodyPart = getFirstDwBodyPart();
+      if( !firstBodyPart ) {
+        mainBody = new DwBodyPart(((KMMessage*)this)->asDwString(), 0);
+	mainBody->Parse();
+      }
+      parseTextStringFromDwPart( mainBody, firstBodyPart, parsedString, codec,
+                                 isHTML );
+    }
+    else {
       DwBodyPart *dwPart = getFirstDwBodyPart();
-      if( !dwPart )
-        dwPart = new DwBodyPart(((KMMessage*)this)->asDwString(), 0);
-      dwPart->Parse();
-      parseTextStringFromDwPart( *dwPart, parsedString, isHTML );
-
-      if( !parsedString.isEmpty() ) {
-
-        Kpgp::Module* pgp = Kpgp::Module::getKpgp();
-        assert(pgp != 0);
-
-        QPtrList<Kpgp::Block> pgpBlocks;
-        QStrList nonPgpBlocks;
-        if( allowDecryption &&
-            Kpgp::Module::prepareMessageForDecryption( parsedString,
-                                                       pgpBlocks, nonPgpBlocks ) )
-        {
-          // Only decrypt/strip off the signature if there is only one OpenPGP
-          // block in the message
-          if( pgpBlocks.count() == 1 )
-          {
-            Kpgp::Block* block = pgpBlocks.first();
-            if( ( block->type() == Kpgp::PgpMessageBlock ) ||
-                ( block->type() == Kpgp::ClearsignedBlock ) )
-            {
-                if( block->type() == Kpgp::PgpMessageBlock )
-                // try to decrypt this OpenPGP block
-                block->decrypt();
-                else
-                {
-                // strip off the signature
-                block->verify();
-                clearSigned = true;
-                }
-
-                result = codec->toUnicode( nonPgpBlocks.first() )
-                    + codec->toUnicode( block->text() )
-                    + codec->toUnicode( nonPgpBlocks.last() );
-            }
-          }
-        }
-      }
-      if( result.isEmpty() )
-        result = codec->toUnicode( parsedString );
-      if( mDecodeHTML && isHTML )
-      {
-        KHTMLPart htmlPart;
-        htmlPart.setOnlyLocalReferences(true);
-        htmlPart.setMetaRefreshEnabled(false);
-        htmlPart.setPluginsEnabled(false);
-        htmlPart.setJScriptEnabled(false);
-        htmlPart.setJavaEnabled(false);
-        htmlPart.begin();
-        htmlPart.write(result);
-        htmlPart.end();
-        htmlPart.selectAll();
-        result = htmlPart.selectedText();
-      }
+      if( dwPart )
+        parseTextStringFromDwPart( 0, dwPart, parsedString, codec, isHTML );
     }
 
-    // Remove blank lines at the beginning
-    for( i = 0; i < (int)result.length() && result[i] <= ' '; i++ );
-    while (i > 0 && result[i-1] == ' ') i--;
-    result.remove(0,i);
+    if( !mAutoDetectCodec )
+      codec = mCodec;
+    if( !codec ) {
+      QCString cset = charset();
+      if( !cset.isEmpty() )
+        codec = KMMsgBase::codecForName( cset );
+      if( !codec )
+        codec = kernel->networkCodec();
+    }
 
-    if (aStripSignature)
-        stripSignature(result, clearSigned);
-
-    result.replace(reNL, '\n' + indentStr);
-    result = indentStr + result + '\n';
-
-    if (sSmartQuote)
-      smartQuote(result, sWrapCol);
-
-  } else {
-    result = "";
-
-    DwBodyPart *dwPart = getFirstDwBodyPart();
-    if( dwPart )
-      parseTextStringFromDwPart( *dwPart, parsedString, isHTML );
-
-    if( !parsedString.isEmpty() )
-    {
+    if( !parsedString.isEmpty() ) {
       Kpgp::Module* pgp = Kpgp::Module::getKpgp();
       assert(pgp != 0);
-      QString part;
 
       QPtrList<Kpgp::Block> pgpBlocks;
       QStrList nonPgpBlocks;
       if( allowDecryption &&
           Kpgp::Module::prepareMessageForDecryption( parsedString,
-                                                     pgpBlocks, nonPgpBlocks ) )
+                                                     pgpBlocks,
+                                                     nonPgpBlocks ) )
       {
         // Only decrypt/strip off the signature if there is only one OpenPGP
         // block in this message part
@@ -870,76 +813,118 @@ QCString KMMessage::asQuotedString(const QString& aHeaderStr,
           if( ( block->type() == Kpgp::PgpMessageBlock ) ||
               ( block->type() == Kpgp::ClearsignedBlock ) )
           {
-            if( block->type() == Kpgp::PgpMessageBlock )
+            if( block->type() == Kpgp::PgpMessageBlock ) {
               // try to decrypt this OpenPGP block
               block->decrypt();
-            else
-            {
+            }
+            else {
               // strip off the signature
               block->verify();
               clearSigned = true;
             }
 
-            part = codec->toUnicode( nonPgpBlocks.first() )
-                 + codec->toUnicode( block->text() )
-                 + codec->toUnicode( nonPgpBlocks.last() );
+            result = codec->toUnicode( nonPgpBlocks.first() )
+                   + codec->toUnicode( block->text() )
+                   + codec->toUnicode( nonPgpBlocks.last() );
           }
         }
       }
-      if( part.isEmpty() )
-      {
-        // part = codec->toUnicode( msgPart.bodyDecoded() );
-        //	    debug ("part\n" + part ); inexplicably crashes -sanders
-        part = codec->toUnicode( parsedString );
-      }
-
-      if (aStripSignature)
-        stripSignature(part, clearSigned);
-
-      part.replace(reNL, '\n' + indentStr);
-      part = indentStr + part + '\n';
-      if (sSmartQuote)
-        smartQuote(part, sWrapCol);
-      result += part;
+      if( result.isEmpty() )
+        result = codec->toUnicode( parsedString );
     }
+
+    if( !result.isEmpty() && mDecodeHTML && isHTML ) {
+      KHTMLPart htmlPart;
+      htmlPart.setOnlyLocalReferences( true );
+      htmlPart.setMetaRefreshEnabled( false );
+      htmlPart.setPluginsEnabled( false );
+      htmlPart.setJScriptEnabled( false );
+      htmlPart.setJavaEnabled( false );
+      htmlPart.begin();
+      htmlPart.write( result );
+      htmlPart.end();
+      htmlPart.selectAll();
+      result = htmlPart.selectedText();
+    }
+
+    if( aStripSignature )
+      stripSignature( result, clearSigned );
   }
 
-  QCString c = QString(headerStr + result).utf8();
+  // Remove blank lines at the beginning:
+  // 1. find first non space, non linebreak character
+  int i = result.find( QRegExp( "[^\\s]" ) );
+  // 2. find the start of the current line
+  i = result.findRev( "\n", i );
+  if( i >= 0 )
+    result.remove( 0, (uint)i );
 
-  return c;
-}
+  result.replace( "\n", '\n' + indentStr );
+  result = indentStr + result + '\n';
 
-QString KMMessage::cleanSubject( const QStringList & prefixRegExps, bool replace, const QString & newPrefix ) const {
-  bool recognized = false;
-  // construct a big regexp that
-  // 1. is anchored to the beginning of the subject (sans whitespace)
-  // 2. matches at least one of the part regexps in prefixRegExps
-  QString bigRegExp = QString::fromLatin1("^(?:\\s+|(?:%1))+\\s*")
-    .arg( prefixRegExps.join(")|(?:") );
-  kdDebug(5006) << "KMMessage::cleanSubject(): bigRegExp = \"" << bigRegExp
-		<< "\"" << endl;
-  QRegExp rx( bigRegExp, false /*case insens.*/ );
-  if ( !rx.isValid() ) {
-    kdDebug(5006) << "prefix regexp is invalid!" << endl;
-    // try good ole Re/Fwd:
-    recognized = subject().startsWith( newPrefix );
-  } else { // valid rx
-    QString subj = subject();
-    if ( rx.search( subj ) == 0 ) {
-      recognized = true;
-      if ( replace )
-	return subj.replace( 0, rx.matchedLength(), newPrefix + ' ' );
-    }
-  }
-  if ( !recognized )
-    return newPrefix + ' ' + subject();
-  else
-    return subject();
+  if( sSmartQuote )
+    smartQuote( result, sWrapCol );
+
+  return QString( headerStr + result ).utf8();
 }
 
 //-----------------------------------------------------------------------------
-KMMessage* KMMessage::createReply(bool replyToAll, bool replyToList,
-  QString selection, bool noQuote, bool allowDecryption)
+// static
+QString KMMessage::stripOffPrefixes( const QString& str )
+{
+  return replacePrefixes( str, sReplySubjPrefixes + sForwardSubjPrefixes,
+                          true, QString::null ).stripWhiteSpace();
+}
+
+//-----------------------------------------------------------------------------
+// static
+QString KMMessage::replacePrefixes( const QString& str,
+                                    const QStringList& prefixRegExps,
+                                    bool replace,
+                                    const QString& newPrefix )
+{
+  bool recognized = false;
+  // construct a big regexp that
+  // 1. is anchored to the beginning of str (sans whitespace)
+  // 2. matches at least one of the part regexps in prefixRegExps
+  QString bigRegExp = QString::fromLatin1("^(?:\\s+|(?:%1))+\\s*")
+                      .arg( prefixRegExps.join(")|(?:") );
+  QRegExp rx( bigRegExp, false /*case insens.*/ );
+  if ( !rx.isValid() ) {
+    kdWarning(5006) << "KMMessage::replacePrefixes(): bigRegExp = \""
+                    << bigRegExp << "\"\n"
+                    << "prefix regexp is invalid!" << endl;
+    // try good ole Re/Fwd:
+    recognized = str.startsWith( newPrefix );
+  } else { // valid rx
+    QString tmp = str;
+    if ( rx.search( tmp ) == 0 ) {
+      recognized = true;
+      if ( replace )
+	return tmp.replace( 0, rx.matchedLength(), newPrefix + ' ' );
+    }
+  }
+  if ( !recognized )
+    return newPrefix + ' ' + str;
+  else
+    return str;
+}
+
+//-----------------------------------------------------------------------------
+QString KMMessage::cleanSubject( const QStringList & prefixRegExps,
+                                 bool replace,
+                                 const QString & newPrefix ) const
+{
+  return KMMessage::replacePrefixes( subject(), prefixRegExps, replace,
+                                     newPrefix );
+}
+
+//-----------------------------------------------------------------------------
+KMMessage* KMMessage::createReply( bool replyToAll /* = false */,
+                                   bool replyToList /* = false */,
+                                   QString selection /* = QString::null */,
+                                   bool noQuote /* = false */,
+                                   bool allowDecryption /* = true */)
 {
   KMMessage* msg = new KMMessage;
   QString str, replyStr, mailingListStr, replyToStr, toStr;
@@ -994,10 +979,10 @@ KMMessage* KMMessage::createReply(bool replyToAll, bool replyToList,
     }
 
     // strip my own address from the list of recipients
-    QString myAddr = getEmailAddr(msg->from());
+    QCString myAddr = getEmailAddr(msg->from()).lower();
     for (QStringList::Iterator it = recipients.begin();
          it != recipients.end(); ) {
-      if ((*it).find(myAddr,0,false) != -1) {
+      if ( myAddr == getEmailAddr( *it ).lower() ) {
         kdDebug(5006) << "Removing " << *it << " from the list of recipients"
                       << endl;
         it = recipients.remove(it);
@@ -1015,7 +1000,7 @@ KMMessage* KMMessage::createReply(bool replyToAll, bool replyToList,
       // strip my own address
       for (QStringList::Iterator it = recipients.begin();
            it != recipients.end(); ) {
-        if ((*it).find(myAddr,0,false) != -1) {
+        if ( myAddr == getEmailAddr( *it ).lower() ) {
           kdDebug(5006) << "Removing " << *it << " from the cc recipients"
                         << endl;
           it = recipients.remove(it);
@@ -1279,8 +1264,14 @@ KMMessage* KMMessage::createForward(void)
     for (i = 0; i < numBodyParts(); i++)
     {
       bodyPart(i, &msgPart);
-      if (i > 0 || qstricmp(msgPart.typeStr(),"text") != 0)
-        msg->addBodyPart(&msgPart);
+      QCString mimeType = msgPart.typeStr().lower() + '/'
+                        + msgPart.subtypeStr().lower();
+      // don't add the detached signature as attachment when forwarding a
+      // PGP/MIME signed message inline
+      if( mimeType != "application/pgp-signature" ) {
+        if (i > 0 || qstricmp(msgPart.typeStr(),"text") != 0)
+          msg->addBodyPart(&msgPart);
+      }
     }
   }
 
@@ -1715,7 +1706,7 @@ QString KMMessage::replyToId(void) const
 
   // if we have found a good message id we can return immediately
   // We ignore mangled In-Reply-To headers which are created by a
-  // missconfigured Mutt. They look like this <"from foo"@bar.baz>, i.e.
+  // misconfigured Mutt. They look like this <"from foo"@bar.baz>, i.e.
   // they contain double quotes and spaces. We only check for '"'.
   if (!replyTo.isEmpty() && (replyTo[0] == '<') &&
       ( -1 == replyTo.find( '"' ) ) )
@@ -2106,100 +2097,94 @@ QCString KMMessage::bodyDecoded(void) const
 
 
 //-----------------------------------------------------------------------------
-void KMMessage::setBodyAndGuessCte(const QByteArray& aBuf,
-                       QValueList<int> & allowedCte,
-                       bool allow8Bit )
+QValueList<int> KMMessage::determineAllowedCtes( const CharFreq& cf,
+                                                 bool allow8Bit,
+                                                 bool willBeSigned )
 {
-  allowedCte.clear();
-
-  CharFreq cf( aBuf ); // save to pass null arrays...
+  QValueList<int> allowedCtes;
 
   switch ( cf.type() ) {
   case CharFreq::SevenBitText:
-    allowedCte << DwMime::kCte7bit;
+    allowedCtes << DwMime::kCte7bit;
+  case CharFreq::EightBitText:
     if ( allow8Bit )
-      allowedCte << DwMime::kCte8bit;
+      allowedCtes << DwMime::kCte8bit;
   case CharFreq::SevenBitData:
     if ( cf.printableRatio() > 5.0/6.0 ) {
       // let n the length of data and p the number of printable chars.
       // Then base64 \approx 4n/3; qp \approx p + 3(n-p)
       // => qp < base64 iff p > 5n/6.
-      allowedCte << DwMime::kCteQp;
-      allowedCte << DwMime::kCteBase64;
+      allowedCtes << DwMime::kCteQp;
+      allowedCtes << DwMime::kCteBase64;
     } else {
-      allowedCte << DwMime::kCteBase64;
-      allowedCte << DwMime::kCteQp;
-    }
-    break;
-  case CharFreq::EightBitText:
-    if ( allow8Bit )
-      allowedCte << DwMime::kCte8bit;
-    if ( cf.printableRatio() > 5.0/6.0 ) {
-      allowedCte << DwMime::kCteQp;
-      allowedCte << DwMime::kCteBase64;
-    } else {
-      allowedCte << DwMime::kCteBase64;
-      allowedCte << DwMime::kCteQp;
+      allowedCtes << DwMime::kCteBase64;
+      allowedCtes << DwMime::kCteQp;
     }
     break;
   case CharFreq::EightBitData:
-    allowedCte << DwMime::kCteBase64;
+    allowedCtes << DwMime::kCteBase64;
     break;
+  case CharFreq::None:
+  default:
+    // just nothing (avoid compiler warning)
+    ;
   }
 
+  // In the following cases only QP and Base64 are allowed:
+  // - the buffer will be OpenPGP/MIME signed and it contains trailing
+  //   whitespace (cf. RFC 3156)
+  // - a line starts with "From "
+  if ( ( willBeSigned && cf.hasTrailingWhitespace() ) ||
+       cf.hasLeadingFrom() ) {
+    allowedCtes.remove( DwMime::kCte8bit );
+    allowedCtes.remove( DwMime::kCte7bit );
+  }
+  
+  return allowedCtes;
+}
+
+
+//-----------------------------------------------------------------------------
+void KMMessage::setBodyAndGuessCte( const QByteArray& aBuf,
+                                    QValueList<int> & allowedCte,
+                                    bool allow8Bit,
+                                    bool willBeSigned )
+{
+  CharFreq cf( aBuf ); // it's safe to pass null arrays
+
+  allowedCte = KMMessage::determineAllowedCtes( cf, allow8Bit, willBeSigned );
+
+#ifndef NDEBUG
+  DwString dwCte;
+  DwCteEnumToStr(allowedCte[0], dwCte);
   kdDebug() << "CharFreq returned " << cf.type() << "/"
-        << cf.printableRatio() << " and I chose "
-        << allowedCte[0] << endl;
+	    << cf.printableRatio() << " and I chose "
+	    << dwCte.c_str() << endl;
+#endif
+
   setCte( allowedCte[0] ); // choose best fitting
   setBodyEncodedBinary( aBuf );
 }
 
 
 //-----------------------------------------------------------------------------
-void KMMessage::setBodyAndGuessCte(const QCString& aBuf,
-                       QValueList<int> & allowedCte,
-                       bool allow8Bit )
+void KMMessage::setBodyAndGuessCte( const QCString& aBuf,
+                                    QValueList<int> & allowedCte,
+                                    bool allow8Bit,
+                                    bool willBeSigned )
 {
-  allowedCte.clear();
+  CharFreq cf( aBuf.data(), aBuf.length() ); // it's safe to pass null strings
 
-  CharFreq cf( aBuf.data(), aBuf.length() ); // save to pass null strings
-
-  switch ( cf.type() ) {
-  case CharFreq::SevenBitText:
-    allowedCte << DwMime::kCte7bit;
-    if ( allow8Bit )
-      allowedCte << DwMime::kCte8bit;
-  case CharFreq::SevenBitData:
-    if ( cf.printableRatio() > 5.0/6.0 ) {
-      // let n the length of data and p the number of printable chars.
-      // Then base64 \approx 4n/3; qp \approx p + 3(n-p)
-      // => qp < base64 iff p > 5n/6.
-      allowedCte << DwMime::kCteQp;
-      allowedCte << DwMime::kCteBase64;
-    } else {
-      allowedCte << DwMime::kCteBase64;
-      allowedCte << DwMime::kCteQp;
-    }
-    break;
-  case CharFreq::EightBitText:
-    if ( allow8Bit )
-      allowedCte << DwMime::kCte8bit;
-    if ( cf.printableRatio() > 5.0/6.0 ) {
-      allowedCte << DwMime::kCteQp;
-      allowedCte << DwMime::kCteBase64;
-    } else {
-      allowedCte << DwMime::kCteBase64;
-      allowedCte << DwMime::kCteQp;
-    }
-    break;
-  case CharFreq::EightBitData:
-    allowedCte << DwMime::kCteBase64;
-    break;
-  }
+  allowedCte = KMMessage::determineAllowedCtes( cf, allow8Bit, willBeSigned );
 
+#ifndef NDEBUG
+  DwString dwCte;
+  DwCteEnumToStr(allowedCte[0], dwCte);
   kdDebug() << "CharFreq returned " << cf.type() << "/"
-        << cf.printableRatio() << " and I chose "
-        << allowedCte[0] << endl;
+	    << cf.printableRatio() << " and I chose "
+	    << dwCte.c_str() << endl;
+#endif
+
   setCte( allowedCte[0] ); // choose best fitting
   setBodyEncoded( aBuf );
 }
