@@ -79,6 +79,7 @@ KMMsgBase::KMMsgBase(KMFolder* aParent)
   mDirty   = FALSE;
   mIndexOffset = 0;
   mIndexLength = 0;
+  mEnableUndo = false;
 }
 
 
@@ -474,7 +475,7 @@ QCString KMMsgBase::encodeRFC2047Quoted(const QCString& aStr, bool base64)
   for (unsigned int i = 0; i < aStr.length(); i++)
   {
     ch = aStr.at(i);
-    if (ch >= 128 || ch == '_' || especials.find(aStr.at(i)) != -1)
+    if ( ch >= 128 || ch == '_' || especials.find(ch) != -1 || ch < 32 )
     {
       result += '=';
       hex = ((ch & 0xF0) >> 4) + 48;
@@ -520,7 +521,8 @@ QCString KMMsgBase::encodeRFC2047String(const QString& _str,
     {
       if (!breakLine && (_str.at(p) == ' ' || dontQuote.find(_str.at(p)) != -1))
         start = p + 1;
-      if (_str.at(p).unicode() >= 128 || _str.at(p) < ' ') break;
+      if (_str.at(p).unicode() >= 128 || _str.at(p).unicode() < 32)
+        break;
       p++;
     }
     if (breakLine || p < _str.length())
