@@ -143,6 +143,10 @@ public:
   bool htmlOverride() const { return mHtmlOverride; }
   void setHtmlOverride( bool override );
 
+  /** Is this an embedded or a separate message viewer? */
+  bool isSeparateWindow() const { return mIsSeparateWindow; }
+  void setIsSeparateWindow( bool isSeparate ) { mIsSeparateWindow = isSeparate; }
+
   /** Is html mail to be supported? Takes into account override */
   bool htmlMail();
 
@@ -174,10 +178,7 @@ public:
                         QTextCodec *codec);
 
     /** find a plugin matching a given libName */
-    static bool foundMatchingCryptPlug( QString libName,
-                                        CryptPlugWrapper** useThisCryptPlug_ref,
-                                        QWidget* parent = 0,
-                                        QString verboseName = "" );
+    static CryptPlugWrapper* matchingCryptPlug( const QString& libName );
 
     /** 1. Create a new partNode using 'content' data and Content-Description
             found in 'cntDesc'.
@@ -230,6 +231,7 @@ public:
                                                   partNode* data,
                                                   partNode& sign,
                                                   const QString& fromAddress,
+                                                  const QString& pluginType,
                                                   bool doCheck = true,
                                                   QCString* cleartextData = 0,
                                                   struct CryptPlugWrapper::SignatureMetaData* paramSigMeta = 0,
@@ -259,7 +261,7 @@ signals:
   void statusMsg(const QString& text);
 
   /** The user presses the right mouse button. 'url' may be 0. */
-  void popupMenu(KMMessage &msg, const KURL &url, const QPoint& mousePos);
+  void popupMenu(const KMReaderWin* win, KMMessage &msg, const KURL &url, const QPoint& mousePos);
 
   /** The user has clicked onto an URL that is no attachment. */
   void urlClicked(const KURL &url, int button);
@@ -341,26 +343,33 @@ protected:
   /** Processed the txt strings and composed an appropriate
     HTML string that is stored into data for displaying it
     instead of the mail part's decrypted content.
-    Also used these texts for displaying a Sorry message box.
     This method was implemented for being called
     by writeSignedMIME and by okDecryptMIME. */
-  virtual void showMessageAndSetData( const QString& txt0,
-                                      const QString& txt1,
-                                      const QString& txt2a,
-                                      const QString& txt2b,
-                                      QCString& data );
+  static QCString formatDecryptionErrorMessage( const QString& text,
+                                                const QString& reason,
+                                                const QString& proposal = QString::null );
 
   /** Feeds the HTML widget with the contents of the given message-body
     string. May contain body parts. */
-  virtual void writeBodyStr( const QCString bodyString, QTextCodec *aCodec,
+  virtual void writeBodyStr( const QCString& bodyString,
+			     const QTextCodec *aCodec,
                              const QString& fromAddress,
-                             bool* isSigned = 0,
-                             bool* isEncrypted = 0 );
+                             KMMsgSignatureState&  inlineSignatureState,
+                             KMMsgEncryptionState& inlineEncryptionState );
+  virtual void writeBodyStr( const QCString& bodyString,
+			     const QTextCodec *aCodec,
+                             const QString& fromAddress );
 
   /** Feeds the HTML widget with the contents of the given HTML message-body
     string. May contain body parts. */
   virtual void writeHTMLStr(const QString& aStr);
 
+  /** Writes the given message part to a temporary file and returns the
+      name of this file or QString::null if writing failed.
+  */
+  QString writeMessagePartToTempFile( const KMMessagePart* msgPart,
+                                      int partNumber );
+
   /** Create a nice icon with comment and name for the given
     body part, appended to the HTML view. Content type and subtype
     are set afterwards if they were not before. */
@@ -392,6 +401,8 @@ protected:
 
 
 private:
+  static const QTextCodec * codecFor( partNode * node, const KMReaderWin * win );
+
   /** extracted parts from writeBodyStr() */
   class PartMetaData;
   QString sigStatusToString(CryptPlugWrapper* cryptPlug,
@@ -406,6 +417,7 @@ private:
 
 protected:
   bool mHtmlMail, mHtmlOverride;
+  bool mIsSeparateWindow;
   int mAtmInline;
   int mAtmCurrent;
   QString mAtmCurrentName;
