@@ -11,12 +11,7 @@
 #include "configaccess.h"
 #include "newsengine.h"
 
-#if QT_VERSION < 300
-#  include <qregexp3.h>
-#else
-#  include <qregexp.h>
-#  define QRegExp3 QRegExp
-#endif
+#include <qregexp.h>
 
 #include <kdebug.h>
 #include <kglobal.h>
@@ -50,6 +45,16 @@ static NewsSourceBase::Data NewsSourceDefault[DEFAULT_NEWSSOURCES] = {
 		QString::null,
 		NewsSourceBase::Business, 10, false, false),
 	// Computers ----------
+		NewsSourceBase::Data(
+		QString::fromLatin1("KDE Deutschland"),
+		QString::fromLatin1("http://www.kde.de/news/news.rdf"),
+		QString::fromLatin1("http://www.kde.de/favicon.ico"),
+		NewsSourceBase::Computers, 10, true, false, QString::fromLatin1("de")),
+		NewsSourceBase::Data(
+		QString::fromLatin1("FreeBSD Project News"),
+		QString::fromLatin1("http://www.freebsd.org/news/news.rdf"),
+		QString::fromLatin1("http://www.freebsd.org/favicon.ico"),
+		NewsSourceBase::Computers, 10, false, false),
 		NewsSourceBase::Data(
 		QString::fromLatin1("dot.kde.org"),
 		QString::fromLatin1("http://www.kde.org/dotkdeorg.rdf"),
@@ -57,7 +62,7 @@ static NewsSourceBase::Data NewsSourceDefault[DEFAULT_NEWSSOURCES] = {
 		NewsSourceBase::Computers, 10, true, false),
 		NewsSourceBase::Data(
 		QString::fromLatin1("GNOME News"),
-		QString::fromLatin1("http://news.gnome.org/gnome-news/rdf"),
+		QString::fromLatin1("http://www.gnomedesktop.org/backend.php"),
 		QString::null,
 		NewsSourceBase::Computers, 10, false, false),
 		NewsSourceBase::Data(
@@ -91,11 +96,6 @@ static NewsSourceBase::Data NewsSourceDefault[DEFAULT_NEWSSOURCES] = {
 		QString::null,
 		NewsSourceBase::Computers, 10, false, false),
 		NewsSourceBase::Data(
-		QString::fromLatin1("appwatch"),
-		QString::fromLatin1("http://static.appwatch.com/appwatch.rdf"),
-		QString::fromLatin1("http://www.appwatch.com/favicon.ico"),
-		NewsSourceBase::Computers, 10, false, false),
-		NewsSourceBase::Data(
 		QString::fromLatin1("Freshmeat"),
 		QString::fromLatin1("http://freshmeat.net/backend/fm.rdf"),
 		QString::fromLatin1("http://freshmeat.net/favicon.ico"),
@@ -221,8 +221,8 @@ static NewsSourceBase::Data NewsSourceDefault[DEFAULT_NEWSSOURCES] = {
 		QString::null,
 		NewsSourceBase::Computers, 10, false, false, QString::fromLatin1("de")),
 		NewsSourceBase::Data(
-		QString::fromLatin1("freekde.org"),
-		QString::fromLatin1("http://www.freekde.org/backend.php"),
+		QString::fromLatin1("kdenews.unixcode.org"),
+		QString::fromLatin1("http://kdenews.unixcode.org/?node=news&action=rss"),
 		QString::null,
 		NewsSourceBase::Computers, 10, false, false),
 		NewsSourceBase::Data(
@@ -240,6 +240,11 @@ static NewsSourceBase::Data NewsSourceDefault[DEFAULT_NEWSSOURCES] = {
 		QString::fromLatin1("http://www.netphoenix.at/rss/shortnews.php"),
 		QString::fromLatin1("http://www.netphoenix.at/favicon.ico"),
 		NewsSourceBase::Computers, 10, false, false, QString::fromLatin1("de")),
+		NewsSourceBase::Data(
+		QString::fromLatin1("zez.org - about code "),
+		QString::fromLatin1("http://zez.org/article/rssheadlines"),
+		QString::null,
+		NewsSourceBase::Computers, 10, false, false),
 	// Miscellaneous ------
 		NewsSourceBase::Data(
 		QString::fromLatin1("tagesschau.de"),
@@ -266,12 +271,24 @@ static NewsSourceBase::Data NewsSourceDefault[DEFAULT_NEWSSOURCES] = {
 		QString::fromLatin1("http://www.theregister.co.uk/tonys/slashdot.rdf"),
 		QString::fromLatin1("http://www.theregister.co.uk/favicon.ico"),
 		NewsSourceBase::Misc, 10, false, false),
+	// Magazines ------
+		NewsSourceBase::Data(
+		QString::fromLatin1("Revista do Linux"),
+		QString::fromLatin1("http://www.revistadolinux.com.br/noticias/arquivo/noticias.rdf"),
+		QString::fromLatin1("http://www.revistadolinux.com.br/favicon.ico"),
+		NewsSourceBase::Magazines, 10, false, false),	
 	// Recreation
 		NewsSourceBase::Data(
 		QString::fromLatin1("Segfault"),
 		QString::fromLatin1("http://segfault.org/stories.xml"),
 		QString::fromLatin1("http://segfault.org/favicon.ico"),
-		NewsSourceBase::Recreation, 10, false, false)
+		NewsSourceBase::Recreation, 10, false, false),
+	// Society
+		NewsSourceBase::Data( 
+		QString::fromLatin1( "gflash" ),
+		QString::fromLatin1( "http://www.gflash.de/backend.php"),
+		QString::fromLatin1( "http://www.gflash.de/favicon.ico"),
+		NewsSourceBase::Society, 10, false, false, QString::fromLatin1( "de" ) )
 };
 
 ArticleFilter::ArticleFilter(const QString &action, const QString &newsSource,
@@ -302,7 +319,7 @@ bool ArticleFilter::matches(Article::Ptr a) const
 	else if (condition() == i18n("don't equal"))
 		matches = (a->headline() != expression());
 	else { // condition() == i18n("match")
-		QRegExp3 regexp = QRegExp3(expression());
+		QRegExp regexp = QRegExp(expression());
 		matches = regexp.exactMatch(a->headline());
 	}
 	
