@@ -103,8 +103,8 @@ void XMLNewsSource::processData(const QByteArray &data, bool okSoFar)
 			QString headline, address;
 			for (unsigned int i = 0; i < items.count(); i++) {
 				itemNode = items.item(i);
-				headline = decodeEntities(itemNode.namedItem(QString::fromLatin1("title")).toElement().text().simplifyWhiteSpace());
-				address = decodeEntities(itemNode.namedItem(QString::fromLatin1("link")).toElement().text().simplifyWhiteSpace());
+				headline = KCharsets::resolveEntities(itemNode.namedItem(QString::fromLatin1("title")).toElement().text().simplifyWhiteSpace());
+				address = KCharsets::resolveEntities(itemNode.namedItem(QString::fromLatin1("link")).toElement().text().simplifyWhiteSpace());
 				m_articles.append(XMLNewsArticle(headline, address));
 			}
 		}
@@ -115,16 +115,4 @@ void XMLNewsSource::processData(const QByteArray &data, bool okSoFar)
 	emit loadComplete(this, validContent);
 }
 
-QString XMLNewsSource::decodeEntities(const QString &s) const
-{
-	QString result = s;
-	result.replace(QRegExp(QString::fromLatin1("&amp;")), QString::fromLatin1("&"));
-	for (int p = result.find(QString::fromLatin1("&")); p >= 0; p = result.find(QString::fromLatin1("&"), p)) {
-		int q = result.find(QString::fromLatin1(";"), p++);
-		if (q != -1)
-			result.replace(p - 1, q - p + 2, KGlobal::charsets()->fromEntity(result.mid(p, q - p)));
-	}
-	return result;
-}
-
 #include "xmlnewsaccess.moc"
