@@ -78,13 +78,7 @@ NewsSourceBase::Data NewsSourceItem::data() const
 	nsd.maxArticles = text(2).toUInt();
 	nsd.icon = m_icon;
 	nsd.isProgram = m_isProgram;
-	for (unsigned int i = 0; i < DEFAULT_SUBJECTS; i++) {
-		NewsSourceBase::Subject subject = static_cast<NewsSourceBase::Subject>(i);
-		if (m_parent->text(0) == NewsSourceBase::subjectText(subject)) {
-			nsd.subject = subject;
-			break;
-		}
-	}
+	nsd.subject = m_subject;
 	return nsd;
 }
 
@@ -97,6 +91,7 @@ void NewsSourceItem::setData(const NewsSourceBase::Data &nsd)
 
 	m_icon = nsd.icon;
 	m_isProgram = nsd.isProgram;
+	m_subject = nsd.subject;
 	m_newsIconMgr->getIcon(m_icon);
 }
 
@@ -524,6 +519,28 @@ void KCMNewsTicker::slotModifyNewsSource()
 
 void KCMNewsTicker::slotModifyNewsSource(const NewsSourceBase::Data &nsd)
 {
+	if (m_modifyItem->data().subject != nsd.subject) {
+		QListViewItem *parentItem = m_modifyItem->parentItem();
+		parentItem->takeItem(m_modifyItem);
+		if (parentItem->childCount() == 0)
+			delete parentItem;
+
+		CategoryItem *catItem = 0L;
+
+		for (QListViewItemIterator it(m_child->lvNewsSources); it.current(); it++) {
+			if (it.current()->text(0) == NewsSourceBase::subjectText(nsd.subject)) {
+				catItem = static_cast<CategoryItem *>(it.current());
+				break;
+			}
+		}
+
+		if (!catItem)
+			catItem = new CategoryItem(m_child->lvNewsSources,
+			                           NewsSourceBase::subjectText(nsd.subject));
+
+		catItem->insertItem(m_modifyItem);
+	}
+
 	m_modifyItem->setData(nsd);
 
 	// FIXME: Only emit changed(true) in case nsd != m_modifyItem->data()
@@ -653,7 +670,7 @@ extern "C"
 	KCModule *create_knewsticker(QWidget *parent, const char *)
 	{
 		return new KCMNewsTicker(parent, "kcmnewsticker");
-	};
+	}
 }
 
 #include "kcmnewsticker.moc"
