@@ -47,22 +47,22 @@ KNewsTicker::KNewsTicker(const QString &cfgFile, Type t, int actions, QWidget *p
 	m_updateTimer(new QTimer(this)),
 	m_newsIconMgr(NewsIconMgr::self()),
 	m_aboutData(new KAboutData("knewsticker", I18N_NOOP("KNewsTicker"), "v0.2",
-			I18N_NOOP("A newsticker applet."), KAboutData::License_BSD,
+			I18N_NOOP("A news ticker applet."), KAboutData::License_BSD,
 			I18N_NOOP("(c) 2000, 2001 The KNewsTicker developers"))),
 	m_contextMenu(0L)
 {
 	QHBoxLayout *layout = new QHBoxLayout(this);
-
+	
 	m_arrowButton = new KArrowButton(this);
 	QToolTip::add(m_arrowButton, i18n("Show menu"));
 	connect(m_arrowButton, SIGNAL(clicked()), SLOT(slotArrowButtonPressed()));
 	m_arrowButton->setFocusPolicy(NoFocus);
 	setupArrowButton();
 	layout->addWidget(m_arrowButton);
-
+	
 	m_scroller = new NewsScroller(this, m_cfg);
 	layout->addWidget(m_scroller);
-
+	
 	m_dcopClient->registerAs("knewsticker", false);
 
 	QToolTip::add(m_scroller, QString::null);
@@ -78,7 +78,7 @@ KNewsTicker::KNewsTicker(const QString &cfgFile, Type t, int actions, QWidget *p
 				" and much more"), "malte@kde.org");
 	m_aboutData->addAuthor("Wilco Greven", I18N_NOOP("Mouse wheel support"),
 			"greven@kde.org");
-	m_aboutData->addAuthor("Adriaan de Groot", I18N_NOOP("Rotated scrolltext"
+	m_aboutData->addAuthor("Adriaan de Groot", I18N_NOOP("Rotated scrolling text"
 			" modes"), "adridg@sci.kun.nl");
 
 	reparseConfig();
@@ -104,11 +104,7 @@ int KNewsTicker::widthForHeight(int) const
 
 void KNewsTicker::preferences()
 {
-	KProcess p;
-	p << locate("exe", QString::fromLatin1("kdeinit_wrapper"));
-	p << locate("exe", QString::fromLatin1("kcmshell"));
-	p << QString::fromLatin1("Network/kcmnewsticker");
-	p.start(KProcess::DontCare);
+	kapp->startServiceByDesktopName("kcmnewsticker");
 }
 
 void KNewsTicker::about()
@@ -323,7 +319,7 @@ void KNewsTicker::slotNotifyOfFailures()
 		notification += QString::fromLatin1("</ul></qt>");
 	} else
 		notification = i18n("Failed to update several news"
-					" sites. The internet connection might be cut.");
+					" sites. The Internet connection might be cut.");
 	
 	KNotifyClient::event(QString::fromLatin1("InvalidRDF"), notification);
 }
@@ -331,7 +327,8 @@ void KNewsTicker::slotNotifyOfFailures()
 void KNewsTicker::setInterval(const uint interval)
 {
 	m_cfg->setInterval(interval);
-	m_newsTimer->changeInterval(interval * 60 * 1000);
+	if ( interval > 4 )
+		m_newsTimer->changeInterval(interval * 60 * 1000);
 }
 
 void KNewsTicker::setScrollingSpeed(const uint scrollingSpeed)
@@ -373,7 +370,8 @@ void KNewsTicker::setOfflineMode(bool offlineMode)
 	if (offlineMode)
 		m_newsTimer->stop();
 	else
-		m_newsTimer->start(m_cfg->interval() * 1000 * 60);
+		if ( m_cfg->interval() > 4 )
+			m_newsTimer->start(m_cfg->interval() * 1000 * 60);
 
 	m_cfg->setOfflineMode(offlineMode);
 }
@@ -490,9 +488,9 @@ KNewsTickerMenu::KNewsTickerMenu(KNewsTicker *parent, const char *name)
 	setItemChecked(index - 1, parent->m_cfg->offlineMode());
 	insertSeparator();
 	insertItem(helpIcon, i18n("Help"), index++);
-	insertItem(helpIcon, i18n("About"), index++);
+	insertItem(logoIcon, i18n("About KNewsTicker"), index++);
 	insertSeparator();
-	insertItem(confIcon, i18n("Preferences..."), index);
+	insertItem(confIcon, i18n("Configure KNewsTicker..."), index);
 
 	m_idx = index;
 }
@@ -561,8 +559,9 @@ extern "C"
 	{
 		KGlobal::locale()->insertCatalogue(QString::fromLatin1("knewsticker"));
 		return new KNewsTicker(configFile, KPanelApplet::Stretch,
-				KPanelApplet::Preferences | KPanelApplet::About | KPanelApplet::ReportBug,
-			  parent, "knewsticker");
+				KPanelApplet::Preferences | KPanelApplet::About | 
+                KPanelApplet::Help | KPanelApplet::ReportBug,
+			    parent, "knewsticker");
 	}
 }
 
