@@ -180,7 +180,7 @@ void NewsScroller::dropEvent(QDropEvent* event)
 				" the list of news sources?</p><p>Press 'Yes' to add the news source to"
 				" the list, press 'No' to cancel and close this dialog.</p>")
 					.arg(newSourceUrl)) == KMessageBox::Yes) {
-			KConfig cfg(QString::fromLatin1("knewsticker_appletrc"), false, false);
+			KConfig cfg(QString::fromLatin1("knewsticker_panelappletrc"), false, false);
 			ConfigAccess configFrontend(&cfg);
 			QStringList newsSources = configFrontend.newsSources();
 
