@@ -51,11 +51,11 @@ KNGroupBrowser::KNGroupBrowser(QWidget *parent, const QString &caption, KNNntpAc
 
   filterEdit=new KLineEdit(page);
   QLabel *l=new QLabel(filterEdit,i18n("S&earch:"), page);
-  noTreeCB=new QCheckBox(i18n("disable &tree view"), page);
+  noTreeCB=new QCheckBox(i18n("Disable &tree view"), page);
   noTreeCB->setChecked(false);
-  subCB=new QCheckBox(i18n("&subscribed only"), page);
+  subCB=new QCheckBox(i18n("&Subscribed only"), page);
   subCB->setChecked(false);
-  newCB=new QCheckBox(i18n("&new only"), page);
+  newCB=new QCheckBox(i18n("&New only"), page);
   if (!newCBact)
     newCB->hide();
   newCB->setChecked(false);
@@ -148,6 +148,7 @@ KNGroupBrowser::~KNGroupBrowser()
 
   delete matchList;
   delete allList;
+  delete refilterTimer;
 }
 
 
@@ -314,7 +315,7 @@ void KNGroupBrowser::slotFilter(const QString &txt)
   bool notCheckNew = !newCB->isChecked();
   bool notCheckStr = (filtertxt.isEmpty());
 
-  bool isRegexp = filtertxt.contains(QRegExp("[^a-z0-9\\-.]"));
+  bool isRegexp = filtertxt.contains(QRegExp("[^a-z0-9\\-\\+.]"));
 
   bool doIncrementalUpdate = (!isRegexp && incrementalFilter && (filtertxt.left(lastFilter.length())==lastFilter));
 
