@@ -1,7 +1,7 @@
 /*
 * edrop.cpp -- Implementation of class KExternDrop.
 * Author:	Sirtaj Singh Kang
-* Version:	$Id: edrop.cpp,v 1.5 2000/07/11 00:27:13 matz Exp $
+* Version:	$Id: edrop.cpp,v 1.6 2002/06/29 15:20:37 gioele Exp $
 * Generated:	Sat Nov 21 18:50:02 EST 1998
 */
 
@@ -26,7 +26,8 @@ bool KExternDrop::startMonitor()
 
 //	debug( "proc start: %s", _command.data() );
 
-	_process = new KShellProcess;
+	_process = new KProcess;
+	_process->setUseShell( true );
 	// only reading stdin yet
 	connect( _process,SIGNAL(receivedStdout( KProcess *, char *, int)),
 			this, 
