@@ -1,6 +1,7 @@
 
 #include<assert.h>
 
+#include <qstring.h>
 #include<qtooltip.h>
 
 #include<kdebug.h>
@@ -55,11 +56,7 @@ void KornButton::setNumber(int num)
 	_style->update( _box->count(), newMessages );
 
 	if (newMessages && !_box->newMailCmd().isEmpty())
-	{
-		KShellProcess * proc = new KShellProcess;
-		*proc << _box->newMailCmd();
-		proc->start();
-	}
+		executeCmd(_box->newMailCmd());
 }
 
 void KornButton::runCommand(bool onlyIfUnread)
@@ -82,12 +79,21 @@ void KornButton::runCommand(bool onlyIfUnread)
 
   kdDebug() << "KornButton::runCommand: clickCmd == `" << _box->clickCmd() << "'" << endl;
 
-  if (!_box->clickCmd().isEmpty())
-	{
-		KShellProcess * proc = new KShellProcess;
-		*proc << _box->clickCmd();
-		proc->start();
-	}
+	if (!_box->clickCmd().isEmpty())
+		executeCmd(_box->clickCmd());
+}
+
+void KornButton::executeCmd(QString cmd) {
+	KProcess* proc = new KProcess;
+	proc->setUseShell(true);
+	*proc << cmd;
+	connect(proc, SIGNAL(processExited(KProcess*)),
+	        this, SLOT(commandRun(KProcess*)));
+	proc->start();
+}
+
+void KornButton::commandRun(KProcess* proc) {
+	delete proc;
 }
 
 void KornButton::disconnectMonitor()
