@@ -1,7 +1,7 @@
 /*
 * newscfg.cpp -- Implementation of class KNewsCfg.
 * Author:	Sirtaj Singh Kang
-* Version:	$Id: newscfg.cpp,v 1.6 2001/12/13 20:11:57 mueller Exp $
+* Version:	$Id: newscfg.cpp,v 1.7 2002/07/01 18:26:04 binner Exp $
 * Generated:	Mon Aug  3 15:41:58 EST 1998
 */
 
@@ -37,13 +37,13 @@ QWidget *KNewsCfg::makeWidget( QWidget *parent )
 	QGridLayout *layout = new QGridLayout( dlg, 3, 2, 10 );
 	layout->addRowSpacing(0,10);
 
-	QLabel *aLabel = new QLabel( i18n("Server"), dlg );
+	QLabel *aLabel = new QLabel( i18n("Server:"), dlg );
 	layout->addWidget(aLabel, 1, 0);
 
 	_serverEdit = new QLineEdit( d->server(), dlg);
 	layout->addWidget(_serverEdit, 1, 1);
 
-	aLabel = new QLabel( i18n("Group"), dlg );
+	aLabel = new QLabel( i18n("Group:"), dlg );
 	layout->addWidget(aLabel, 2, 0);
 
 	_groupEdit = new QLineEdit( d->group(), dlg );
