@@ -34,6 +34,7 @@
 #include "Defines.h"
 #include "ErrorMessageConfigDialog.h"
 #include "ConfigDialogPage.h"
+#include "WebServerManager.h"
 #include "WebServer.h"
 
 namespace KPF
@@ -43,11 +44,11 @@ namespace KPF
       server_                   (server),
       errorMessageConfigDialog_ (0L)
   {
-    l_listenPort_       = new QLabel(i18n("Listen &port"),      this);
-    l_bandwidthLimit_   = new QLabel(i18n("&Bandwidth limit"),  this);
+    l_listenPort_       = new QLabel(i18n("&Listen port:"),      this);
+    l_bandwidthLimit_   = new QLabel(i18n("&Bandwidth limit:"),  this);
 //    l_connectionLimit_  = new QLabel(i18n("Connection &limit"), this);
 
-    sb_listenPort_      = new QSpinBox(1000,  65535, 1, this);
+    sb_listenPort_      = new QSpinBox(1,  65535, 1, this);
     sb_bandwidthLimit_  = new QSpinBox(1,     999999, 1, this);
 //    sb_connectionLimit_ = new QSpinBox(1,     9999,   1, this);
 
@@ -64,14 +65,15 @@ namespace KPF
     l_bandwidthLimit_   ->setBuddy(sb_bandwidthLimit_);
 //    l_connectionLimit_  ->setBuddy(sb_connectionLimit_);
 
-    sb_listenPort_      ->setValue(Config::DefaultListenPort);
+    sb_listenPort_
+      ->setValue(WebServerManager::instance()->nextFreePort());
+
     sb_bandwidthLimit_  ->setValue(Config::DefaultBandwidthLimit);
-    sb_bandwidthLimit_  ->setSuffix(i18n("kB/s"));
+    sb_bandwidthLimit_  ->setSuffix(i18n(" kB/s"));
 //    sb_connectionLimit_ ->setValue(Config::DefaultConnectionLimit);
     cb_followSymlinks_  ->setChecked(Config::DefaultFollowSymlinks);
 
-    QVBoxLayout * l0 =
-      new QVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
+    QVBoxLayout * l0 = new QVBoxLayout(this, 0, KDialog::spacingHint());
 
     QGridLayout * l2 = new QGridLayout(l0);
 
@@ -111,7 +113,6 @@ namespace KPF
       );
 #endif
 
-
     QString listenPortHelp =
       i18n
       (
@@ -176,6 +177,28 @@ namespace KPF
     QWhatsThis::add(cb_followSymlinks_,   followSymlinksHelp);
 //    QWhatsThis::add(pb_errorMessages_,    errorMessagesHelp);
 
+    connect
+      (
+        sb_listenPort_,
+        SIGNAL(valueChanged(int)),
+        SLOT(slotListenPortChanged(int))
+      );
+
+    connect
+      (
+        sb_bandwidthLimit_,
+        SIGNAL(valueChanged(int)),
+        SLOT(slotBandwidthLimitChanged(int))
+      );
+
+    connect
+      (
+        cb_followSymlinks_,
+        SIGNAL(toggled(bool)),
+        SLOT(slotFollowSymlinksToggled(bool))
+      );
+
+
     load();
   }
 
@@ -218,7 +241,59 @@ namespace KPF
 
     errorMessageConfigDialog_->show();
   }
-}
 
+    void
+  ConfigDialogPage::slotListenPortChanged(int)
+  {
+    kpfDebug << "slotBandwidthLimitChanged" << endl;
+    checkOkAndEmit();
+  }
+
+  void ConfigDialogPage::checkOk()
+  {
+    kpfDebug << "slotBandwidthLimitChanged" << endl;
+    checkOkAndEmit();
+  }
+
+  void ConfigDialogPage::slotBandwidthLimitChanged(int)
+  {
+    kpfDebug << "slotBandwidthLimitChanged" << endl;
+    checkOkAndEmit();
+  }
+
+  void ConfigDialogPage::slotFollowSymlinksToggled(bool)
+  {
+    kpfDebug << "slotBandwidthLimitChanged" << endl;
+    checkOkAndEmit();
+  }
+
+  void ConfigDialogPage::checkOkAndEmit()
+  {
+    int newPort = sb_listenPort_->value();
+
+    if (newPort <= 1024)
+    {
+      emit(ok(false));
+      return;
+    }
+
+    QPtrList<WebServer>
+      serverList(WebServerManager::instance()->serverListLocal());
+
+    for (QPtrListIterator<WebServer> it(serverList); it.current(); ++it)
+    {
+      if (it.current() == server_)
+        continue;
+
+      if (it.current()->listenPort() == uint(newPort))
+      {
+        emit(ok(false));
+        return;
+      }
+    }
+
+    emit(ok(true));
+  }
+}
 #include "ConfigDialogPage.moc"
 // vim:ts=2:sw=2:tw=78:et
