@@ -28,6 +28,8 @@
 #include "ServerPrivate.h"
 #include "Utils.h"
 
+#undef KPF_TRAFFIC_DEBUG
+
 namespace KPF
 {
   static const uint IncomingDataLimit = 8 * 1024;     // kB.
@@ -128,11 +130,13 @@ namespace KPF
 
       QString line(d->socket.readLine().stripWhiteSpace());
 
+#ifdef KPF_TRAFFIC_DEBUG
       kpfDebug
         << d->id
         << ": Adding line to incomingLineBuffer: "
         << line
         << endl;
+#endif
 
       d->incomingLineBuffer.append(line);
     }
@@ -194,10 +198,12 @@ namespace KPF
   {
     ++d->requestCount;
 
+#ifdef KPF_TRAFFIC_DEBUG
     kpfDebug
       << d->id
       << ": (request #" << d->requestCount << ") readRequest: `"
       << line << "'" << endl;
+#endif
 
     QStringList l(QStringList::split(' ', line));
 
@@ -258,6 +264,33 @@ namespace KPF
       return false;
     }
 
+    if (d->request.protocol() > 1.1)
+    {
+      if (d->request.protocol() >= 2.0)
+      {
+        kpfDebug
+          << d->id
+          << ": readRequest: unsupported protocol major number"
+          << endl;
+
+        d->request.setProtocol(1, 1);
+
+        d->state = Responding;
+        respond(505);
+        emit(readyToWrite(this));
+        return false;
+      }
+      else
+      {
+        kpfDebug
+          << d->id
+          << ": readRequest: unsupported protocol minor number"
+          << endl;
+
+        d->request.setProtocol(1, 1);
+      }
+    }
+
     if (d->request.protocol() >= 1.0)
     {
       kpfDebug
@@ -399,9 +432,13 @@ namespace KPF
       return;
     }
 
-    if ((Request::Get == d->request.method()) && !d->resource.open())
+//    if ((Request::Get == d->request.method()) && !d->resource.open())
+    // Open resource even if we're asked for HEAD. We need to ensure
+    // Content-Length is sent correctly.
+
+    if (!d->resource.open())
     {
-      // GET request but couldn't open the file. XXX why not ?
+      // Couldn't open the file. XXX why not ?
 
       respond(403);
       return;
@@ -933,12 +970,14 @@ namespace KPF
       return false;
     }
 
+#ifdef KPF_TRAFFIC_DEBUG
     kpfDebug
       << d->id
       << ": Wrote header data: `"
       << d->outgoingHeaderBuffer.left(headerPos)
       << "'"
       << endl;
+#endif
 
     // Subtract the number of bytes we wrote from the number of bytes
     // left to write.
@@ -1003,12 +1042,14 @@ namespace KPF
       return false;
     }
 
+#ifdef KPF_TRAFFIC_DEBUG
     kpfDebug
       << d->id
       << ": Wrote file data: `"
       << QCString(a.data(), fileBytesWritten)
       << "'"
       << endl;
+#endif
 
     // We should have been able to write the full amount to the socket,
     // because we tested d->socket.outputBufferLeft(). If we didn't
