@@ -1,7 +1,7 @@
 /* -*- C++ -*-
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: accounting.h,v 1.14 2000/07/30 21:09:57 bieker Exp $
+ * $Id: accounting.h,v 1.15 2002/08/27 22:13:08 porten Exp $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -43,10 +43,10 @@ public:
   AccountingBase(QObject *parent);
   virtual ~AccountingBase();
 
-  virtual double total();
-  virtual double session();
+  virtual double total() const;
+  virtual double session() const;
 
-  virtual bool running() { return false; };
+  virtual bool running() const { return false; };
   virtual bool loadRuleSet(const QString & name) = 0;
 
 public slots:
@@ -84,11 +84,11 @@ class Accounting : public AccountingBase {
 public:
   Accounting(QObject *parent, PPPStats *st);
 
-  virtual double total();
-  virtual double session();
+  virtual double total() const;
+  virtual double session() const;
 
   virtual bool loadRuleSet(const QString & name);
-  virtual bool running();
+  virtual bool running() const;
 
 private:
   virtual void timerEvent(QTimerEvent *t);
@@ -122,7 +122,7 @@ public:
   ExecutableAccounting(PPPStats *st, QObject *parent = 0);
 
   virtual bool loadRuleSet(const QString & );
-  virtual bool running();
+  virtual bool running() const;
 
 public slots:
   virtual void slotStart();
