@@ -12,7 +12,7 @@
 //
 //---------------------------------------------------------------------------
 //  
-//  $Id: acctselect.h,v 1.7 2002/01/22 12:35:29 winkvist Exp $
+//  $Id: acctselect.h,v 1.8 2002/04/07 18:57:06 cumming Exp $
 //
 //---------------------------------------------------------------------------
 // 
@@ -38,14 +38,14 @@
 #include <qwidget.h>
 #include <qpixmap.h>
 #include <qdir.h>
-#include "groupbox.h"
 
+class QCheckBox;
 class QComboBox;
 class QLabel;
 class QListView;
 class QListViewItem;
 
-class AccountingSelector : public KCheckGroupBox {
+class AccountingSelector : public QWidget {
   Q_OBJECT
 public:
   AccountingSelector(QWidget *parent = 0, bool _isnewaccount = false, const char *name = 0);
@@ -61,10 +61,12 @@ private:
   QString nameToFileName(QString);
 
 private slots:
+  void openURL(const QString &);
   void enableItems(bool);
   void slotSelectionChanged(QListViewItem* i);
 
 private:
+  QCheckBox *enable_accounting;
   QListView *tl;
   QComboBox *use_vol;
   QPixmap pmfolder, pmfile;
