@@ -2,7 +2,7 @@
  *
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: kpppwidget.cpp,v 1.4 2002/03/18 21:04:53 staikos Exp $
+ * $Id: kpppwidget.cpp,v 1.13 2002/09/21 22:36:34 cumming Exp $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -34,7 +34,7 @@
 #include <qlabel.h>
 #include <qpushbutton.h>
 #include <qregexp.h>
-#include <qtabdialog.h>
+#include <kdialogbase.h>
 #include <qwhatsthis.h>
 
 #include <kaboutdata.h>
@@ -49,6 +49,9 @@
 #include <kseparator.h>
 #include <kstandarddirs.h>
 #include <kwin.h>
+#include <khelpmenu.h>
+#include <kpushbutton.h>
+#include <kguiitem.h>
 
 #include <stdlib.h>
 #include <errno.h>
@@ -85,9 +88,6 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
 
   QVBoxLayout *tl = new QVBoxLayout(this, 10, 10);
 
-  fline1 = new KSeparator( KSeparator::HLine, this);
-  tl->addWidget(fline1);
-
   QGridLayout *l1 = new QGridLayout(3, 4);
   tl->addLayout(l1);
   l1->addColSpacing(0, 10);
@@ -95,20 +95,22 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
   l1->setColStretch(1, 3);
   l1->setColStretch(2, 4);
 
-  label1 = new QLabel(i18n("Connect to: "), this);
+  label1 = new QLabel(i18n("C&onnect to: "), this);
   l1->addWidget(label1, 0, 1);
 
   connectto_c = new QComboBox(false, this);
+  label1->setBuddy(connectto_c);
 
   connect(connectto_c, SIGNAL(activated(int)),
 	  SLOT(newdefaultaccount(int)));
   l1->addWidget(connectto_c, 0, 2);
 
-  ID_Label = new QLabel(i18n("Login ID:"), this);
+  ID_Label = new QLabel(i18n("&Login ID:"), this);
   l1->addWidget(ID_Label, 1, 1);
 
   // the entry line for usernames
   ID_Edit = new QLineEdit(this);
+  ID_Label->setBuddy(ID_Edit);
   l1->addWidget(ID_Edit, 1, 2);
   connect(ID_Edit, SIGNAL(returnPressed()),
 	  this, SLOT(enterPressedInID()));
@@ -123,10 +125,11 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
   QWhatsThis::add(ID_Label,tmp);
   QWhatsThis::add(ID_Edit,tmp);
 
-  PW_Label = new QLabel(i18n("Password:"), this);
+  PW_Label = new QLabel(i18n("&Password:"), this);
   l1->addWidget(PW_Label, 2, 1);
 
   PW_Edit= new QLineEdit(this);
+  PW_Label->setBuddy(PW_Edit);
   PW_Edit->setEchoMode(QLineEdit::Password);
   l1->addWidget(PW_Edit, 2, 2);
   connect(PW_Edit, SIGNAL(returnPressed()),
@@ -148,7 +151,7 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
    tl->addLayout(l3);
    tl->addSpacing(5);
    l3->addSpacing(10);
-   log = new QCheckBox(i18n("Show Log Window"), this);
+   log = new QCheckBox(i18n("Show lo&g window"), this);
    connect(log, SIGNAL(toggled(bool)),
   	  this, SLOT(log_window_toggled(bool)));
    log->setChecked(gpppdata.get_show_log_window());
@@ -170,30 +173,37 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
   tl->addLayout(l2);
 
   int minw = 0;
-  quit_b = new QPushButton(i18n("&Quit"), this);
+  quit_b = new KPushButton(i18n("&Quit"), this);
+  quit_b-> setGuiItem (KGuiItem(i18n("&Quit"), "exit" ) );
   connect( quit_b, SIGNAL(clicked()), SLOT(quitbutton()));
   if(quit_b->sizeHint().width() > minw)
-    minw = quit_b->sizeHint().width();
+      minw = quit_b->sizeHint().width();
 
-  setup_b = new QPushButton(i18n("&Setup"), this);
+  setup_b = new KPushButton(i18n("&Setup..."), this);
+  setup_b->setGuiItem (KGuiItem(i18n("&Setup...")) );
   connect( setup_b, SIGNAL(clicked()), SLOT(expandbutton()));
   if(setup_b->sizeHint().width() > minw)
-    minw = setup_b->sizeHint().width();
+      minw = setup_b->sizeHint().width();
 
   if(gpppdata.access() != KConfig::ReadWrite)
     setup_b->setEnabled(false);
 
-  help_b = new QPushButton(i18n("?"), this);
+  help_b = new KPushButton(i18n("&Help"), this);
   connect( help_b, SIGNAL(clicked()), SLOT(helpbutton()));
+
+  KHelpMenu *helpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData(), true);
+  help_b->setPopup((QPopupMenu*)helpMenu->menu());
+  help_b->setGuiItem (KGuiItem(i18n("&Help"), "help" ) );
+
   if(help_b->sizeHint().width() > minw)
-    minw = help_b->sizeHint().width();
+      minw = help_b->sizeHint().width();
 
   connect_b = new QPushButton(i18n("&Connect"), this);
   connect_b->setDefault(true);
   connect_b->setFocus();
   connect(connect_b, SIGNAL(clicked()), SLOT(beginConnect()));
   if(connect_b->sizeHint().width() > minw)
-    minw = connect_b->sizeHint().width();
+      minw = connect_b->sizeHint().width();
 
   quit_b->setFixedWidth(minw);
   setup_b->setFixedWidth(minw);
@@ -218,7 +228,7 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
 
   KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
 
-  // constructor of con_win reads position from config file  
+  // constructor of con_win reads position from config file
   con_win = new ConWindow(0, "conw", this, stats);
   KWin::setIcons(con_win->winId(), kapp->icon(), kapp->miniIcon());
 
@@ -257,7 +267,7 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
 	  this, SLOT(saveMyself()));
   connect(KApplication::kApplication(), SIGNAL(shutDown()),
 	  this, SLOT(shutDown()));
-	  
+
   debugwindow->setGeometry(desk.center().x()+190, desk.center().y()-55,
 			   debugwindow->width(),debugwindow->height());
 
@@ -275,16 +285,16 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
   }
 
   if(m_bCmdlAccount){
-    bool result;
-    result = gpppdata.setAccount(m_strCmdlAccount);
+    bool result = gpppdata.setAccount(m_strCmdlAccount);
     if (!result){
       QString string;
       string = i18n("No such Account:\n%1").arg(m_strCmdlAccount);
       KMessageBox::error(this, string);
       m_bCmdlAccount = false;
       this->show();
-    } else
-      emit cmdl_start();
+    } else {
+      beginConnect();
+    }
   } else
     show();
 
@@ -333,32 +343,27 @@ bool KPPPWidget::eventFilter(QObject *o, QEvent *e) {
 
 void KPPPWidget::prepareSetupDialog() {
   if(tabWindow == 0) {
-    tabWindow = new QTabDialog( kapp->mainWidget(), 0, TRUE );
+    tabWindow = new KDialogBase( KDialogBase::Tabbed, i18n("KPPP Configuration"),
+                                 KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok,
+                                 kapp->mainWidget(), 0, true);
+
+
     KWin::setIcons(tabWindow->winId(), kapp->icon(), kapp->miniIcon());
-    tabWindow->setCaption( i18n("kppp Configuration") );
-    tabWindow->setOkButton(i18n("OK"));
-    tabWindow->setCancelButton(i18n("Cancel"));
+
     //    tabWindow->setFixedSize( 365, 375 );
 
-    accounts = new AccountWidget(tabWindow,"accounts");
+    accounts = new AccountWidget(tabWindow->addPage( i18n("&Accounts"), i18n("Account Setup") ) );
     connect(accounts, SIGNAL(resetaccounts()),
 	    this, SLOT(resetaccounts()));
     connect(accounts, SIGNAL(resetCosts(const QString &)),
 	    this, SLOT(resetCosts(const QString &)));
     connect(accounts, SIGNAL(resetVolume(const QString &)),
 	    this, SLOT(resetVolume(const QString &)));
-    modem1 = new ModemWidget(tabWindow);
-    modem2 = new ModemWidget2(tabWindow);
-    general = new GeneralWidget(tabWindow);
-    graph = new GraphSetup(tabWindow);
-    about  = new AboutWidget(tabWindow);
 
-    tabWindow->addTab( accounts, i18n("Accounts") );
-    tabWindow->addTab( modem1, i18n("Device") );
-    tabWindow->addTab( modem2, i18n("Modem") );
-    tabWindow->addTab( graph, i18n("Graph") );
-    tabWindow->addTab( general, i18n("Misc.") );
-    tabWindow->addTab( about, i18n("About") );
+    modem1 = new ModemWidget( tabWindow->addPage( i18n("&Device"), i18n("Serial Device") ) );
+    modem2 = new ModemWidget2( tabWindow->addPage( i18n("&Modem"), i18n("Modem Settings") ) );
+    graph = new GraphSetup( tabWindow->addPage( i18n("&Graph"), i18n("Throughput Graph" ) ) );
+    general = new GeneralWidget( tabWindow->addPage( i18n("M&isc"), i18n("Miscellaneous Settings") ) );
   }
 }
 
@@ -522,14 +527,14 @@ void KPPPWidget::sigPPPDDied() {
 	if(KMessageBox::warningYesNo(0, msg, i18n("Error"), i18n("&OK"), i18n("&Details...")) == KMessageBox::No)
 	  PPPL_ShowLog();
       } else { /* reconnect on disconnect */
-	kdDebug(5002) << "Trying to reconnect ... " << endl;
+	kdDebug(5002) << "Trying to reconnect... " << endl;
 
         if(gpppdata.authMethod() == AUTH_PAP ||
 	   gpppdata.authMethod() == AUTH_CHAP ||
 	   gpppdata.authMethod() == AUTH_PAPCHAP)
           Requester::rq->setSecret(gpppdata.authMethod(),
 				   encodeWord(gpppdata.storedUsername()),
-				   encodeWord(gpppdata.password));
+				   encodeWord(gpppdata.password()));
 
 	con_win->hide();
 	con_win->stopClock();
@@ -549,9 +554,9 @@ void KPPPWidget::sigChld() {
   //  if(id == helperPid && helperPid != -1) {
   //    kdDebug(5002) << "It was the setuid child that died" << endl;
  // helperPid = -1;
-    QString msg = i18n("Sorry. kppp's helper process just died.\n"
+    QString msg = i18n("kppp's helper process just died.\n"
                        "Since a further execution would be pointless, "
-                       "kppp will shut down right now.");
+                       "kppp will shut down now.");
     KMessageBox::error(0L, msg);
     remove_pidfile();
     exit(1);
@@ -575,8 +580,12 @@ void KPPPWidget::expandbutton() {
 void KPPPWidget::beginConnect() {
   // make sure to connect to the account that is selected in the combo box
   // (exeption: an account given by a command line argument)
-  if(!m_bCmdlAccount)
+  if(!m_bCmdlAccount) {
     gpppdata.setAccount(connectto_c->currentText());
+    gpppdata.setPassword(PW_Edit->text());
+  } else {
+    gpppdata.setPassword(gpppdata.storedPassword());
+  }
 
   QFileInfo info(pppdPath());
 
@@ -608,13 +617,11 @@ void KPPPWidget::beginConnect() {
 		   "your modem device properly "
 		   "and/or adjust the location of the modem device on "
 		   "the modem tab of "
-		   "the setup dialog.\nThank You").arg(gpppdata.modemDevice());
+		   "the setup dialog.").arg(gpppdata.modemDevice());
     KMessageBox::error(this, string);
     return;
   }
 
-  gpppdata.setPassword(PW_Edit->text());
-
   // if this is a PAP or CHAP account, ensure that username is
   // supplied
   if(gpppdata.authMethod() == AUTH_PAP ||
@@ -628,10 +635,9 @@ void KPPPWidget::beginConnect() {
 			   "supply a username and a password!"));
       return;
     } else {
-      gpppdata.password = PW_Edit->text();
       if(!Requester::rq->setSecret(gpppdata.authMethod(),
 				   encodeWord(gpppdata.storedUsername()),
-				   encodeWord(gpppdata.password))) {
+				   encodeWord(gpppdata.password()))) {
 	QString s;
 	s = i18n("Cannot create PAP/CHAP authentication\n"
 				     "file \"%1\"").arg(PAP_AUTH_FILE);
@@ -672,7 +678,7 @@ void KPPPWidget::disconnect() {
   if (!gpppdata.command_before_disconnect().isEmpty()) {
     con_win->hide();
     con->show();
-    con->setCaption(i18n("Disconnecting ..."));
+    con->setCaption(i18n("Disconnecting..."));
     con->setMsg(i18n("Executing command before disconnection."));
 
     kapp->processEvents();
@@ -853,7 +859,7 @@ void KPPPWidget::setQuitOnDisconnect (bool b)
 }
 
 void KPPPWidget::showNews() {
-#ifdef KPPP_SHOW_NEWS 
+#ifdef KPPP_SHOW_NEWS
   /*
    * Introduce the QuickHelp feature to new users of this version
    */
@@ -901,9 +907,9 @@ void KPPPWidget::showNews() {
     l2->addWidget(cb);
     tl->addWidget(bbox);
 
-    QString tmp = i18n("This is an example for <b>QuickHelp</b>.\n"
+    QString tmp = i18n("This is an example of <b>QuickHelp</b>.\n"
 		       "This window will stay open until you\n"
-		       "click a mouse button or a hit a key.\n");
+		       "click a mouse button or a press a key.\n");
 
     QWhatsThis::add(cb,tmp);
     QWhatsThis::add(l, tmp);
