@@ -2,7 +2,7 @@
 /*
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: opener.cpp,v 1.56 2002/02/02 10:01:01 leitner Exp $
+ * $Id: opener.cpp,v 1.57.2.3 2002/12/16 13:25:01 lunakl Exp $
  *
  *              Copyright (C) 1997,98 Bernd Johannes Wuebben,
  *		                      Mario Weilguni
@@ -34,14 +34,18 @@
  * o be paranoid and think twice about everything you change.
  */
 
-#include "kpppconfig.h"
+#include <config.h>
 
 #if defined(__osf__) || defined(__svr4__)
 #define _POSIX_PII_SOCKET
 extern "C" int sethostname(char *name, int name_len);
+#if !defined(__osf__)
 extern "C" int _Psendmsg(int, void*, int);
 extern "C" int _Precvmsg(int, void*, int);
 #endif
+#endif
+
+#include "kpppconfig.h"
 
 #include <sys/types.h>
 #include <sys/uio.h>
@@ -199,10 +203,8 @@ void Opener::mainLoop() {
 
 	device = deviceByIndex(request.lock.deviceNum);
 	MY_ASSERT(strlen(LOCK_DIR)+strlen(device) < MaxPathLen);
-	strncpy(lockfile, LOCK_DIR"/LCK..", MaxPathLen);
-	strncat(lockfile, strrchr(device, '/') + 1,
-		MaxPathLen - strlen(lockfile));
-	lockfile[MaxPathLen] = '\0';
+	strlcpy(lockfile, LOCK_DIR"/LCK..", MaxPathLen);
+	strlcat(lockfile, strrchr(device, '/') + 1, MaxPathLen );
 	response.status = 0;
 	// TODO:
 	//   struct stat st;
@@ -417,7 +419,7 @@ bool Opener::createAuthFile(Auth method, char *username, char *password) {
 
   // look for username, "username" or 'username'
   // if you modify this RE you have to adapt regexp's size above
-  sprintf(regexp, "^[ \t]*%s[ \t]\\|^[ \t]*[\"\']%s[\"\']",
+  snprintf(regexp, sizeof(regexp), "^[ \t]*%s[ \t]\\|^[ \t]*[\"\']%s[\"\']",
           username,username);
   MY_ASSERT(regcomp(&preg, regexp, 0) == 0);
 
@@ -522,7 +524,7 @@ bool Opener::execpppd(const char *arguments) {
     case 0:
       // let's parse the arguments the user supplied into UNIX suitable form
       // that is a list of pointers each pointing to exactly one word
-      strcpy(buf, arguments);
+      strlcpy(buf, arguments, sizeof(buf));
       parseargs(buf, args);
       // become a session leader and let /dev/ttySx
       // be the controlling terminal.
@@ -660,7 +662,7 @@ int checkForInterface()
     if ((s = socket(AF_INET, SOCK_DGRAM, 0)) < 0)
         return 1;               /* can't tell */
 
-    strncpy(ifr.ifr_name, "ppp0", sizeof (ifr.ifr_name));
+    strlcpy(ifr.ifr_name, "ppp0", sizeof (ifr.ifr_name));
     ok = ioctl(s, SIOCGIFFLAGS, (caddr_t) &ifr) >= 0;
     close(s);
 
