@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: pppstatdlg.cpp,v 1.44 2001/07/16 19:47:55 porten Exp $
+ * $Id: pppstatdlg.cpp,v 1.46 2001/12/13 20:12:18 mueller Exp $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -25,16 +25,14 @@
 
 #include <qlayout.h>
 #include <qpainter.h>
-#include <kapp.h>
 #include <kwin.h>
-#include <kglobal.h>
 #include <kiconloader.h>
+#include <kapplication.h>
+#include <klocale.h>
 
 #include "pppdata.h"
 #include "pppstatdlg.h"
-#include "kpppconfig.h"
 #include "iplined.h"
-#include <klocale.h>
 #include "pppstats.h"
 
 extern PPPData gpppdata;
