@@ -10,10 +10,13 @@
 #ifndef FilterRuleEditor_h
 #define FilterRuleEditor_h
 
-#include "FilterRuleEditorData.h"
 #include <qstring.h>
 
-class FilterRuleEditor : public FilterRuleEditorData
+#include <kdialogbase.h>
+
+#include "FilterRuleWidget.h"
+
+class FilterRuleEditor : public KDialogBase
 {
     Q_OBJECT
 
@@ -28,10 +31,10 @@ public:
     virtual ~FilterRuleEditor();
 
 protected slots:
+
      virtual void newRule();
      virtual void OkPressed();
      virtual void deleteRule();
-     virtual void closePressed();
      virtual void newHighlight(int);
      virtual void raiseRule();
      virtual void lowerRule();
@@ -40,5 +43,10 @@ protected:
      void updateListBox(int citem = 0);
      void moveRule(int, int);
      QString convertSpecial(QString);
+
+    FilterRuleWidget *filter;
 };
 #endif // FilterRuleEditor_included
+
+// vim:tabstop=2:shiftwidth=2:expandtab:cinoptions=(s,U1,m1
+
