@@ -20,6 +20,10 @@ class PageRMBMenu;
 class PageServChan;
 */
 
+
+class PageFont; /* For the font settings */
+
+
 class KSPrefs : public KDialogBase
 {
 
@@ -29,7 +33,6 @@ public:
     ~KSPrefs();
 
 public slots:
-    void closeDialog();
     void saveConfig();
     void defaultConfig();
     void readConfig();
@@ -44,6 +47,8 @@ private:
 //    PageRMBMenu  *pageRMBMenu;
     PageStartup  *pageStartup;
 //    PageServChan *pageServChan;
+
+    PageFont *pageFont; /* Font settings page */
     int dirty;
 };
 
