@@ -20,7 +20,7 @@ SpeedDialog::SpeedDialog
 )
   : Inherited( parent, name )
 {
-  setCaption("Speed setup");
+  setCaption("Speed Setup");
   connect(sliderTick, SIGNAL(valueChanged(int)),
 	  lcdTick, SLOT(display(int)));
   connect(sliderStep, SIGNAL(valueChanged(int)),
