@@ -4,7 +4,7 @@
 #include <kcombobox.h>
 #include <qhbox.h>
 #include <qlabel.h>
-
+#include <qlineedit.h>
 #include "NewWindowDialog.h"
 
 NewWindowDialog::NewWindowDialog(QWidget * parent, const char * name)
@@ -22,10 +22,13 @@ NewWindowDialog::NewWindowDialog(QWidget * parent, const char * name)
   connect(
       combo_, SIGNAL(activated(const QString &)),
       combo_, SLOT(addToHistory(const QString &)));
+  connect( combo_->lineEdit(), SIGNAL(textChanged ( const QString & )),
+	   this, SLOT( slotTextChanged( const QString &)));
 
   KConfig *kConfig = kapp->config();
   KConfigGroupSaver saver(kConfig, "Recent");
   combo_->setHistoryItems(kConfig->readListEntry("Channels"));
+  slotTextChanged( combo_->lineEdit()->text());
 }
 
 NewWindowDialog::~NewWindowDialog()
@@ -35,6 +38,12 @@ NewWindowDialog::~NewWindowDialog()
   kConfig->writeEntry("Channels", combo_->historyItems());
 }
 
+void NewWindowDialog::slotTextChanged( const QString &_text)
+{
+  enableButtonOK( !_text.isEmpty() );
+}
+
+
   void
 NewWindowDialog::slotOk()
 {
