@@ -2,7 +2,7 @@
 
  aListBox
 
- $$Id: alistbox.cpp,v 1.36 2001/12/13 20:13:01 mueller Exp $$
+ $$Id: alistbox.cpp,v 1.37 2002/09/28 11:40:45 hausmann Exp $$
 
  List box that outputs a right click mouse so I can popup a qpopupmenu.
 
@@ -19,6 +19,7 @@
 #include <qpainter.h>
 
 #include <kdebug.h>
+#include <kglobal.h>
 
 aListBox::aListBox(QWidget *parent, const char *name )
     : QListBox(parent,name)
@@ -239,8 +240,10 @@ void aListBox::dropEvent( QDropEvent *e )
 
 bool aListBox::needNickPrefix() const
 {
-    if ( m_nickListDirty )
+    if ( m_nickListDirty ) {
         updateNeedNickPrefixFlag();
+        const_cast<aListBox *>( this )->updateNickPrefixWidth();
+    }
 
     return m_needNickPrefix;
 }
@@ -276,10 +279,11 @@ void aListBox::updateNickPrefixWidth()
 {
     QFontMetrics metrics( font() );
 
-    m_nickPrefixWidth = metrics.width( nickPrefixOp() );
-    m_nickPrefixWidth = QMAX( m_nickPrefixWidth, metrics.width( nickPrefixVoice() ) );
-    m_nickPrefixWidth = QMAX( m_nickPrefixWidth, metrics.width( nickPrefixAway() ) );
-    m_nickPrefixWidth = QMAX( m_nickPrefixWidth, metrics.width( nickPrefixIrcOp() ) );
+    m_nickPrefixWidth = 0;
+
+    nickListItem *item = static_cast<nickListItem *>( firstItem() );
+    for ( ; item; item = static_cast<nickListItem *>( item->next() ) )
+        m_nickPrefixWidth = kMax( m_nickPrefixWidth, metrics.width( item->nickPrefix() ) );
 
     // padding
     m_nickPrefixWidth += metrics.width( " " );
@@ -368,16 +372,21 @@ void nickListItem::paint(QPainter *p)
 
 QString nickListItem::nickPrefix() const
 {
-    if ( voice() )
-        return aListBox::nickPrefixVoice();
-    if ( op() )
-        return aListBox::nickPrefixOp();
-    if ( away() )
-        return aListBox::nickPrefixAway();
-    if ( ircOp() )
-        return aListBox::nickPrefixIrcOp();
+    QString prefix;
 
-    return QString::null;
+    if ( voice() )
+        prefix += aListBox::nickPrefixVoice();
+    if ( op() )
+        prefix += aListBox::nickPrefixOp();
+    if ( away() )
+        prefix += aListBox::nickPrefixAway();
+    if ( ircOp() )
+        prefix += aListBox::nickPrefixIrcOp();
+
+    if ( !prefix.isEmpty() )
+        prefix.prepend( "+" );
+
+    return prefix;
 }
 
 int nickListItem::height(const QListBox *lb ) const
