@@ -15,7 +15,7 @@ public:
     {
     }
 
-  virtual void sirc_receive(QString str, bool broadcast);
+  virtual void sirc_receive(QCString str, bool broadcast);
 
   virtual void control_message(int, QString);
 
