@@ -8,6 +8,7 @@
 #include "control_message.h"
 #include "ssfeprompt.h"
 #include "toplevel.h"
+#include "ksircprocess.h"
 
 #include <stdio.h>
 
@@ -133,23 +134,23 @@ parseResult * ChannelParser::parseSSFEStatus(QString string)
   string.remove(0, 4); // strip off the first 4 characters
   const char *status;
   if(string.length() < 8)
-    return new parseError("", "Unable to parse status string");
+    return new parseError("", i18n("Unable to parse status string"));
 
   status = string.ascii()+8;
   char nick[101], modes[101], chan[101], chanmode[101];
-  int away = 0;
+  int away = 1;
   modes[0] = 0x0; modes[1] = 0x0; // No mode set for user
-  int found = sscanf(status, "%100s (%100[^)]) on %100s (%100[^)])", nick, modes, chan, chanmode); // Channel modes and user modes
-  if(found != 4){
+  int found = sscanf(status, "%100s (away) on %100s (%100[^)])", nick, chan, chanmode); // Away and no user mode set
+  if(found != 3){
     found = sscanf(status, "%100s on %100s (%100[^)])", nick, chan, chanmode); // No user mode set
     away = 0;
     if(found != 3){
       found = sscanf(status, "%100s (%100[^)]) (away) on %100s (%100[^)])", nick, modes, chan, chanmode); // Away
       away = 1; modes[0] = 0x0; modes[1] = 0x0;
       if(found != 4){
-	found = sscanf(status, "%100s (away) on %100s (%100[^)])", nick, chan, chanmode); // Away and no user mode set
-	away = 1;
-	if(found != 3) {
+  	found = sscanf(status, "%100s (%100[^)]) on %100s (%100[^)])", nick, modes, chan, chanmode); // Channel modes and user modes
+	away = 0;
+	if(found != 4) {
 	  found = sscanf(status, "%100s [query: %*[^]]] on %100s (%100[^)])", nick, chan, chanmode);
 	  away = 0; modes[0] = 0x0; modes[1] = 0x0;
 	  if(found != 3) {
@@ -162,7 +163,7 @@ parseResult * ChannelParser::parseSSFEStatus(QString string)
 		found = sscanf(status, "%100s (%100[^)]) [query: %*[^]]] (away) on %100s (%100[^)])", nick, modes, chan, chanmode);
 		away = 1; modes[0] = 0x0; modes[1] = 0x0;
 		if(found != 4) {
-		  return new parseError("", "Unable to parse status (no known format) string");
+		  return new parseError("", i18n("Unable to parse status (no known format) string"));
 		}
 	      }
 	    }
@@ -179,7 +180,14 @@ parseResult * ChannelParser::parseSSFEStatus(QString string)
     }
   }
 
+  nickListItem *nickItem = top->nicks->item( top->nicks->findNick( nick ) );
+  if ( nickItem ) {
+      nickItem->setAway( away );
+      top->nicks->viewport()->repaint( top->nicks->itemRect( nickItem ), false );
+  }
+
   top->channelButtons->setNick(nick);
+  top->setNick(nick);
   QString channelMode = chanmode;
   if (channelMode.findRev("t") != -1)
     top->channelButtons->setProtectMode(true);
@@ -234,7 +242,7 @@ parseResult * ChannelParser::parseSSFEStatus(QString string)
     if(top->topic().length() > 0)
       status_line += "T: " + top->topic();
     else
-      status_line += "T: " + QString("<No Topic Set>");
+      status_line += "T: " + i18n("<No Topic Set>");
   }
 
   if(strcmp(top->caption, status_line) != 0){
@@ -275,17 +283,17 @@ parseResult * ChannelParser::parseSSFEMsg(QString string)
 {
 
   if(string.length() > 100)
-    return new parseError(QString::null, QString("String length for nick is greater than 100 characters, insane, too big"));
+    return new parseError(QString::null, i18n("String length for nick is greater than 100 characters. This is unacceptably long."));
 
   int l = string.length();
   if (l <= 0)
-    return new parseError(string, QString("String not long enough"));
+    return new parseError(string, i18n("String not long enough"));
   char *nick = new char[l + 1];
   int found = sscanf(string.ascii(), "`t` %s", nick);
 
   if(found < 1) {
-    delete nick;
-    return new parseError(string, QString("Could not find nick in string"));
+    delete[] nick;
+    return new parseError(string, i18n("Could not find nick in string"));
   }
 
   if(!top->nick_ring.contains(nick)){
@@ -293,7 +301,7 @@ parseResult * ChannelParser::parseSSFEMsg(QString string)
     if(top->nick_ring.count() > 10)
       top->nick_ring.removeFirst();
   }
-  delete nick;
+  delete[] nick;
   return new parseSucc(QString::null); // Null string, don't display anything
 }
 
@@ -325,7 +333,7 @@ parseResult * ChannelParser::parseSSFEPrompt(QString string)
     */
     // "'[pP]' " gives 4 spaces
     if(string.length() < 5)
-      prompt = "No Prompt Given?";
+      prompt = i18n("No Prompt Given?");
     else
       prompt = string.mid(4, string.length() - 4);
     prompt_active = TRUE;
@@ -339,7 +347,7 @@ parseResult * ChannelParser::parseSSFEPrompt(QString string)
     //	  cerr << "Entered: " << sp->text() << endl;
     prompt = sp->text();
     prompt += "\n";
-    emit top->outputLine(prompt);
+    emit top->outputUnicodeLine(prompt);
     delete sp;
     prompt_active = FALSE;
   }
@@ -352,7 +360,7 @@ parseResult * ChannelParser::parseSSFEReconnect(QString)
 
   if(top->channel_name[0] == '#'){
     QString str = "/join " + QString(top->channel_name) + "\n";
-    emit top->outputLine(str);
+    emit top->outputUnicodeLine(str);
   }
 
   return new parseSucc(QString::null); // Null string, don't display anything
@@ -405,7 +413,7 @@ parseResult * ChannelParser::parseINFONicks(QString in_string)
   // Search for the first space, since : can be embeded into channel names.
   count = sscanf(string, "*!* Users on %100[^ ]", channel_name);
   if(count < 1){
-    return new parseError(string, QString("Could not find channel name"));
+    return new parseError(string, i18n("Could not find channel name"));
   }
 
   // Remove the : from the end.
@@ -424,7 +432,7 @@ parseResult * ChannelParser::parseINFONicks(QString in_string)
 
   int start = string.find(": ", 0, FALSE); // Find start of nicks
   if (start < 0)
-    return new parseError(string, QString("Could not find start of nicks"));
+    return new parseError(string, i18n("Could not find start of nicks"));
 
   place_holder = new char[string.length()];
   strcpy(place_holder, string.ascii()+start+2);
@@ -534,7 +542,7 @@ parseResult * ChannelParser::parseINFOPart(QString string)
     if (ksopts->autoRejoin == TRUE)
     {
        QString str = "/join " + QString(top->channel_name) + "\n";
-       emit top->outputLine(str);
+       emit top->outputUnicodeLine(str);
 /*       if(top->ticker)
          top->ticker->show();
        else*/
@@ -543,13 +551,13 @@ parseResult * ChannelParser::parseINFOPart(QString string)
     else
     {
       if(top->KickWinOpen != false)
-        return new parseError(" " + string, QString("Kick window open"));
+        return new parseError(" " + string, i18n("Kick window open"));
       top->KickWinOpen = true;
       int result = KMessageBox::questionYesNo(top, string, i18n("You Have Been Kicked"), i18n("Rejoin"), i18n("Leave"));
       if (result == KMessageBox::Yes)
       {
         QString str = "/join " + QString(top->channel_name) + "\n";
-	emit top->outputLine(str);
+	emit top->outputUnicodeLine(str);
 /*	if(top->ticker)
 	  top->ticker->show();
 	else*/
@@ -586,7 +594,7 @@ parseResult * ChannelParser::parseINFOPart(QString string)
     }
   }
   else{                                // uhoh, something we missed?
-    return new parseError(" " + string, QString("Failed to parse part/kick/leave/quit message"));
+    return new parseError(" " + string, i18n("Failed to parse part/kick/leave/quit message"));
   }
   if (foundNick)
   {
@@ -609,7 +617,7 @@ parseResult * ChannelParser::parseINFOChangeNick(QString string)
   string.remove(0, 4); // Remove the leading *N* and space
   int found = sscanf(string, "%100s is now known as %100s", old_nick, new_nick);
   if(found < 0){
-    return new parseError(" Unable to parse: " + string, QString("Unable to parse change nick code"));
+    return new parseError(i18n("Unable to parse: %1").arg(string), i18n("Unable to parse change nick code"));
   }
 
     // If we have a window open talking to the nick
@@ -720,7 +728,7 @@ parseResult * ChannelParser::parseINFOMode(QString string)
     case 'k': // kcik, arg is nick
       mode.append(fmode);
       if(next_arg == NULL)
-        return new parseError(" Unable to parse mode change: " + string, QString::null);
+        return new parseError(i18n("Unable to parse mode change: %1").arg(string), QString::null);
       arg.append(next_arg);
       next_arg = strtok(NULL, " ");
       break;
@@ -841,19 +849,45 @@ parseResult * ChannelParser::parseINFOTopic(QString string)
 {
   char channel[101];
 
+  int found = 0;
+
   string.remove(0, 4); // Remove the leading *T* and space
   // *T* Topic for #kde: Don't use koffice! You will get into deep emotional problems!
-  int found = sscanf(string, "Topic for %100[^:]: ", channel);
+  QRegExp topicRegExp( "Topic for (#[^ ]*): (.*)" );
+  QRegExp topicWhoTimeRegExp( "Topic for (#[^ ]*) set by (.*) on (.*)" );
+  if ( topicRegExp.search( string ) == 0 && 
+#if QT_VERSION < 0x030100
+       topicRegExp.capturedTexts().count() == 2 && 
+#else
+       topicRegExp.numCaptures() == 2 && 
+#endif
+       topicWhoTimeRegExp.search( string ) == -1 ) {
+
+      QString channel = topicRegExp.cap( 1 );
+      QString topic = topicRegExp.cap( 2 );
+      topic.replace( QRegExp( "~~" ), "~" );
+
+      KSircTopLevel *topLevel = 0;
+      if ( top->proc )
+          topLevel = dynamic_cast<KSircTopLevel *>( top->proc->getWindowList()[ channel ] );
+
+      if ( topLevel )
+          topLevel->setTopic( topic );
+  }
+  /*
+  int found = sscanf(string, "Topic for %100[^: ]: ", channel);
   if(found == 1){
-    // If this is the correct channel, set the status line for the topic
-    if(strcasecmp(top->channel_name, channel) == 0){
+    KSircTopLevel *topLevel = topLevelForTopicByName( channel );
+    if ( topLevel ) {
       int start = string.find(": ")+1;
       int end = string.length() - start;
       QString topic = string.mid(start, end);
       topic.replace(QRegExp("~~"), "~");
-      top->setTopic( topic );
+      qDebug( "SETTING TOPIC TO %s", topic.ascii() );
+      topLevel->setTopic( topic );
     }
   }
+  */
   else {
     found = sscanf(string, "%*s has changed the topic on channel %100s to", channel);
     if(found == 1){
