@@ -3,14 +3,14 @@
 #ifndef CHARSELECTOR_H
 #define CHARSELECTOR_H
 
-#include <qdialog.h>
+#include <kdialog.h>
 
 #include <kcharselect.h>
 
 class QVBoxLayout;
 class QPushButton;
 
-class charSelector : public QDialog
+class charSelector : public KDialog
 {
   Q_OBJECT
   public:
