@@ -35,7 +35,7 @@ public:
     }
   virtual ~KSircIODCC();
 
-  virtual void sirc_receive(QString, bool broadcast);
+  virtual void sirc_receive(QCString, bool broadcast);
   virtual void control_message(int, QString);
   virtual filterRuleList *defaultRules();
 
@@ -45,7 +45,7 @@ protected slots:
   void forgetFile();
 
 signals:
-  void outputLine(QString);
+  void outputLine(QCString);
 
 private:
 //  QDict<QProgressDialog> DlgList;
