@@ -16,11 +16,11 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: ksview.cpp,v 1.51.2.1 2002/03/28 18:31:02 hausmann Exp $
+// $Id: ksview.cpp,v 1.64.2.1 2002/12/13 22:40:30 hausmann Exp $
 
+#include <qclipboard.h>
 #include <qdatetime.h>
 #include <qregexp.h>
-#include <qclipboard.h>
 #include <qdragobject.h>
 #include <qvaluestack.h>
 
@@ -29,6 +29,9 @@
 #include <klocale.h>
 #include <krun.h>
 #include <kpopupmenu.h>
+#include <kstringhandler.h>
+#include <kfiledialog.h>
+#include <kio/job.h>
 
 #include "ksopts.h"
 #include "ksview.moc"
@@ -195,13 +198,17 @@ QColor KSParser::ircColor(int code)
 }
 
 KSircView::KSircView(QWidget *parent, const char *name)
-    : KSTextView(parent, name)
+    : KSirc::TextView(parent, name)
 {
     m_acceptFiles = false;
     viewport()->setAcceptDrops(true);
     clear();
     connect( this, SIGNAL( linkClicked( const QMouseEvent *, const QString & ) ),
              this, SLOT( anchorClicked( const QMouseEvent *, const QString & ) ) );
+
+	QPixmap background = ksopts->backgroundPixmap();
+	if ( !background.isNull() )
+		viewport()->setBackgroundPixmap( background );
 }
 
 KSircView::~KSircView()
@@ -212,7 +219,7 @@ void KSircView::clear()
 {
     m_lines = 0;
     m_timeStamps.clear();
-    KSTextView::clear();
+	KSirc::TextView::clear();
 }
 
 QString KSircView::makeTimeStamp()
@@ -225,6 +232,30 @@ QString KSircView::makeTimeStamp()
     return timeStamp; 
 }
 
+void KSircView::saveURL( const QString &url )
+{
+	KURL kurl( url );
+
+	KFileDialog *dlg = new KFileDialog( QString::null, QString::null /*filter*/, this /*parent*/, "filedialog" /*name*/, true /*modal*/ );
+
+	dlg->setKeepLocation( true );
+
+	dlg->setCaption( i18n( "Save As" ) );
+
+	if ( !kurl.fileName().isEmpty() )
+		dlg->setSelection( kurl.fileName() );
+
+	if ( dlg->exec() ) {
+		KURL destURL( dlg->selectedURL() );
+		if ( !destURL.isMalformed() ) {
+			KIO::Job *job = KIO::copy( kurl, destURL );
+			job->setAutoErrorHandlingEnabled( true );
+		}
+	}
+
+	delete dlg;
+}
+
 QString KSircView::addLine(const QString &pixmap, const QColor &color, const QString &_text)
 {
     QString richText( "<font color=\"%1\">" );
@@ -233,7 +264,6 @@ QString KSircView::addLine(const QString &pixmap, const QColor &color, const QSt
     if ( !pixmap.isEmpty() )
         richText.prepend( QString::fromLatin1( "<img src=\"%1\"></img>" ).arg( pixmap ) );
 
-    QTime now = QTime::currentTime();
     QString timeStamp = QString::fromLatin1( "<font color=\"%1\">%2</font>" )
         .arg( ksopts->textColor.name() )
         .arg( makeTimeStamp() );
@@ -249,25 +279,27 @@ QString KSircView::addLine(const QString &pixmap, const QColor &color, const QSt
     text.replace(ltRex, "&lt;");
     text.replace(gtRex, "&gt;");
 
+    // ### a bit of a hack: turn '&lt;nick&gt; message' into
+    // <span>&lt;nick&gt;<span> message' . span itself isn't supported but it
+    // enforces the creation of separate item objects and hence separate
+    // drawing of '<nick>' and 'message' , which is needed for BiDi users,
+    // according to UV Kochavi <uv1st@yahoo.com> , to prevent output like
+    // '<nick message<' , which is supposedly a bug in Qt's reordering.  The
+    // same is done for [nick] and >nick< to catch queries.
+    QRegExp bidiRe( "^(&lt;\\S+&gt;)(.+)$" );
+    text.replace( bidiRe, QString::fromLatin1( "<span>\\1</span>\\2" ) );
+    QRegExp bidiRe2( "^(\\[\\S+\\])(.+)$" );
+    text.replace( bidiRe2, QString::fromLatin1( "<span>\\1</span>\\2" ) );
+    QRegExp bidiRe3( "^(&gt;\\S+&lt;)(.+)$" );
+    text.replace( bidiRe3, QString::fromLatin1( "<span>\\1</span>\\2" ) );
+
     KSParser parser;
     richText += parser.parse( text );
 
     richText += "</font>";
 
-    static QRegExp urlEx("(www\\.|(f|ht)tp(|s)://)[\\d\\w./,:_~\\?=&;#-]+[\\d\\w/]");
-
-    int urlPos = 0, urlLen;
-    while ((urlPos = urlEx.search(richText, urlPos)) >= 0)
-    {
-        urlLen = urlEx.matchedLength();
-        QString href = richText.mid( urlPos, urlLen );
-        QString anchor( "<a href=\"%1\">%2</a>" );
-        anchor = anchor.arg( href ).arg( href );
-        richText.replace( urlPos, urlLen, anchor );
-
-        urlPos += anchor.length();
-    }
-    TextParagIterator parag = appendParag( richText );
+	richText = KStringHandler::tagURLs( richText );
+	KSirc::TextParagIterator parag = appendParag( richText );
 
     m_lines++;
     if ( ksopts->windowLength && m_lines > ksopts->windowLength )
@@ -291,7 +323,7 @@ QString KSircView::addLine(const QString &pixmap, const QColor &color, const QSt
 void KSircView::enableTimeStamps(bool enable)
 {
     setUpdatesEnabled( false );
-    TextParagIterator paragIt = firstParag();
+	KSirc::TextParagIterator paragIt = firstParag();
     QStringList::ConstIterator timeStampIt = m_timeStamps.begin();
     for (; !paragIt.atEnd(); ++paragIt, ++timeStampIt )
     {
@@ -308,11 +340,13 @@ void KSircView::enableTimeStamps(bool enable)
 
 void KSircView::anchorClicked(const QMouseEvent *ev, const QString &url)
 {
-	if ( ev->button() & LeftButton )
+    if ( (ev->button() & LeftButton) && (ev->state() & ShiftButton ) )
+		saveURL( url );
+	else if ( (ev->button() & LeftButton) || (ev->button() & MidButton) )
     {
         openBrowser( url );
-	}
-	else if ( ev->button() & RightButton )
+    }
+    else if ( ev->button() & RightButton )
     {
         static const int openURLID = 0;
         static const int copyLinkLocationID = 1;
@@ -321,7 +355,7 @@ void KSircView::anchorClicked(const QMouseEvent *ev, const QString &url)
         KPopupMenu* menu = new KPopupMenu( this );
         menu->insertTitle( i18n( "URL" ) );
         menu->insertItem( i18n("Open URL"), openURLID );
-        menu->insertItem( i18n("Copy link location"), copyLinkLocationID );
+        menu->insertItem( i18n("Copy Link Location"), copyLinkLocationID );
         switch( menu->exec( ( ev->globalPos() ) ) )
         {
         case openURLID :
@@ -344,12 +378,11 @@ void KSircView::openBrowser(const QString &url )
 
 void KSircView::copyLinkToClipboard( const QString &url )
 {
-    // copy url to selection clipboard
-    QClipboard *cb = QApplication::clipboard();
-    cb->clear();
-    if (cb->supportsSelection()) // is this needed on *nix ?
-        cb->setSelectionMode( true );
-    cb->setText( url );
+    QClipboard *clip = QApplication::clipboard();
+    bool oldMode = clip->selectionModeEnabled();
+    clip->setSelectionMode( false );
+    clip->setText( url );
+    clip->setSelectionMode( oldMode );
 }
 
 QColor KSircView::ircColor(int code)
@@ -359,19 +392,6 @@ QColor KSircView::ircColor(int code)
     return QColor();
 }
 
-void KSircView::mousePressEvent( QMouseEvent *e )
-{
-    if (e->button() & Qt::MidButton)
-    {
-        QClipboard *cp = KApplication::clipboard();
-        bool restoreMode = cp->selectionModeEnabled();
-        cp->setSelectionMode(true);
-        emit pasteReq( cp->text() );
-        cp->setSelectionMode(restoreMode);
-    }
-    KSTextView::mousePressEvent(e);
-}
-
 void KSircView::contentsDragEnterEvent(QDragEnterEvent* event)
 {
     event->accept((QTextDrag::canDecode(event) ||
