@@ -19,11 +19,11 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: ksview.h,v 1.16.2.1 2002/03/28 18:31:02 hausmann Exp $
+// $Id: ksview.h,v 1.20 2002/05/28 08:23:48 hausmann Exp $
 //
 #include <kstextview.h>
 
-class KSircView : public KSTextView
+class KSircView : public KSirc::TextView
 {
 	Q_OBJECT
 public:
@@ -36,12 +36,10 @@ public:
 	void enableTimeStamps(bool enable);
 	void setAcceptFiles(bool _acceptFiles) { m_acceptFiles = _acceptFiles; }
 signals:
-        void pasteReq(const QString&);
         void urlsDropped(const QStringList&);
         void textDropped(const QString&);
         
 protected:
-        virtual void mousePressEvent( QMouseEvent *e );
         virtual void contentsDragEnterEvent(QDragEnterEvent *);
         virtual void contentsDragMoveEvent(QDragMoveEvent *);
         virtual void contentsDropEvent(QDropEvent *);
@@ -52,6 +50,8 @@ private:
     void copyLinkToClipboard( const QString &url );
 	static QString makeTimeStamp();
 
+	void saveURL( const QString &url );
+
 private slots:
 	void anchorClicked(const QMouseEvent *ev, const QString &url);
 
