@@ -1,3 +1,5 @@
+#include <config.h>
+
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -78,7 +80,8 @@ PukeController::PukeController(QString sock, QObject *parent, const char *name)
   }
   memset(&unix_addr, 0, sizeof(unix_addr));
   unix_addr.sun_family = AF_UNIX;
-  strcpy(unix_addr.sun_path, qsPukeSocket);
+  strlcpy(unix_addr.sun_path, qsPukeSocket, sizeof(unix_addr.sun_path));
+
   len = sizeof(unix_addr.sun_family) + qsPukeSocket.length();
 #if defined(__FreeBSD__)
   if( bind(iListenFd, (struct sockaddr *) &unix_addr, len+1) < 0){
@@ -566,7 +569,7 @@ void PukeController::hdlrPukeFetchWidget(int fd, PukeMessage *pm)
   int iParent=-1, iType=-1;
 
   char rand[50],name[50];
-  int found = sscanf(pm->cArg, "%d\t%d\t%s\t%s", &iParent, &iType, rand, name);
+  int found = sscanf(pm->cArg, "%d\t%d\t%49s\t%49s", &iParent, &iType, rand, name);
   if(found != 4){
       throw(errorCommandFailed(PUKE_INVALID,6));
   }
