@@ -3,22 +3,19 @@
 
 class PPopupMenu;
 
-#include "qpopupmenu.h"
+#include <qpopupmenu.h>
 #include "pobject.h"
 #include "pmessage.h"
 
 #include "ptablevw.h"
 #include "pmenudta.h"
 
-extern "C" {
-  // Init and setup code
-  PObject *createWidget(CreateArgs &ca);
-}
-
 class PPopupMenu : public PFrame
 {
   Q_OBJECT
 public:
+  static PObject *createWidget(CreateArgs &ca);
+
   PPopupMenu(PObject *child);
   virtual ~PPopupMenu();
 
@@ -27,11 +24,6 @@ public:
   virtual void setWidget(QObject *_menu);
   virtual QPopupMenu *widget();
 
-
-signals:
-  void outputMessage(int fd, PukeMessage *pm);
-  void widgetDestroyed(widgetId wI);
-
 protected slots:
   void got_activated ( int itemId );
 
