@@ -4,10 +4,10 @@
 
 	File: servercontroller.h
 	Last generated: Sat Nov 29 08:50:19 1997
-	
+
  Now Under CVS control.
 
- $$Id: servercontroller.h,v 1.52 2001/12/09 14:35:18 hausmann Exp $$
+ $$Id: servercontroller.h,v 1.56 2002/08/26 08:57:35 hausmann Exp $$
 
  *********************************************************************/
 
@@ -100,6 +100,17 @@ public:
 
     static servercontroller *self() { return s_self; }
 
+    /**
+     * Someone is talking to the user (blue icon), notify him (docked icon).
+     */
+    void increaseNotificationCount();
+
+    /**
+     * The channel in which the user was talked to, has been read.
+     * -> decrease count of blue icons.
+     */
+    void decreaseNotificationCount();
+
 signals:
     /**
       * Filter rules have changed, need to re-read and update.
@@ -141,12 +152,16 @@ public slots:
       */
     virtual void slot_filters_update();
     virtual void ToggleAutoCreate();
-    virtual void font_prefs();
+
     /**
      * Action: Popup a general preferences window which allows various
      * settings, etc.
      */
     virtual void general_prefs();
+    /**
+     * Opens the dialog that lets the user configure system notifications
+     */
+    virtual void notification_prefs();
     virtual void font_update(const QFont&);
     virtual void filter_rule_editor();
     virtual void configChange();
@@ -176,8 +191,8 @@ protected:
 private:
     void saveSessionConfig();
 
-    // La raison d'etre.  We don't run ConnectionTree outr selves, but
-    // we get it from out helper class scInside.
+    // La raison d'etre.  We don't run ConnectionTree ourselves, but
+    // we get it from our helper class scInside.
     KListView *ConnectionTree;
 
     scInside *sci;
@@ -199,6 +214,7 @@ private:
     QPixmap pic_run;
     QPixmap pic_ppl;
     QPixmap pic_dock;
+    QPixmap pic_info;
 
 //    PukeController *PukeC;
 
@@ -206,8 +222,21 @@ private:
     dockServerController *dockWidget;
     bool we_are_exiting;
 
+    int m_notificationCount;
+
     QString pukeSocket;
-    QMap<QString,QStringList> m_sessionConfig;
+    
+    struct ChannelSessionInfo
+    {
+	ChannelSessionInfo()
+	    : desktop( -1 ) {}
+	QString name;
+	int desktop;
+    };
+    typedef QValueList<ChannelSessionInfo> ChannelSessionInfoList;
+
+    typedef QMap<QString, ChannelSessionInfoList> SessionConfigMap;
+    SessionConfigMap m_sessionConfig;
 
     static servercontroller *s_self;
 };
