@@ -8,10 +8,7 @@
  *********************************************************************/
 
 #include "ssfeprompt.h"
-#include "kplunger/kplunger.h"
-#include <kapp.h>
 #include <klocale.h>
-#include "config.h"
 
 #undef Inherited
 #define Inherited ssfepromptdata
