@@ -2,33 +2,33 @@
  * Copyright (c) 1983 Regents of the University of California.
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
- *    may be used to endorse or promote products derived from this software
- *    without specific prior written permission.
+ *  Redistribution and use in source and binary forms, with or
+ *    without modification, are permitted provided that the following
+ *    conditions are met:
  *
- * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ *    - Redistributions of source code must retain the above
+ *      copyright notice, this list of conditions and the following
+ *      disclaimer.
+ *
+ *    - Redistributions in binary form must reproduce the above
+ *      copyright notice, this list of conditions and the following
+ *      disclaimer in the documentation and/or other materials
+ *      provided with the distribution.
+ *
+ *  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY
+ *    EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
+ *    THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
+ *    PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR
+ *    BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ *    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+ *    TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ *    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+ *    ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ *    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ *    IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ *    THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * (BSD License, from kdelibs/doc/common/bsd-license.html)
  */
 
 #include "includ.h"
@@ -41,9 +41,6 @@
 #include <stdio.h>
 #include <string.h>
 #define USE_UT_HOST
-#ifndef UT_LINESIZE
-#define UT_LINESIZE 12
-#endif
 #ifndef UT_HOSTSIZE
 #define UT_HOSTSIZE 12 /*whatever*/
 #undef USE_UT_HOST
@@ -61,7 +58,7 @@
 #include <errno.h>
 #endif
 
-#include "print.h"
+#include "proto.h"
 #include "defs.h"
 
 #ifdef PROC_FIND_USER
@@ -77,22 +74,24 @@ char *get_display(pid_t pid) {
 
     std::ifstream ifstr(buf);
     if (ifstr.fail()) return 0;
-    /* message("reading %s...", fname); */
+    /* debug("reading %s...", fname); */
 
     char * dpy = 0;
     while (!ifstr.eof()) {
         ifstr.getline(buf, sizeof buf - 1, '\0');
         if (ifstr.fail()) {
-            syslog(LOG_ERR, "getline: %m");
+            syslog(LOG_ERR, "getline: %s", strerror(errno));
             return 0;        /* read error */
         }
         if (!strncmp("DISPLAY=", buf, 8)) {
             int l = strlen(buf + 8);
+            if( l >= DISPLAY_MAX )
+                return 0;
             if (l >= 2 && l < (int) sizeof buf - 1) {
                 dpy = new char[ l+2 ];
                 strcpy(dpy," ");
                 strcat(dpy, buf + 8); /* returns " "+dpy */
-                /* message("- %s",dpy); */
+                /* debug("- %s",dpy); */
             }
             break;
         }
@@ -123,6 +122,8 @@ struct dirent *direntry
 
     /* make absolute path   (would sprintf be better ?)*/
     char abspath[20]="/proc/";
+    if( strlen( direntry->d_name ) > 12 )
+        return 0;
     strcat(abspath,direntry->d_name);
 
     if (isdigit(direntry->d_name[0])) {    /* starts with [0-9]*/
@@ -136,9 +137,9 @@ struct dirent *direntry
                     errno=0;
                     return 1;
                 }
-                /* else message("st_uid=%d", statbuf.st_uid); */
-            } /* else message("st_mode=%d", statbuf.st_mode); */
-        } else message("stat error : %m");
+                /* else debug("st_uid=%d", statbuf.st_uid); */
+            } /* else debug("st_mode=%d", statbuf.st_mode); */
+        } else debug("stat error : %s", strerror(errno));
     }
 
     errno=0;
@@ -163,7 +164,7 @@ int find_X_process(char *name, char *disp) {
     struct dirent **namelist;
 
     struct passwd * pw = getpwnam(name);
-    message("find_X_process");
+    debug("find_X_process");
     /* find uid */
     if ((pw) && ((user_uid=pw->pw_uid)>10))
     { /* uid<10 : no X detection because any suid program will be taken
@@ -171,7 +172,7 @@ int find_X_process(char *name, char *disp) {
         /* scan /proc */
         int n = scandir("/proc", &namelist, select_process, 0 /*no sort*/);
         if (n < 0)
-            message("scandir: %m");
+            debug("scandir: %s", strerror(errno));
         else
             while(n--)
             {
@@ -187,7 +188,8 @@ int find_X_process(char *name, char *disp) {
                     { /* not already in the list? */
                         char * pointlocation=strstr(dispwithblanks,".");
                         if (pointlocation) *pointlocation='\0';
-                        if (!strstr(displays_list,dispwithblanks))
+                        if (!strstr(displays_list,dispwithblanks)
+                            && strlen(dispwithblanks)+strlen(displays_list)<DISPLAYS_LIST_MAX)
                         { /* display up to the '.' mustn't be already in the list */
                             strcat(displays_list,dispwithblanks+1); /* insert display (no ' ') */
                             strcat(displays_list," "); /* and a blank */
@@ -198,7 +200,6 @@ int find_X_process(char *name, char *disp) {
             } /* while */
         if (strlen(displays_list)>1)
         {
-	    /* XXX No bounds checks either */
             strcpy(disp,displays_list+1); /* removes the leading white space
                              but leave the final one, needed by announce.c */
             return 1;
@@ -234,18 +235,18 @@ int find_user(char *name, char *tty, char *disp) {
     struct utmp *ubuf;
     int prio = 0, status = NOT_HERE;
     struct stat statb;
-    char ftty[20];
+    char ftty[20+UT_LINESIZE];
     char *ntty, *dpy;
     char ttyFound[UT_LINESIZE] = "";
-    char dispFound[UT_HOSTSIZE] = "";
-    
+    char dispFound[DISPLAYS_LIST_MAX] = "";
+
     strcpy(ftty, _PATH_DEV);
     ntty = ftty + strlen(ftty);
     setutent();
     while ((ubuf = getutent())) {
         if ((ubuf->ut_type == USER_PROCESS) &&
             (!SCMPN(ubuf->ut_name, name))) {
-            
+
             if (*tty == '\0') {    /* no particular tty was requested */
 
                 if (Options.XAnnounce && ubuf->ut_line[0] == ':') {
@@ -263,7 +264,7 @@ int find_user(char *name, char *tty, char *disp) {
                 strcpy(ntty, ubuf->ut_line);
                 if (stat(ftty, &statb) != 0 || (!(statb.st_mode & 020)))
                 {
-                   message("Permission denied on %s", ntty);
+                   debug("Permission denied on %s", ntty);
                    continue; /* not a char dev */
                 }
 
@@ -282,7 +283,7 @@ int find_user(char *name, char *tty, char *disp) {
                  * 2) get environment variables of an arbitrary process?
                  */
                 if (strncmp("tty", ubuf->ut_line, 3) != 0 ||
-                    !strchr("pqrstuvwxyzabcde", ubuf->ut_line[3])) 
+                    !strchr("pqrstuvwxyzabcde", ubuf->ut_line[3]))
                     continue; /* not a pty */
 
                 /* device is a pseudo terminal (ex : a xterm) */
@@ -318,19 +319,19 @@ int find_user(char *name, char *tty, char *disp) {
         }
     }
     endutent();
-    
-    message("End of Utmp reading");
+
+    debug("End of Utmp reading");
 #if defined(HAVE_KDE) && defined(ALL_PROCESSES_AND_PROC_FIND_USER)
     if (Options.XAnnounce && prio < PRIO_DISPLAY)
         if (find_X_process(name, dispFound))
-            { message(dispFound); status=SUCCESS; }
-#endif        
+            { debug(dispFound); status=SUCCESS; }
+#endif
     if (status == SUCCESS) {
         (void) strcpy(tty, ttyFound);
         (void) strcpy(disp, dispFound);
         if (Options.debug_mode)
          syslog(LOG_DEBUG, "Returning tty '%s', display '%s'", ttyFound, dispFound);
-    } else message("Returning status %d",status);
+    } else debug("Returning status %d",status);
     return (status);
 }
 
@@ -344,10 +345,10 @@ int find_user(char *name, char *tty, char *disp) {
     int status;
     FILE *fd;
     struct stat statb;
-    char ftty[20];
+    char ftty[20+UT_LINESIZE];
     char ttyFound[UT_LINESIZE] = "";
-    char dispFound[UT_HOSTSIZE] = "";
-  
+    char dispFound[UT_HOSTSIZE+1] = "";
+
     if (!(fd = fopen(_PATH_UTMP, "r"))) {
         fprintf(stderr, "talkd: can't read %s.\n", _PATH_UTMP);
         return (FAILED);
