@@ -1,21 +1,36 @@
 /* This file is part of ktalkd
-
-    Copyright (C) 1997 David Faure (faure@kde.org)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA. */
+ *
+ *  Copyright (C) 1997 David Faure (faure@kde.org)
+ *
+ *  Redistribution and use in source and binary forms, with or
+ *    without modification, are permitted provided that the following
+ *    conditions are met:
+ *
+ *    - Redistributions of source code must retain the above
+ *      copyright notice, this list of conditions and the following
+ *      disclaimer.
+ *
+ *    - Redistributions in binary form must reproduce the above
+ *      copyright notice, this list of conditions and the following
+ *      disclaimer in the documentation and/or other materials
+ *      provided with the distribution.
+ *
+ *  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY
+ *    EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
+ *    THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
+ *    PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR
+ *    BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ *    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+ *    TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ *    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+ *    ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ *    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ *    IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ *    THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * (BSD License, from kdelibs/doc/common/bsd-license.html)
+ *
+ */
 
 /*
  * Routines for reading configuration from KDE configuration
@@ -45,7 +60,7 @@
 #include "defs.h"
 #include <config.h>
 
-#include "print.h"
+#include "proto.h"
 
 /** Converts a string s into a boolean. Handles 0/1, on/off, true/false. 
  * (case insensitive) */
@@ -80,12 +95,12 @@ int init_user_config(const char * l_name)
       setenv("HOME",pw->pw_dir,1 /* overwrite */); 
       unsetenv("KDEHOME");
       unsetenv("XAUTHORITY");
-message("%s",pw->pw_dir);
+debug("%s",pw->pw_dir);
       KInstance tmpInstance("tmpInstance");
       cfgFileName = locateLocal("config", "ktalkdrc", &tmpInstance );
       tkannFileName = locateLocal("config", "ktalkannouncerc", &tmpInstance);
       endpwent();
-message("%s","endpwent");
+debug("%s","endpwent");
  
 //WABA: New KConfig should be able to handle this gracefully:
      if (stat(QFile::encodeName(tkannFileName),&buf)!=-1) {
@@ -101,12 +116,12 @@ message("%s","endpwent");
           ktalkdcfg = new KConfig(cfgFileName);
           ktalkdcfg -> setGroup("ktalkd");
           ktalkdcfg -> setDollarExpansion(true);
-          message("User config file ok");
+          debug("User config file ok");
       } else {
           ktalkdcfg = 0L;
-          message("No user config file %s !",cfgFileName.ascii());
+          debug("No user config file %s !",cfgFileName.ascii());
       }
-message("%s","done");
+debug("%s","done");
       return ((ktkanncfg != 0L) || (ktalkdcfg != 0L));
       /* Return true if at least one file exists */
   }
@@ -137,7 +152,7 @@ int read_user_config(const char * key, char * result, int max)
     }
     else 
     {
-        message("User option %s NOT found", key);
+        debug("User option %s NOT found", key);
         return 0;
     }
 }
@@ -182,35 +197,35 @@ int process_config_file(void)
   
   if (found("AnswMach")) {
     Options.answmach=booleanresult(result.ascii()); 
-    message("AnswMach : %d",Options.answmach);}
+    debug("AnswMach : %d",Options.answmach);}
   
   if (found("XAnnounce")) {
     Options.XAnnounce=booleanresult(result.ascii()); 
-    message("XAnnounce : %d",Options.XAnnounce); }
+    debug("XAnnounce : %d",Options.XAnnounce); }
   
   if (found("Time")) { 
     Options.time_before_answmach=result.toInt(); 
-    message("Time : %d",Options.time_before_answmach); }
+    debug("Time : %d",Options.time_before_answmach); }
   
   if (found("Sound")) { 
     Options.sound=booleanresult(result.ascii());
-    message("Sound : %d",Options.sound); }
+    debug("Sound : %d",Options.sound); }
   
   if (found("SoundFile")) { 
     qstrncpy(Options.soundfile,QFile::encodeName(result),S_CFGLINE);
-    message("SoundFile = %s",Options.soundfile); }
+    debug("SoundFile = %s",Options.soundfile); }
   
   if (found("SoundPlayer")) { 
     qstrncpy(Options.soundplayer,QFile::encodeName(result),S_CFGLINE); 
-    message("SoundPlayer = %s",Options.soundplayer); }
+    debug("SoundPlayer = %s",Options.soundplayer); }
   
   if (found("SoundPlayerOpt")) { 
     qstrncpy(Options.soundplayeropt,QFile::encodeName(result),S_CFGLINE);
-    message("SoundPlayerOpt = %s",Options.soundplayeropt); }
+    debug("SoundPlayerOpt = %s",Options.soundplayeropt); }
   
   if (found("MailProg")) { 
     qstrncpy(Options.mailprog,QFile::encodeName(result),S_CFGLINE);
-    message("Mail prog = %s",Options.mailprog); }
+    debug("Mail prog = %s",Options.mailprog); }
   
   /* text based announcement */
   if (found("Announce1")) { qstrncpy(Options.announce1,result.local8Bit(),S_CFGLINE); }
@@ -218,28 +233,28 @@ int process_config_file(void)
   if (found("Announce3")) { qstrncpy(Options.announce3,result.local8Bit(),S_CFGLINE); }
 
   if (found("NEUUser"))   { 
-      qstrncpy(Options.NEU_user,result.local8Bit(),S_INVITE_LINES); 
-      message("NEUUser = %s", Options.NEU_user); 
+      qstrncpy(Options.NEU_user,result.local8Bit(),S_CFGLINE); 
+      debug("NEUUser = %s", Options.NEU_user); 
   }
   if (found("NEUBehaviour")) {
       Options.NEU_behaviour=result.toInt(); 
-      message("NEUBehaviour : %d",Options.NEU_behaviour); 
+      debug("NEUBehaviour : %d",Options.NEU_behaviour); 
   }
   if (found("NEUForwardMethod"))   { 
       qstrncpy(Options.NEU_forwardmethod,result.ascii(),5); 
-      message("NEUForwardMethod = %s", Options.NEU_forwardmethod); 
+      debug("NEUForwardMethod = %s", Options.NEU_forwardmethod); 
   }
   
   if (found("ExtPrg")) { 
     qstrncpy(Options.extprg,QFile::encodeName(result),S_CFGLINE);
-    message("Ext prg = %s",Options.extprg); }
+    debug("Ext prg = %s",Options.extprg); }
   else {   /* has to work even without config file at all */
     KStandardDirs stddirs;
     qstrncpy(Options.extprg, QFile::encodeName(stddirs.findResource("exe","ktalkdlg")), S_CFGLINE-1);
   }
 
   delete syscfg;
-  message("End of global configuration");
+  debug("End of global configuration");
   return 1;
 }
 
