@@ -3,7 +3,36 @@
  *
  * Routines for reading talkd.conf and .talkdrc
  *
- * by David Faure, faure@kde.org
+ * Copyright 1999-2002, David Faure, faure@kde.org
+ *
+ *  Redistribution and use in source and binary forms, with or
+ *    without modification, are permitted provided that the following
+ *    conditions are met:
+ *
+ *    - Redistributions of source code must retain the above
+ *      copyright notice, this list of conditions and the following
+ *      disclaimer.
+ *
+ *    - Redistributions in binary form must reproduce the above
+ *      copyright notice, this list of conditions and the following
+ *      disclaimer in the documentation and/or other materials
+ *      provided with the distribution.
+ *
+ *  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY
+ *    EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
+ *    THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
+ *    PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR
+ *    BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ *    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+ *    TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ *    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+ *    ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ *    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ *    IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ *    THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * (BSD License, from kdelibs/doc/common/bsd-license.html)
+ *
  */
 
 #include <pwd.h>
@@ -15,7 +44,7 @@
 #include <unistd.h>
 #include <string.h>
 #include <ctype.h>
-#include "print.h"
+#include "proto.h"
 #include "readconf.h"
 #include "defs.h"
 
@@ -110,35 +139,35 @@ int process_config_file(void)
 		 
 	       if (found("AnswMach:")) {
 		    Options.answmach=booleanresult(result); 
-		    message("AnswMach : %d",Options.answmach);}
+		    debug("AnswMach : %d",Options.answmach);}
 		 
 	       if (found("XAnnounce:")) {
 		    Options.XAnnounce=booleanresult(result); 
-		    message("XAnnounce : %d",Options.XAnnounce); }
+		    debug("XAnnounce : %d",Options.XAnnounce); }
 	    
 	       if (found("Time:")) { 
 		    Options.time_before_answmach=atoi(result); 
-		    message("Time : %d",Options.time_before_answmach); }
+		    debug("Time : %d",Options.time_before_answmach); }
 
 	       if (found("Sound:")) { 
 		    Options.sound=booleanresult(result);
-		    message("Sound : %d",Options.sound); }
+		    debug("Sound : %d",Options.sound); }
 
 	       if (found("SoundFile:")) { 
 		    strncpy(Options.soundfile,result,S_CFGLINE);
-		    message("SoundFile =");message(Options.soundfile); }
+		    debug("SoundFile =");debug(Options.soundfile); }
 
 	       if (found("SoundPlayer:")) { 
                    strncpy(Options.soundplayer,result,S_CFGLINE);
-		    message("SoundPlayer ="); message(result); }
+		    debug("SoundPlayer ="); debug(result); }
 
 	       if (found("SoundPlayerOpt:")) { 
                     strncpy(Options.soundplayeropt,result,S_CFGLINE); 
-		    message("SoundPlayerOpt ="); message(result); }
+		    debug("SoundPlayerOpt ="); debug(result); }
 
 	       if (found("MailProg:")) { 
 		    strncpy(Options.mailprog,result,S_CFGLINE);
-		    message("Mail prog ="); message(result); }
+		    debug("Mail prog ="); debug(result); }
 
                /* text based announcement */
                if (found("Announce1")) { strncpy(Options.announce1,result,S_CFGLINE); }
