@@ -35,44 +35,57 @@
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qgrid.h>
+#include <qvbuttongroup.h>
 
 #include <kapplication.h>
 #include <kprocess.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <keditlistbox.h>
+#include <krestrictedline.h>
+#include <kdialogbase.h>
+#include <ktempfile.h>
 
 #include <kdebug.h>
 
 LisaSettings::LisaSettings(const QString& config, QWidget *parent)
-:QVBox(parent)
+: KCModule(parent)
 ,m_config(config,false,true)
+,m_wizard(0)
+,m_configFilename(config)
+,m_changed(false)
 {
-   m_configFilename=config;
-   QHBox *hbox1 = new QHBox(this);
-   new QWidget(hbox1);
-   m_autoSetup=new QPushButton(i18n("&Guided LISa Setup..."),hbox1);
-   m_autoSetup->setFixedWidth( m_autoSetup->sizeHint().width() );   
+   QVBoxLayout *layout = new QVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
+   layout->setAutoAdd(true);
 
-   QGrid *addressesGrid = new QGrid(2, Qt::Horizontal, this);
-   addressesGrid->setSpacing(10);
-   setStretchFactor(addressesGrid,0);
+   QWidget *dummy(0);
 
-   QLabel *label=new QLabel(i18n("&Scan these addresses"),addressesGrid);
+   QVButtonGroup *gb=new QVButtonGroup(i18n("Tell LISa Daemon How to Search for Hosts"),this);
+   gb->setInsideSpacing(10);
+
+   m_useNmblookup=new QCheckBox(i18n("Send &NetBIOS broadcasts using nmblookup"), gb);
+   QToolTip::add(m_useNmblookup,i18n("Only hosts running SMB servers will answer"));
+
+   m_sendPings=new QCheckBox(i18n("Send &pings (ICMP echo packets)"), gb);
+   QToolTip::add(m_sendPings,i18n("All hosts running TCP/IP will answer"));
+
+   QHBox *hbox=new QHBox(gb);
+   hbox->setSpacing(10);
+
+   dummy=new QWidget(hbox);
+   dummy->setMinimumWidth(10);
+   QLabel *label=new QLabel(i18n("To these &IP addresses:"),hbox);
    QString comment = i18n("Enter all ranges to scan, using the format '192.168.0.1/255.255.255.255.0;10.0.0.1;255.0.0.0'");
    QToolTip::add(label,comment);
-   m_pingAddresses=new KRestrictedLine(addressesGrid,"a","0123456789.-/;");
+   m_pingAddresses=new KRestrictedLine(hbox,"a","0123456789.-/;");
    QToolTip::add(m_pingAddresses, comment);
    label->setBuddy(m_pingAddresses);
 
-   label=new QLabel(i18n("&Trusted addresses"),addressesGrid);
-   comment = i18n("usually your network address/subnet mask (e.g. 192.168.0.0/255.255.255.0;)");
-   QToolTip::add(label, comment);
+   QGrid *addressesGrid = new QGrid(2, Qt::Horizontal, this);
+   addressesGrid->setSpacing(10);
+   layout->setStretchFactor(addressesGrid,0);
 
-   m_allowedAddresses=new KRestrictedLine(addressesGrid,"a","0123456789./;");
-   QToolTip::add(m_allowedAddresses, comment);
-   label->setBuddy(m_allowedAddresses);
-
-   label=new QLabel(i18n("&Broadcast network address"),addressesGrid);
+   label=new QLabel(i18n("&Broadcast network address:"),addressesGrid);
    comment=i18n("Your network address/subnet mask (e.g. 192.168.0.0/255.255.255.0;)");
    QToolTip::add(label, comment);
 
@@ -80,58 +93,73 @@ LisaSettings::LisaSettings(const QString& config, QWidget *parent)
    QToolTip::add(m_broadcastNetwork,comment);
    label->setBuddy(m_broadcastNetwork);
 
-   m_pingNames=new KEditListBox(i18n("A&dditionally check the following hosts"),this,"a",false, KEditListBox::Add|KEditListBox::Remove);
-   QToolTip::add(m_pingNames,i18n("The names of the hosts you want to check"));
+   label=new QLabel(i18n("&Trusted IP addresses:"),addressesGrid);
+   comment = i18n("Usually your network address/subnet mask (e.g. 192.168.0.0/255.255.255.0;)");
+   QToolTip::add(label, comment);
 
-   QGroupBox *gb=new QGroupBox(i18n("Advanced settings"),this);
-   gb->setColumnLayout(0, Qt::Vertical );
-   gb->layout()->setSpacing( 6 );
-   gb->layout()->setMargin( 6 );
-   QGridLayout *grid2 = new QGridLayout( gb->layout(), 4, 4);
-   m_useNmblookup=new QCheckBox(i18n("Send NetBIOS broadcasts using &nmblookup for searching"), gb);
-   QToolTip::add(m_useNmblookup,i18n("only hosts running smb servers will answer"));
-   grid2->addMultiCellWidget(m_useNmblookup, 0, 0, 0, 3);
+   m_allowedAddresses=new KRestrictedLine(addressesGrid,"a","0123456789./;");
+   QToolTip::add(m_allowedAddresses, comment);
+   label->setBuddy(m_allowedAddresses);
 
-   m_deliverUnnamedHosts=new QCheckBox(i18n("Re&port unnamed hosts"),gb);
-   QToolTip::add(m_deliverUnnamedHosts,i18n("report hosts without DNS names"));
-   grid2->addMultiCellWidget(m_deliverUnnamedHosts, 1, 1, 0, 1);
+   dummy=new QWidget(this);
+   layout->setStretchFactor(dummy,10);
 
-   m_secondScan=new QCheckBox(i18n("Al&ways scan twice"),gb);
-   QToolTip::add(m_secondScan,i18n("check the hosts twice"));
-   grid2->addMultiCellWidget(m_secondScan, 1, 1, 2, 3);
+   hbox = new QHBox(this);
+   hbox->setSpacing(10);
+   m_autoSetup=new QPushButton(i18n("&Guided LISa Setup..."),hbox);
+   m_autoSetup->setFixedWidth( m_autoSetup->sizeHint().width() );   
 
-   label=new QLabel(i18n("Update interval"),gb);
-   QToolTip::add(label,i18n("search hosts after this number of seconds"));
-   grid2->addWidget(label, 2, 0);
-   m_updatePeriod=new QSpinBox(30,1800,10,gb);
+   m_suggestSettings=new QPushButton(i18n("&Suggest Settings"),hbox);
+
+   new QWidget(hbox);
+
+   m_advancedSettingsButton=new QPushButton(i18n("Ad&vanced Settings..."),hbox);
+
+   m_lisaAdvancedDlg=new KDialogBase(0,0,true,i18n("Advanced Settings for LISa"),KDialogBase::Close, KDialogBase::Close);
+   connect(m_advancedSettingsButton,SIGNAL(clicked()),m_lisaAdvancedDlg,SLOT(show()));
+
+   QVBox *vbox=m_lisaAdvancedDlg->makeVBoxMainWidget();
+
+   m_pingNames=new KEditListBox(i18n("&Additionally Check These Hosts"),vbox,"a",false, KEditListBox::Add|KEditListBox::Remove);
+   m_pingNames->setMinimumHeight(180);
+   QToolTip::add(m_pingNames,i18n("The hosts listed here will be pinged"));
+
+   dummy=new QWidget(vbox);
+   dummy->setMinimumHeight(10);
+   m_deliverUnnamedHosts=new QCheckBox(i18n("Show &hosts without DNS names"),vbox);
+
+   QGrid *advGrid = new QGrid(2, Qt::Horizontal, vbox);
+   advGrid->setSpacing(10);
+
+   label=new QLabel(i18n("Host list update interval:"),advGrid);
+   QToolTip::add(label,i18n("Search hosts after this number of seconds"));
+   m_updatePeriod=new QSpinBox(30,1800,10,advGrid);
    m_updatePeriod->setSuffix(i18n(" sec"));
-   QToolTip::add(m_updatePeriod,i18n("search hosts after this number of seconds"));
-   grid2->addWidget(m_updatePeriod, 2, 1);
+   QToolTip::add(m_updatePeriod,i18n("Search hosts after this number of seconds"));
 
-   label=new QLabel(i18n("Wait for replies after first scan"),gb);
-   QToolTip::add(label,i18n("how long to wait for replies to the ICMP echo requests from hosts"));
-   grid2->addWidget(label, 2, 2);
-   m_firstWait=new QSpinBox(10,1000,50,gb);
+   m_secondScan=new QCheckBox(i18n("Always check twice for hosts when searching"),advGrid);
+   new QWidget(advGrid);
+
+   label=new QLabel(i18n("Wait for replies from hosts after first scan:"),advGrid);
+   QToolTip::add(label,i18n("How long to wait for replies to the ICMP echo requests from hosts"));
+   m_firstWait=new QSpinBox(10,1000,50,advGrid);
    m_firstWait->setSuffix(i18n(" ms"));
-   QToolTip::add(m_firstWait,i18n("how long to wait for replies to the ICMP echo requests from hosts"));
-   grid2->addWidget(m_firstWait, 2, 3);
+   QToolTip::add(m_firstWait,i18n("How long to wait for replies to the ICMP echo requests from hosts"));
 
-   label=new QLabel(i18n("Send pings at once"),gb);
-   QToolTip::add(label,i18n("send this number of ping packets at once"));
-   grid2->addWidget(label, 3, 0);
-   m_maxPingsAtOnce=new QSpinBox(8,1024,5,gb);
-   QToolTip::add(m_maxPingsAtOnce,i18n("send this number of ping packets at once"));
-   grid2->addWidget(m_maxPingsAtOnce, 3, 1);
-
-   label=new QLabel(i18n("Wait for replies after second scan"),gb);
-   QToolTip::add(label,i18n("how long to wait for replies to the ICMP echo requests from hosts"));
-   grid2->addWidget(label, 3, 2);
-   m_secondWait=new QSpinBox(0,1000,50,gb);
+   label=new QLabel(i18n("Wait for replies from hosts after second scan:"),advGrid);
+   QToolTip::add(label,i18n("How long to wait for replies to the ICMP echo requests from hosts"));
+   m_secondWait=new QSpinBox(0,1000,50,advGrid);
    m_secondWait->setSuffix(i18n(" ms"));
    QToolTip::add(m_secondWait,i18n("how long to wait for replies to the ICMP echo requests from hosts"));
-   grid2->addWidget(m_secondWait, 3, 3);
+
+   label=new QLabel(i18n("Max. number of ping packets to send at once:"),advGrid);
+   m_maxPingsAtOnce=new QSpinBox(8,1024,5,advGrid);
+
+   dummy=new QWidget(advGrid);
+   dummy->setMinimumHeight(10);
 
    connect(m_secondScan,SIGNAL(toggled(bool)),m_secondWait,SLOT(setEnabled(bool)));
+   connect(m_sendPings,SIGNAL(toggled(bool)),m_pingAddresses,SLOT(setEnabled(bool)));
 
    connect(m_pingAddresses,SIGNAL(textChanged(const QString&)),this,SIGNAL(changed()));
    connect(m_allowedAddresses,SIGNAL(textChanged(const QString&)),this,SIGNAL(changed()));
@@ -141,6 +169,7 @@ LisaSettings::LisaSettings(const QString& config, QWidget *parent)
    connect(m_allowedAddresses,SIGNAL(returnPressed()),this,SIGNAL(changed()));
    connect(m_broadcastNetwork,SIGNAL(returnPressed()),this,SIGNAL(changed()));
 
+   connect(m_sendPings,SIGNAL(toggled(bool)),this,SIGNAL(changed()));
    connect(m_firstWait,SIGNAL(valueChanged(int)),this,SIGNAL(changed()));
    connect(m_secondWait,SIGNAL(valueChanged(int)),this,SIGNAL(changed()));
    connect(m_maxPingsAtOnce,SIGNAL(valueChanged(int)),this,SIGNAL(changed()));
@@ -150,9 +179,8 @@ LisaSettings::LisaSettings(const QString& config, QWidget *parent)
    connect(m_pingNames,SIGNAL(changed()),this,SIGNAL(changed()));
    connect(m_useNmblookup,SIGNAL(toggled(bool)),this,SIGNAL(changed()));
    connect(m_autoSetup,SIGNAL(clicked()),this,SLOT(autoSetup()));
-
-   setMargin(10);
-   setSpacing(15);
+   connect(m_suggestSettings,SIGNAL(clicked()),this,SLOT(suggestSettings()));
+   connect(this, SIGNAL(changed()), SLOT(slotChanged()));
 }
 
 void LisaSettings::load()
@@ -169,23 +197,27 @@ void LisaSettings::load()
       m_secondWait->setValue(secondWait*10);
       m_secondScan->setChecked(TRUE);
       m_secondWait->setEnabled(TRUE);
-   };
+   }
    m_deliverUnnamedHosts->setChecked(m_config.readNumEntry("DeliverUnnamedHosts",0));
 
    m_firstWait->setValue(m_config.readNumEntry("FirstWait",30)*10);
    m_maxPingsAtOnce->setValue(m_config.readNumEntry("MaxPingsAtOnce",256));
    m_updatePeriod->setValue(m_config.readNumEntry("UpdatePeriod",300));
    m_pingAddresses->setText(m_config.readEntry("PingAddresses","192.168.0.0/255.255.255.0;192.168.100.0-192.168.100.254"));
-   m_allowedAddresses->setText(m_config.readEntry("AllowedAddresses","192.168.0.0/255.255.0.0"));
-   m_broadcastNetwork->setText(m_config.readEntry("BroadcastNetwork","192.168.0.0/255.255.0.0"));
+   m_sendPings->setChecked(!m_pingAddresses->text().isEmpty());
+   m_allowedAddresses->setText(m_config.readEntry("AllowedAddresses","192.168.0.0/255.255.255.0"));
+   m_broadcastNetwork->setText(m_config.readEntry("BroadcastNetwork","192.168.0.0/255.255.255.0"));
    m_pingNames->clear();
    m_pingNames->insertStringList(m_config.readListEntry("PingNames",';'));
    int i=m_config.readNumEntry("SearchUsingNmblookup",1);
    m_useNmblookup->setChecked(i!=0);
-};
+   m_changed = false;
+}
 
 void LisaSettings::save()
 {
+   if (!m_changed) return;
+   
    if ( getuid()==0)
    {
       if (m_secondScan->isChecked())
@@ -206,7 +238,7 @@ void LisaSettings::save()
       m_config.writeEntry("FirstWait",(m_firstWait->value()+5)/10);
       m_config.writeEntry("MaxPingsAtOnce",m_maxPingsAtOnce->value());
       m_config.writeEntry("UpdatePeriod",m_updatePeriod->value());
-      m_config.writeEntry("PingAddresses",m_pingAddresses->text());
+      m_config.writeEntry("PingAddresses",m_sendPings->isChecked()?m_pingAddresses->text():"");
       m_config.writeEntry("AllowedAddresses",m_allowedAddresses->text());
       m_config.writeEntry("BroadcastNetwork",m_broadcastNetwork->text());
       QStringList writeStuff;
@@ -222,17 +254,12 @@ void LisaSettings::save()
       //ok, now it gets harder
       //we are not root but we want to write into /etc ....
       //any idea how to do it better ?
-      QString username("???");
-      struct passwd *user = getpwuid( getuid() );
-      if ( user )
-         username=user->pw_name;
-      m_tmpFilename=QString("/tmp/kcmlisa-%1-%2-%3").arg(username).arg(getpid()).arg(time(0));
+      KTempFile tmp;
 
-      QFile tmpFile(m_tmpFilename);
-      bool res=tmpFile.open(IO_ReadWrite);
-      if (res)
+      if (tmp.status() == 0 && tmp.textStream())
       {
-         QTextStream confStream(&tmpFile);
+         m_tmpFilename = tmp.name();
+         QTextStream &confStream = *(tmp.textStream());
          if (m_secondScan->isChecked())
             confStream<<"SecondWait = "<<(m_secondWait->value()+5)/10<<"\n";
          else
@@ -259,8 +286,8 @@ void LisaSettings::save()
             writeStuff=writeStuff+m_pingNames->text(i).latin1()+";";
 
          confStream<<"PingNames = "<<writeStuff.latin1()<<"\n";
-         tmpFile.close();
-         QString suCommand=QString("cp %1 %2; chmod 644 %3").arg(m_tmpFilename).arg(m_configFilename).arg(m_configFilename);
+         tmp.close();
+         QString suCommand=QString("cp '%1' '%2'; chmod 644 '%3'; rm -f '%4'").arg(m_tmpFilename).arg(m_configFilename).arg(m_configFilename).arg(m_tmpFilename);
          KProcess *proc = new KProcess();
          connect(proc, SIGNAL(processExited(KProcess *)), this, SLOT(saveDone(KProcess *)));
          *proc<<"kdesu"<<"-c"<<suCommand;
@@ -269,20 +296,66 @@ void LisaSettings::save()
          proc->start();
       }
       else
-         KMessageBox::sorry(0,i18n("Sorry, saving the results to %1 failed.").arg(m_configFilename));
+         KMessageBox::sorry(0,i18n("Saving the results to %1 failed.").arg(m_configFilename));
    }
 }
 
+void LisaSettings::suggestSettings()
+{
+   NICList *nics=findNICs();
+   if (nics->count()==0)
+   {
+      KMessageBox::sorry(0,i18n("No network interface cards found."));
+      delete nics;
+      return;
+   }
+   MyNIC *nic=nics->first();
+   LisaConfigInfo lci;
+   suggestSettingsForNic(nic,lci);
+   m_pingAddresses->setText(lci.pingAddresses);
+   m_sendPings->setChecked(!m_pingAddresses->text().isEmpty());
+   m_broadcastNetwork->setText(lci.broadcastNetwork);
+   m_allowedAddresses->setText(lci.allowedAddresses);
+   m_secondWait->setValue(lci.secondWait*10);
+   m_secondScan->setChecked(lci.secondScan);
+   m_secondWait->setEnabled(lci.secondScan);
+   m_firstWait->setValue(lci.firstWait*10);
+   m_maxPingsAtOnce->setValue(lci.maxPingsAtOnce);
+   m_updatePeriod->setValue(lci.updatePeriod);
+   m_useNmblookup->setChecked(lci.useNmblookup);
+   m_deliverUnnamedHosts->setChecked(lci.unnamedHosts);
+
+   if (nics->count()>1)
+   {
+      QString msg(i18n("You have more than one network interface installed.<br>"
+                       "Please make sure the suggested settings are correct.<br>"
+                       "<br>The following interfaces were found:<br><br>"));
+      //not that easy to handle
+      for (MyNIC* tmp=nics->first(); tmp!=0; tmp=nics->next())
+      {
+         msg+="<b>"+tmp->name+": </b>"+inet_ntoa(tmp->addr.sin_addr)+"/"+inet_ntoa(tmp->netmask.sin_addr)+";<br>";
+      }
+      KMessageBox::information(0,QString("<html>%1</html>").arg(msg));
+   }
+
+   emit changed();
+   delete nics;
+}
+
 void LisaSettings::autoSetup()
 {
    LisaConfigInfo lci;
-   SetupWizard *w=new SetupWizard(this,&lci);
-   int result=w->exec();
-   delete w;
+   if (m_wizard==0)
+      m_wizard=new SetupWizard(this,&lci);
+   else
+      m_wizard->clearAll();
+   int result=m_wizard->exec();
+
    if (result!=QDialog::Accepted)
       return;
 
    m_pingAddresses->setText(lci.pingAddresses);
+   m_sendPings->setChecked(!m_pingAddresses->text().isEmpty());
    m_broadcastNetwork->setText(lci.broadcastNetwork);
    m_allowedAddresses->setText(lci.allowedAddresses);
    m_secondWait->setValue(lci.secondWait*10);
@@ -296,15 +369,24 @@ void LisaSettings::autoSetup()
 
    emit changed();
    return;
-};
+}
 
 void LisaSettings::saveDone(KProcess *proc)
 {
    unlink(QFile::encodeName(m_tmpFilename));
    KApplication::restoreOverrideCursor();
    setEnabled(true);
+   KMessageBox::information(0,i18n("The configuration has been saved to /etc/lisarc.\n"
+                                   "Make sure that the LISa daemon is started,\n e.g. using an init script when booting.\n"
+                                   "You can find examples and documentation at http://lisa-home.sourceforge.net ."));
+
    delete(proc);
 }
 
+void LisaSettings::slotChanged()
+{
+   m_changed = true;
+}
+
 #include "kcmlisa.moc"
 
