@@ -1,17 +1,32 @@
-/*
+/*  -*- c++ -*-
     kmime_codec_qp.cpp
 
-    KMime, the KDE internet mail/usenet news message library.
-    Copyright (c) 2002 the KMime authors.
-    See file AUTHORS for details
+    This file is part of KMime, the KDE internet mail/usenet news message library.
+    Copyright (c) 2002 Marc Mutz <mutz@kde.org>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License,
-    version 2.0, as published by the Free Software Foundation.
+    KMime is free software; you can redistribute it and/or modify it
+    under the terms of the GNU General Public License, version 2, as
+    published by the Free Software Foundation.
+
+    KMime is distributed in the hope that it will be useful, but
+    WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software Foundation,
-    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, US
+    along with this library; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+    In addition, as a special exception, the copyright holders give
+    permission to link the code of this library with any edition of
+    the Qt library by Trolltech AS, Norway (or with modified versions
+    of Qt that use the same license as Qt), and distribute linked
+    combinations including the two.  You must obey the GNU General
+    Public License in all respects for all of the code used other than
+    Qt.  If you modify this file, you may extend this exception to
+    your version of the file, but you are not obligated to do so.  If
+    you do not wish to do so, delete this exception statement from
+    your version.
 */
 
 #include "kmime_codec_qp.h"
@@ -597,9 +612,9 @@ bool Rfc2047QEncodingEncoder::finish( char* & dcursor, const char * const dend )
   }
 
   return mStepNo == 0;
-};
+}
 
 
 
 
-}; // namespace KMime
+} // namespace KMime
